@@ -22,6 +22,8 @@
 #ifndef _WIN32
 #include <langinfo.h>
 #include <sys/param.h>
+#else
+#include "wincodepages.h"
 #endif
 #include <limits.h>
 #include "safesysstat.h"
@@ -42,7 +44,7 @@
 #include "rclutil.h"
 #include "rclconfig.h"
 #include "conftree.h"
-#include "debuglog.h"
+#include "log.h"
 #include "smallut.h"
 #include "textsplit.h"
 #include "readfile.h"
@@ -52,8 +54,6 @@
 
 using namespace std;
 
-typedef pair<int,int> RclPII;
-
 // Static, logically const, RclConfig members are initialized once from the
 // first object build during process initialization.
 
@@ -65,57 +65,93 @@ bool o_uptodate_test_use_mtime = false;
 string RclConfig::o_localecharset; 
 string RclConfig::o_origcwd; 
 
-bool ParamStale::needrecompute()
+// Compute the difference of 1st to 2nd set<string> and return as
+// plus/minus strings
+static void setPlusMinus(const set<string>& base, const set<string>& upd,
+                         string& plus, string& minus)
 {
-    LOGDEB2(("ParamStale:: needrecompute. parent gen %d mine %d\n", 
-	     parent->m_keydirgen, savedkeydirgen));
-    if (active && parent->m_keydirgen != savedkeydirgen) {
-	LOGDEB2(("ParamState:: needrecompute. conffile %p\n", conffile));
+    vector<string> diff;
+    auto it =
+        set_difference(base.begin(), base.end(), upd.begin(), upd.end(),
+                       std::inserter(diff, diff.begin()));
+    minus = stringsToString(diff);
 
-        savedkeydirgen = parent->m_keydirgen;
-        string newvalue;
-        if (!conffile)
-            return false;
-        conffile->get(paramname, newvalue, parent->m_keydir);
-        if (newvalue.compare(savedvalue)) {
-            savedvalue = newvalue;
-	    LOGDEB2(("ParamState:: needrecompute. return true newvalue [%s]\n",
-		     newvalue.c_str()));
-            return true;
+    diff.clear();
+    it = set_difference(upd.begin(), upd.end(), base.begin(), base.end(),
+                        std::inserter(diff, diff.begin()));
+    plus = stringsToString(diff);
+}
+
+static void computeBasePlusMinus(set<string>& res, const string& strbase,
+                                 const string& strplus, const string& strminus)
+{
+    set<string> plus, minus;
+    stringToStrings(strbase, res);
+    stringToStrings(strplus, plus);
+    stringToStrings(strminus, minus);
+    for (auto& it : minus) {
+        auto it1 = res.find(it);
+        if (it1 != res.end()) {
+            res.erase(it1);
         }
     }
-    return false;
+    for (auto& it : plus) {
+        res.insert(it);
+    }
+}
+
+bool ParamStale::needrecompute()
+{
+    LOGDEB1("ParamStale:: needrecompute. parent gen " << parent->m_keydirgen <<
+            " mine " << savedkeydirgen << "\n");
+
+    if (!conffile) {
+        LOGDEB("ParamStale::needrecompute: conffile not set\n");
+        return false;
+    }
+
+    bool needrecomp = false;
+    if (active && parent->m_keydirgen != savedkeydirgen) {
+        savedkeydirgen = parent->m_keydirgen;
+        for (unsigned int i = 0; i < paramnames.size(); i++) {
+            string newvalue;
+            conffile->get(paramnames[i], newvalue, parent->m_keydir);
+            LOGDEB1("ParamStale::needrecompute: " << paramnames[i] << " -> " <<
+                    newvalue << " keydir " << parent->m_keydir << endl);
+            if (newvalue.compare(savedvalues[i])) {
+                savedvalues[i] = newvalue;
+                needrecomp = true;
+            }
+        }
+    }
+    return needrecomp;
+}
+
+const string& ParamStale::getvalue(unsigned int i) const
+{
+    if (i < savedvalues.size()) {
+        return savedvalues[i];
+    } else {
+        static string nll;
+        return nll;
+    }
 }
 
 void ParamStale::init(ConfNull *cnf)
 {
     conffile = cnf;
     active = false;
-    if (conffile)
-      active = conffile->hasNameAnywhere(paramname);
+    if (conffile) {
+        for (auto& nm : paramnames) {
+            if (conffile->hasNameAnywhere(nm)) {
+                active = true;
+                break;
+            }
+        }
+    }
     savedkeydirgen = -1;
 }
 
-ParamStale::ParamStale(RclConfig *rconf, const string& nm)
-    : parent(rconf), conffile(0), paramname(nm),
-      active(false), savedkeydirgen(-1)
-{
-}
-
-void RclConfig::zeroMe() {
-    m_ok = false; 
-    m_keydirgen = 0;
-    m_conf = 0; 
-    mimemap = 0; 
-    mimeconf = 0; 
-    mimeview = 0; 
-    m_fields = 0;
-    m_ptrans = 0;
-    m_stopsuffixes = 0;
-    m_maxsufflen = 0;
-    initParamStale(0, 0);
-}
-
 bool RclConfig::isDefaultConfig() const
 {
     string defaultconf = path_cat(path_homedata(),
@@ -126,10 +162,24 @@ bool RclConfig::isDefaultConfig() const
     return !defaultconf.compare(specifiedconf);
 }
 
+
+RclConfig::RclConfig(const RclConfig &r) 
+    : m_oldstpsuffstate(this, "recoll_noindex"),
+      m_stpsuffstate(this, {"noContentSuffixes", "noContentSuffixes+",
+                  "noContentSuffixes-"}),
+      m_skpnstate(this, {"skippedNames", "skippedNames+", "skippedNames-"}),
+      m_rmtstate(this, "indexedmimetypes"),
+      m_xmtstate(this, "excludedmimetypes"),
+      m_mdrstate(this, "metadatacmds")
+{
+    initFrom(r);
+}
+
 RclConfig::RclConfig(const string *argcnf)
     : m_oldstpsuffstate(this, "recoll_noindex"),
-      m_stpsuffstate(this, "noContentSuffixes"),
-      m_skpnstate(this, "skippedNames"),
+      m_stpsuffstate(this, {"noContentSuffixes", "noContentSuffixes+",
+                  "noContentSuffixes-"}),
+      m_skpnstate(this, {"skippedNames", "skippedNames+", "skippedNames-"}),
       m_rmtstate(this, "indexedmimetypes"),
       m_xmtstate(this, "excludedmimetypes"),
       m_mdrstate(this, "metadatacmds")
@@ -141,7 +191,8 @@ RclConfig::RclConfig(const string *argcnf)
 	if (getcwd(buf, MAXPATHLEN)) {
 	    o_origcwd = string(buf);
 	} else {
-	    fprintf(stderr, "recollxx: can't retrieve current working directory: relative path translations will fail\n");
+	    fprintf(stderr, "recollxx: can't retrieve current working "
+                    "directory: relative path translations will fail\n");
 	}
     }
 
@@ -165,7 +216,7 @@ RclConfig::RclConfig(const string *argcnf)
 	    m_confdir = path_canon(cp);
 	} else {
 	    autoconfdir = true;
-	    m_confdir = path_cat(path_homedata(), path_defaultrecollconfsubdir());
+	    m_confdir=path_cat(path_homedata(), path_defaultrecollconfsubdir());
 	}
     }
 
@@ -212,10 +263,10 @@ RclConfig::RclConfig(const string *argcnf)
 	    o_localecharset = string(cstr_cp1252);
 	}
 #else
-        o_localecharset = "UTF-8";
+        o_localecharset = winACPName();
 #endif
-	LOGDEB1(("RclConfig::getDefCharset: localecharset [%s]\n",
-		 o_localecharset.c_str()));
+	LOGDEB1("RclConfig::getDefCharset: localecharset ["  <<
+                o_localecharset << "]\n");
     }
 
     const char *cp;
@@ -269,8 +320,7 @@ RclConfig::RclConfig(const string *argcnf)
 	return;
 
     // Default is no threading
-    m_thrConf = create_vector<RclPII>
-	(RclPII(-1, 0))(RclPII(-1, 0))(RclPII(-1, 0));
+    m_thrConf = {{-1, 0}, {-1, 0}, {-1, 0}};
 
     m_ptrans = new ConfSimple(path_cat(m_confdir, "ptrans").c_str());
 
@@ -398,7 +448,7 @@ bool RclConfig::getConfParam(const string &name, bool *bvp, bool shallow) const
 }
 
 bool RclConfig::getConfParam(const string &name, vector<string> *svvp,
-    bool shallow) const
+                             bool shallow) const
 {
     if (!svvp) 
 	return false;
@@ -409,8 +459,20 @@ bool RclConfig::getConfParam(const string &name, vector<string> *svvp,
     return stringToStrings(s, *svvp);
 }
 
+bool RclConfig::getConfParam(const string &name, unordered_set<string> *out,
+                             bool shallow) const
+{
+    vector<string> v;
+    if (!out || !getConfParam(name, &v, shallow)) {
+	return false;
+    }
+    out->clear();
+    out->insert(v.begin(), v.end());
+    return true;
+}
+
 bool RclConfig::getConfParam(const string &name, vector<int> *vip,
-    bool shallow) const
+                             bool shallow) const
 {
     if (!vip) 
 	return false;
@@ -423,8 +485,8 @@ bool RclConfig::getConfParam(const string &name, vector<int> *vip,
 	char *ep;
 	vip->push_back(strtol(vs[i].c_str(), &ep, 0));
 	if (ep == vs[i].c_str()) {
-	    LOGDEB(("RclConfig::getConfParam: bad int value in [%s]\n",
-		    name.c_str()));
+	    LOGDEB("RclConfig::getConfParam: bad int value in [" << name <<
+                   "]\n");
 	    return false;
 	}
     }
@@ -434,24 +496,27 @@ bool RclConfig::getConfParam(const string &name, vector<int> *vip,
 void RclConfig::initThrConf()
 {
     // Default is no threading
-    m_thrConf = create_vector<RclPII>
-	(RclPII(-1, 0))(RclPII(-1, 0))(RclPII(-1, 0));
+    m_thrConf = {{-1, 0}, {-1, 0}, {-1, 0}};
 
     vector<int> vq;
     vector<int> vt;
     if (!getConfParam("thrQSizes", &vq)) {
-	LOGINFO(("RclConfig::initThrConf: no thread info (queues)\n"));
+	LOGINFO("RclConfig::initThrConf: no thread info (queues)\n");
 	goto out;
     }
 
     // If the first queue size is 0, autoconf is requested.
     if (vq.size() > 0 && vq[0] == 0) {
-	LOGDEB(("RclConfig::initThrConf: autoconf requested\n"));
 	CpuConf cpus;
 	if (!getCpuConf(cpus) || cpus.ncpus < 1) {
-	    LOGERR(("RclConfig::initThrConf: could not retrieve cpu conf\n"));
+	    LOGERR("RclConfig::initThrConf: could not retrieve cpu conf\n");
 	    cpus.ncpus = 1;
 	}
+        if (cpus.ncpus != 1) {
+            LOGDEB("RclConfig::initThrConf: autoconf requested. " <<
+                   cpus.ncpus << " concurrent threads available.\n");
+        }
+
 	// Arbitrarily set threads config based on number of CPUS. This also
 	// depends on the IO setup actually, so we're bound to be wrong...
 	if (cpus.ncpus == 1) {
@@ -459,14 +524,11 @@ void RclConfig::initThrConf()
 	    // it seems that the best config here is no threading
 	} else if (cpus.ncpus < 4) {
 	    // Untested so let's guess...
-	    m_thrConf = create_vector<RclPII>
-		(RclPII(2, 2))(RclPII(2, 2))(RclPII(2, 1));
+            m_thrConf = {{2, 2}, {2, 2}, {2, 1}};
 	} else if (cpus.ncpus < 6) {
-	    m_thrConf = create_vector<RclPII>
-		(RclPII(2, 4))(RclPII(2, 2))(RclPII(2, 1));
+	    m_thrConf = {{2, 4}, {2, 2}, {2, 1}};
 	} else {
-	    m_thrConf = create_vector<RclPII>
-		(RclPII(2, 5))(RclPII(2, 3))(RclPII(2, 1));
+	    m_thrConf = {{2, 5}, {2, 3}, {2, 1}};
 	}
 	goto out;
     } else if (vq.size() > 0 && vq[0] < 0) {
@@ -475,19 +537,19 @@ void RclConfig::initThrConf()
     }
 
     if (!getConfParam("thrTCounts", &vt) ) {
-	LOGINFO(("RclConfig::initThrConf: no thread info (threads)\n"));
+	LOGINFO("RclConfig::initThrConf: no thread info (threads)\n");
 	goto out;
     }
 
     if (vq.size() != 3 || vt.size() != 3) {
-	LOGINFO(("RclConfig::initThrConf: bad thread info vector sizes\n"));
+	LOGINFO("RclConfig::initThrConf: bad thread info vector sizes\n");
 	goto out;
     }
 
     // Normal case: record info from config
     m_thrConf.clear();
     for (unsigned int i = 0; i < 3; i++) {
-	m_thrConf.push_back(RclPII(vq[i], vt[i]));
+	m_thrConf.push_back({vq[i], vt[i]});
     }
 
 out:
@@ -497,14 +559,14 @@ out:
 	    ") ";
     }
 
-    LOGDEB(("RclConfig::initThrConf: chosen config (ql,nt): %s\n", 
-	    sconf.str().c_str()));
+    LOGDEB("RclConfig::initThrConf: chosen config (ql,nt): " << sconf.str() <<
+           "\n");
 }
 
 pair<int,int> RclConfig::getThrConf(ThrStage who) const
 {
     if (m_thrConf.size() != 3) {
-	LOGERR(("RclConfig::getThrConf: bad data in rclconfig\n"));
+	LOGERR("RclConfig::getThrConf: bad data in rclconfig\n");
 	return pair<int,int>(-1,-1);
     }
     return m_thrConf[who];
@@ -514,8 +576,8 @@ vector<string> RclConfig::getTopdirs() const
 {
     vector<string> tdl;
     if (!getConfParam("topdirs", &tdl)) {
-	LOGERR(("RclConfig::getTopdirs: no top directories in config or "
-		"bad list format\n"));
+	LOGERR("RclConfig::getTopdirs: no top directories in config or "
+               "bad list format\n");
 	return tdl;
     }
 
@@ -526,6 +588,11 @@ vector<string> RclConfig::getTopdirs() const
     return tdl;
 }
 
+const string& RclConfig::getLocaleCharset()
+{
+    return o_localecharset;
+}
+
 // Get charset to be used for transcoding to utf-8 if unspecified by doc
 // For document contents:
 //  If defcharset was set (from the config or a previous call, this
@@ -599,7 +666,7 @@ typedef multiset<SfString, SuffCmp> SuffixStore;
 
 bool RclConfig::inStopSuffixes(const string& fni)
 {
-    LOGDEB2(("RclConfig::inStopSuffixes(%s)\n", fni.c_str()));
+    LOGDEB2("RclConfig::inStopSuffixes(" << fni << ")\n");
     // Beware: both needrecompute() need to be called always hence the
     // bizarre way we do things
     bool needrecompute = m_stpsuffstate.needrecompute();
@@ -608,23 +675,24 @@ bool RclConfig::inStopSuffixes(const string& fni)
 	// Need to initialize the suffixes
         delete STOPSUFFIXES;
 	if ((m_stopsuffixes = new SuffixStore) == 0) {
-	    LOGERR(("RclConfig::inStopSuffixes: out of memory\n"));
+	    LOGERR("RclConfig::inStopSuffixes: out of memory\n");
 	    return false;
 	}
         // Let the old customisation have priority: if recoll_noindex
         // from mimemap is set, it the user's (the default value is
         // gone). Else use the new variable
-	vector<string> stoplist;
-        if (!m_oldstpsuffstate.savedvalue.empty()) {
-            stringToStrings(m_oldstpsuffstate.savedvalue, stoplist);
+	set<string> stoplist;
+        if (!m_oldstpsuffstate.getvalue(0).empty()) {
+            stringToStrings(m_oldstpsuffstate.getvalue(0), stoplist);
         } else {
-            stringToStrings(m_stpsuffstate.savedvalue, stoplist);
+            computeBasePlusMinus(stoplist, m_stpsuffstate.getvalue(0), 
+                                 m_stpsuffstate.getvalue(1), 
+                                 m_stpsuffstate.getvalue(2));
         }
-	for (vector<string>::const_iterator it = stoplist.begin(); 
-	     it != stoplist.end(); it++) {
-	    STOPSUFFIXES->insert(SfString(stringtolower(*it)));
-	    if (m_maxsufflen < it->length())
-		m_maxsufflen = int(it->length());
+	for (auto& it : stoplist) {
+	    STOPSUFFIXES->insert(SfString(stringtolower(it)));
+	    if (m_maxsufflen < it.length())
+		m_maxsufflen = int(it.length());
 	}
     }
 
@@ -635,11 +703,11 @@ bool RclConfig::inStopSuffixes(const string& fni)
     stringtolower(fn);
     SuffixStore::const_iterator it = STOPSUFFIXES->find(fn);
     if (it != STOPSUFFIXES->end()) {
-	LOGDEB2(("RclConfig::inStopSuffixes: Found (%s) [%s]\n", 
-		fni.c_str(), (*it).m_str.c_str()));
+	LOGDEB2("RclConfig::inStopSuffixes: Found (" << fni << ") ["  <<
+                ((*it).m_str) << "]\n");
 	return true;
     } else {
-	LOGDEB2(("RclConfig::inStopSuffixes: not found [%s]\n", fni.c_str()));
+	LOGDEB2("RclConfig::inStopSuffixes: not found [" << fni << "]\n");
 	return false;
     }
 }
@@ -706,28 +774,28 @@ string RclConfig::getMimeHandlerDef(const string &mtype, bool filtertypes)
     if (filtertypes) {
         if(m_rmtstate.needrecompute()) {
             m_restrictMTypes.clear();
-            stringToStrings(stringtolower((const string&)m_rmtstate.savedvalue),
+            stringToStrings(stringtolower((const string&)m_rmtstate.getvalue()),
                             m_restrictMTypes);
         }
         if (m_xmtstate.needrecompute()) {
             m_excludeMTypes.clear();
-            stringToStrings(stringtolower((const string&)m_xmtstate.savedvalue),
+            stringToStrings(stringtolower((const string&)m_xmtstate.getvalue()),
                             m_excludeMTypes);
         }
         if (!m_restrictMTypes.empty() && 
             !m_restrictMTypes.count(stringtolower(mtype))) {
-            LOGDEB2(("RclConfig::getMimeHandlerDef: not in mime type list\n"));
+            LOGDEB2("RclConfig::getMimeHandlerDef: not in mime type list\n");
             return hs;
         }
         if (!m_excludeMTypes.empty() && 
             m_excludeMTypes.count(stringtolower(mtype))) {
-            LOGDEB2(("RclConfig::getMimeHandlerDef: in excluded mime list\n"));
+            LOGDEB2("RclConfig::getMimeHandlerDef: in excluded mime list\n");
             return hs;
         }
     }
 
     if (!mimeconf->get(mtype, hs, "index")) {
-	LOGDEB1(("getMimeHandler: no handler for '%s'\n", mtype.c_str()));
+	LOGDEB1("getMimeHandlerDef: no handler for '" << mtype << "'\n");
     }
     return hs;
 }
@@ -737,8 +805,8 @@ const vector<MDReaper>& RclConfig::getMDReapers()
     string hs;
     if (m_mdrstate.needrecompute()) {
         m_mdreapers.clear();
-	// New value now stored in m_mdrstate.savedvalue
-	string& sreapers = m_mdrstate.savedvalue;
+	// New value now stored in m_mdrstate.getvalue(0)
+	const string& sreapers = m_mdrstate.getvalue(0);
 	if (sreapers.empty())
 	  return m_mdreapers;
 	string value;
@@ -818,7 +886,7 @@ void RclConfig::storeMissingHelperDesc(const string &s)
     FILE *fp = fopen(fmiss.c_str(), "w");
     if (fp) {
 	if (s.size() > 0 && fwrite(s.c_str(), s.size(), 1, fp) != 1) {
-            LOGERR(("storeMissingHelperDesc: fwrite failed\n"));
+            LOGERR("storeMissingHelperDesc: fwrite failed\n");
         }
 	fclose(fp);
     }
@@ -828,7 +896,7 @@ void RclConfig::storeMissingHelperDesc(const string &s)
 // things for speed (theses are used a lot during indexing)
 bool RclConfig::readFieldsConfig(const string& cnferrloc)
 {
-    LOGDEB2(("RclConfig::readFieldsConfig\n"));
+    LOGDEB2("RclConfig::readFieldsConfig\n");
     m_fields = new ConfStack<ConfSimple>("fields", m_cdirs, true);
     if (m_fields == 0 || !m_fields->ok()) {
 	m_reason = string("No/bad fields file in: ") + cnferrloc;
@@ -846,8 +914,8 @@ bool RclConfig::readFieldsConfig(const string& cnferrloc)
 	ConfSimple attrs;
 	FieldTraits ft;
 	if (!valueSplitAttributes(val, ft.pfx, attrs)) {
-	    LOGERR(("readFieldsConfig: bad config line for [%s]: [%s]\n", 
-		    it->c_str(), val.c_str()));
+	    LOGERR("readFieldsConfig: bad config line for ["  << *it <<
+                   "]: [" << val << "]\n");
 	    return 0;
 	}
 	string tval;
@@ -860,8 +928,8 @@ bool RclConfig::readFieldsConfig(const string& cnferrloc)
 	if (attrs.get("noterms", tval))
 	    ft.noterms = stringToBool(tval);
 	m_fldtotraits[stringtolower(*it)] = ft;
-	LOGDEB2(("readFieldsConfig: [%s] -> [%s] %d %.1f\n", 
-		it->c_str(), ft.pfx.c_str(), ft.wdfinc, ft.boost));
+	LOGDEB2("readFieldsConfig: ["  << *it << "] -> ["  << ft.pfx <<
+                "] " << ft.wdfinc << " " << ft.boost << "\n");
     }
 
     // Add prefixes for aliases and build alias-to-canonic map while
@@ -907,9 +975,8 @@ bool RclConfig::readFieldsConfig(const string& cnferrloc)
 #if 0
     for (map<string, FieldTraits>::const_iterator it = m_fldtotraits.begin();
 	 it != m_fldtotraits.end(); it++) {
-	LOGDEB(("readFieldsConfig: [%s] -> [%s] %d %.1f\n", 
-		it->c_str(), it->second.pfx.c_str(), it->second.wdfinc, 
-		it->second.boost));
+	LOGDEB("readFieldsConfig: ["  << *it << "] -> ["  << it->second.pfx <<
+               "] " << it->second.wdfinc << " " << it->second.boost << "\n");
     }
 #endif
 
@@ -942,12 +1009,12 @@ bool RclConfig::getFieldTraits(const string& _fld, const FieldTraits **ftpp,
     map<string, FieldTraits>::const_iterator pit = m_fldtotraits.find(fld);
     if (pit != m_fldtotraits.end()) {
 	*ftpp = &pit->second;
-	LOGDEB1(("RclConfig::getFieldTraits: [%s]->[%s]\n", 
-		 _fld.c_str(), pit->second.pfx.c_str()));
+	LOGDEB1("RclConfig::getFieldTraits: [" << _fld << "]->["  <<
+                pit->second.pfx << "]\n");
 	return true;
     } else {
-	LOGDEB1(("RclConfig::getFieldTraits: no prefix for field [%s]\n",
-		 fld.c_str()));
+	LOGDEB1("RclConfig::getFieldTraits: no prefix for field [" << fld <<
+                "]\n");
 	*ftpp = 0;
 	return false;
     }
@@ -969,11 +1036,11 @@ string RclConfig::fieldCanon(const string& f) const
     string fld = stringtolower(f);
     map<string, string>::const_iterator it = m_aliastocanon.find(fld);
     if (it != m_aliastocanon.end()) {
-	LOGDEB1(("RclConfig::fieldCanon: [%s] -> [%s]\n", 
-		 f.c_str(), it->second.c_str()));
+	LOGDEB1("RclConfig::fieldCanon: [" << f << "] -> [" << it->second <<
+                "]\n");
 	return it->second;
     }
-    LOGDEB1(("RclConfig::fieldCanon: [%s] -> [%s]\n", f.c_str(), fld.c_str()));
+    LOGDEB1("RclConfig::fieldCanon: ["  << (f) << "] -> ["  << (fld) << "]\n");
     return fld;
 }
 
@@ -982,8 +1049,8 @@ string RclConfig::fieldQCanon(const string& f) const
     string fld = stringtolower(f);
     map<string, string>::const_iterator it = m_aliastoqcanon.find(fld);
     if (it != m_aliastoqcanon.end()) {
-	LOGDEB1(("RclConfig::fieldQCanon: [%s] -> [%s]\n", 
-                f.c_str(), it->second.c_str()));
+	LOGDEB1("RclConfig::fieldQCanon: [" << f << "] -> ["  << it->second <<
+                "]\n");
 	return it->second;
     }
     return fieldCanon(f);
@@ -1005,20 +1072,44 @@ bool RclConfig::getFieldConfParam(const string &name, const string &sk,
     return m_fields->get(name, value, sk);
 }
 
-string RclConfig::getMimeViewerAllEx() const
+set<string> RclConfig::getMimeViewerAllEx() const
 {
-    string hs;
+    set<string> res;
     if (mimeview == 0)
-	return hs;
-    mimeview->get("xallexcepts", hs, "");
-    return hs;
+	return res;
+
+    string base, plus, minus;
+    mimeview->get("xallexcepts", base, "");
+    LOGDEB1("RclConfig::getMimeViewerAllEx(): base: " << s << endl);
+    mimeview->get("xallexcepts+", plus, "");
+    LOGDEB1("RclConfig::getMimeViewerAllEx(): plus: " << plus << endl);
+    mimeview->get("xallexcepts-", minus, "");
+    LOGDEB1("RclConfig::getMimeViewerAllEx(): minus: " << minus << endl);
+
+    computeBasePlusMinus(res, base, plus, minus);
+    LOGDEB1("RclConfig::getMimeViewerAllEx(): res: " << stringsToString(res)
+           << endl);
+    return res;
 }
 
-bool RclConfig::setMimeViewerAllEx(const string& allex)
+bool RclConfig::setMimeViewerAllEx(const set<string>& allex)
 {
     if (mimeview == 0)
         return false;
-    if (!mimeview->set("xallexcepts", allex, "")) {
+
+    string s;
+    mimeview->get("xallexcepts", s, "");
+    set<string> base;
+    stringToStrings(s, base);
+
+    string splus, sminus;
+    setPlusMinus(base, allex, splus, sminus);
+
+    if (!mimeview->set("xallexcepts-", sminus, "")) {
+	m_reason = string("RclConfig:: cant set value. Readonly?");
+	return false;
+    }
+    if (!mimeview->set("xallexcepts+", splus, "")) {
 	m_reason = string("RclConfig:: cant set value. Readonly?");
 	return false;
     }
@@ -1029,22 +1120,19 @@ bool RclConfig::setMimeViewerAllEx(const string& allex)
 string RclConfig::getMimeViewerDef(const string &mtype, const string& apptag,
 				   bool useall) const
 {
-    LOGDEB2(("RclConfig::getMimeViewerDef: mtype [%s] apptag [%s]\n",
-	     mtype.c_str(), apptag.c_str()));
+    LOGDEB2("RclConfig::getMimeViewerDef: mtype [" << mtype << "] apptag ["
+            << apptag << "]\n");
     string hs;
     if (mimeview == 0)
 	return hs;
 
     if (useall) {
 	// Check for exception
-	string excepts = getMimeViewerAllEx();
-	vector<string> vex;
-	stringToTokens(excepts, vex);
+	set<string> allex = getMimeViewerAllEx();
 	bool isexcept = false;
-	for (vector<string>::iterator it = vex.begin();
-	     it != vex.end(); it++) {
+	for (auto& it : allex) {
 	    vector<string> mita;
-	    stringToTokens(*it, mita, "|");
+	    stringToTokens(it, mita, "|");
 	    if ((mita.size() == 1 && apptag.empty() && mita[0] == mtype) ||
 		(mita.size() == 2 && mita[1] == apptag && mita[0] == mtype)) {
 		// Exception to x-all
@@ -1214,19 +1302,19 @@ string RclConfig::getPidfile() const
 
 void RclConfig::urlrewrite(const string& dbdir, string& url) const
 {
-    LOGDEB2(("RclConfig::urlrewrite: dbdir [%s] url [%s]\n",
-	    dbdir.c_str(), url.c_str()));
+    LOGDEB2("RclConfig::urlrewrite: dbdir [" << dbdir << "] url [" << url <<
+            "]\n");
 
     // Do path translations exist for this index ?
     if (m_ptrans == 0 || !m_ptrans->hasSubKey(dbdir)) {
-	LOGDEB2(("RclConfig::urlrewrite: no paths translations (m_ptrans %p)\n",
-		m_ptrans));
+	LOGDEB2("RclConfig::urlrewrite: no paths translations (m_ptrans " <<
+                m_ptrans << ")\n");
 	return;
     }
 
     string path = fileurltolocalpath(url);
     if (path.empty()) {
-	LOGDEB2(("RclConfig::urlrewrite: not file url\n"));
+	LOGDEB2("RclConfig::urlrewrite: not file url\n");
 	return;
     }
 
@@ -1276,7 +1364,10 @@ string RclConfig::getWebQueueDir() const
 vector<string>& RclConfig::getSkippedNames()
 {
     if (m_skpnstate.needrecompute()) {
-	stringToStrings(m_skpnstate.savedvalue, m_skpnlist);
+        set<string> ss;
+        computeBasePlusMinus(ss, m_skpnstate.getvalue(0),
+                             m_skpnstate.getvalue(1), m_skpnstate.getvalue(2));
+        m_skpnlist = vector<string>(ss.begin(), ss.end());
     }
     return m_skpnlist;
 }
@@ -1385,7 +1476,7 @@ bool RclConfig::getUncompressor(const string &mtype, vector<string>& cmd) const
     vector<string> tokens;
     stringToStrings(hs, tokens);
     if (tokens.empty()) {
-	LOGERR(("getUncompressor: empty spec for mtype %s\n", mtype.c_str()));
+	LOGERR("getUncompressor: empty spec for mtype " << mtype << "\n");
 	return false;
     }
     vector<string>::iterator it = tokens.begin();
@@ -1403,7 +1494,8 @@ bool RclConfig::getUncompressor(const string &mtype, vector<string>& cmd) const
     if (!stringlowercmp("python", *it) || !stringlowercmp("perl", *it)) {
         it++;
         if (tokens.size() < 3) {
-            LOGERR(("getUncpressor: python/perl cmd: no script?. [%s]\n", mtype.c_str()));
+            LOGERR("getUncpressor: python/perl cmd: no script?. [" <<
+                   mtype << "]\n");
         } else {
             *it = findFilter(*it);
         }
@@ -1478,6 +1570,20 @@ bool RclConfig::initUserConfig()
     return true;
 }
 
+void RclConfig::zeroMe() {
+    m_ok = false; 
+    m_keydirgen = 0;
+    m_conf = 0; 
+    mimemap = 0; 
+    mimeconf = 0; 
+    mimeview = 0; 
+    m_fields = 0;
+    m_ptrans = 0;
+    m_stopsuffixes = 0;
+    m_maxsufflen = 0;
+    initParamStale(0, 0);
+}
+
 void RclConfig::freeAll() 
 {
     delete m_conf;
@@ -1496,12 +1602,30 @@ void RclConfig::initFrom(const RclConfig& r)
     zeroMe();
     if (!(m_ok = r.m_ok))
 	return;
+
+    // Copyable fields
+    m_ok = r.m_ok;
     m_reason = r.m_reason;
     m_confdir = r.m_confdir;
     m_cachedir = r.m_cachedir;
     m_datadir = r.m_datadir;
     m_keydir = r.m_keydir;
+    m_keydirgen = r.m_keydirgen;
     m_cdirs = r.m_cdirs;
+    m_fldtotraits = r.m_fldtotraits;
+    m_aliastocanon = r.m_aliastocanon;
+    m_aliastoqcanon = r.m_aliastoqcanon;
+    m_storedFields = r.m_storedFields;
+    m_xattrtofld = r.m_xattrtofld;
+    m_maxsufflen = r.m_maxsufflen;
+    m_skpnlist = r.m_skpnlist;
+    m_defcharset = r.m_defcharset;
+    m_restrictMTypes  = r.m_restrictMTypes;
+    m_excludeMTypes = r.m_excludeMTypes;
+    m_thrConf = r.m_thrConf;
+    m_mdreapers = r.m_mdreapers;
+
+    // Special treatment
     if (r.m_conf)
 	m_conf = new ConfStack<ConfTree>(*(r.m_conf));
     if (r.mimemap)
@@ -1514,19 +1638,9 @@ void RclConfig::initFrom(const RclConfig& r)
 	m_fields = new ConfStack<ConfSimple>(*(r.m_fields));
     if (r.m_ptrans)
 	m_ptrans = new ConfSimple(*(r.m_ptrans));
-    m_fldtotraits = r.m_fldtotraits;
-    m_aliastocanon = r.m_aliastocanon;
-    m_aliastoqcanon = r.m_aliastoqcanon;
-    m_storedFields = r.m_storedFields;
-    m_xattrtofld = r.m_xattrtofld;
     if (r.m_stopsuffixes)
 	m_stopsuffixes = new SuffixStore(*((SuffixStore*)r.m_stopsuffixes));
-    m_maxsufflen = r.m_maxsufflen;
-    m_defcharset = r.m_defcharset;
-
     initParamStale(m_conf, mimemap);
-
-    m_thrConf = r.m_thrConf;
 }
 
 void RclConfig::initParamStale(ConfNull *cnf, ConfNull *mimemap)
@@ -1550,7 +1664,8 @@ void RclConfig::initParamStale(ConfNull *cnf, ConfNull *mimemap)
 
 using namespace std;
 
-#include "debuglog.h"
+#include "log.h"
+
 #include "rclinit.h"
 #include "rclconfig.h"
 #include "cstr.h"
@@ -1725,3 +1840,4 @@ int main(int argc, char **argv)
 }
 
 #endif // TEST_RCLCONFIG
+
