@@ -17,16 +17,18 @@
 #include "autoconfig.h"
 
 
-#include "debuglog.h"
+#include "log.h"
+#include "rclconfig.h"
 
 #include "fetcher.h"
 #include "fsfetcher.h"
 #include "bglfetcher.h"
+#include "exefetcher.h"
 
-DocFetcher *docFetcherMake(const Rcl::Doc& idoc)
+DocFetcher *docFetcherMake(RclConfig *config, const Rcl::Doc& idoc)
 {
     if (idoc.url.empty()) {
-        LOGERR(("docFetcherMakeg:: no url in doc!\n"));
+        LOGERR("docFetcherMakeg:: no url in doc!\n" );
         return 0;
     }
     string backend;
@@ -38,7 +40,11 @@ DocFetcher *docFetcherMake(const Rcl::Doc& idoc)
 	return new BGLDocFetcher;
 #endif
     } else {
-	LOGERR(("DocFetcherFactory: unknown backend [%s]\n", backend.c_str()));
-	return 0;
+        DocFetcher *f = exeDocFetcherMake(config, backend);
+        if (!f) {
+            LOGERR("DocFetcherFactory: unknown backend ["  << (backend) << "]\n" );
+        }
+	return f;
     }
 }
+
