@@ -22,7 +22,8 @@
 #include <algorithm>
 
 #include "cstr.h"
-#include "debuglog.h"
+#include "log.h"
+#include "recollindex.h"
 #include "indexer.h"
 #include "fsindexer.h"
 #ifndef DISABLE_WEB_INDEXER
@@ -60,13 +61,13 @@ bool ConfIndexer::runFirstIndexing()
 {
     // Indexing status file existing and not empty ?
     if (path_filesize(m_config->getIdxStatusFile()) > 0) {
-	LOGDEB0(("ConfIndexer::runFirstIndexing: no: status file not empty\n"));
+	LOGDEB0("ConfIndexer::runFirstIndexing: no: status file not empty\n");
 	return false;
     }
     // And only do this if the user has kept the default topdirs (~). 
     vector<string> tdl = m_config->getTopdirs();
     if (tdl.size() != 1 || tdl[0].compare(path_canon(path_tildexpand("~")))) {
-	LOGDEB0(("ConfIndexer::runFirstIndexing: no: not home only\n"));
+	LOGDEB0("ConfIndexer::runFirstIndexing: no: not home only\n");
 	return false;
     }
     return true;
@@ -74,7 +75,7 @@ bool ConfIndexer::runFirstIndexing()
 
 bool ConfIndexer::firstFsIndexingSequence()
 {
-    LOGDEB(("ConfIndexer::firstFsIndexingSequence\n"));
+    LOGDEB("ConfIndexer::firstFsIndexingSequence\n");
     deleteZ(m_fsindexer);
     m_fsindexer = new FsIndexer(m_config, &m_db, m_updater);
     if (!m_fsindexer) {
@@ -92,8 +93,9 @@ bool ConfIndexer::index(bool resetbefore, ixType typestorun, int flags)
 {
     Rcl::Db::OpenMode mode = resetbefore ? Rcl::Db::DbTrunc : Rcl::Db::DbUpd;
     if (!m_db.open(mode)) {
-	LOGERR(("ConfIndexer: error opening database %s : %s\n", 
-                m_config->getDbDir().c_str(), m_db.getReason().c_str()));
+	LOGERR("ConfIndexer: error opening database " << m_config->getDbDir() <<
+               " : " << m_db.getReason() << "\n");
+        addIdxReason("indexer", m_db.getReason());
 	return false;
     }
 
@@ -105,6 +107,7 @@ bool ConfIndexer::index(bool resetbefore, ixType typestorun, int flags)
         deleteZ(m_fsindexer);
         m_fsindexer = new FsIndexer(m_config, &m_db, m_updater);
         if (!m_fsindexer || !m_fsindexer->index(flags)) {
+            addIdxReason("indexer", "Index creation failed. See log");
 	    m_db.close();
             return false;
         }
@@ -115,6 +118,7 @@ bool ConfIndexer::index(bool resetbefore, ixType typestorun, int flags)
         m_beagler = new BeagleQueueIndexer(m_config, &m_db, m_updater);
         if (!m_beagler || !m_beagler->index()) {
 	    m_db.close();
+            addIdxReason("indexer", "Web index creation failed. See log");
             return false;
         }
     }
@@ -124,6 +128,7 @@ bool ConfIndexer::index(bool resetbefore, ixType typestorun, int flags)
         // filesystem anymore. Only if all *configured* indexers ran.
         if (m_updater && !m_updater->update(DbIxStatus::DBIXS_PURGE, string())) {
 	    m_db.close();
+            addIdxReason("indexer", "Index purge failed. See log");
 	    return false;
 	}
         m_db.purge();
@@ -135,21 +140,29 @@ bool ConfIndexer::index(bool resetbefore, ixType typestorun, int flags)
     if (m_updater)
 	m_updater->update(DbIxStatus::DBIXS_CLOSING, string());
     if (!m_db.close()) {
-	LOGERR(("ConfIndexer::index: error closing database in %s\n", 
-		m_config->getDbDir().c_str()));
+	LOGERR("ConfIndexer::index: error closing database in " <<
+               m_config->getDbDir() << "\n");
+        addIdxReason("indexer", "Index close/flush failed. See log");
 	return false;
     }
 
     if (m_updater && !m_updater->update(DbIxStatus::DBIXS_CLOSING, string()))
 	return false;
-    createStemmingDatabases();
+    bool ret = true;
+    if (!createStemmingDatabases()) {
+	ret = false;
+    }
     if (m_updater && !m_updater->update(DbIxStatus::DBIXS_CLOSING, string()))
 	return false;
-    createAspellDict();
+
+    // Don't fail indexing because of an aspell issue: we ignore the status.
+    // Messages were written to the reasons output
+    (void)createAspellDict();
+    
     clearMimeHandlerCache();
     if (m_updater)
 	m_updater->update(DbIxStatus::DBIXS_DONE, string());
-    return true;
+    return ret;
 }
 
 bool ConfIndexer::indexFiles(list<string>& ifiles, int flag)
@@ -163,8 +176,8 @@ bool ConfIndexer::indexFiles(list<string>& ifiles, int flag)
     myfiles.sort();
 
     if (!m_db.open(Rcl::Db::DbUpd)) {
-	LOGERR(("ConfIndexer: indexFiles error opening database %s\n", 
-                m_config->getDbDir().c_str()));
+	LOGERR("ConfIndexer: indexFiles error opening database " <<
+               m_config->getDbDir() << "\n");
 	return false;
     }
     m_config->setKeyDir(cstr_null);
@@ -173,8 +186,8 @@ bool ConfIndexer::indexFiles(list<string>& ifiles, int flag)
         m_fsindexer = new FsIndexer(m_config, &m_db, m_updater);
     if (m_fsindexer)
         ret = m_fsindexer->indexFiles(myfiles, flag);
-    LOGDEB2(("ConfIndexer::indexFiles: fsindexer returned %d, "
-            "%d files remainining\n", ret, myfiles.size()));
+    LOGDEB2("ConfIndexer::indexFiles: fsindexer returned " << ret << ", " <<
+            myfiles.size() << " files remainining\n");
 #ifndef DISABLE_WEB_INDEXER
 
     if (m_dobeagle && !myfiles.empty() && !(flag & IxFNoWeb)) {
@@ -189,8 +202,8 @@ bool ConfIndexer::indexFiles(list<string>& ifiles, int flag)
 #endif
     // The close would be done in our destructor, but we want status here
     if (!m_db.close()) {
-	LOGERR(("ConfIndexer::index: error closing database in %s\n", 
-		m_config->getDbDir().c_str()));
+	LOGERR("ConfIndexer::index: error closing database in " <<
+               m_config->getDbDir() << "\n");
 	return false;
     }
     ifiles = myfiles;
@@ -198,31 +211,6 @@ bool ConfIndexer::indexFiles(list<string>& ifiles, int flag)
     return ret;
 }
 
-bool ConfIndexer::docsToPaths(vector<Rcl::Doc> &docs, vector<string> &paths)
-{
-    for (vector<Rcl::Doc>::iterator it = docs.begin(); it != docs.end(); it++) {
-	Rcl::Doc &idoc = *it;
-	string backend;
-	idoc.getmeta(Rcl::Doc::keybcknd, &backend);
-
-	// This only makes sense for file system files: beagle docs are
-	// always up to date because they can't be updated in the cache,
-	// only added/removed. Same remark as made inside internfile, we
-	// need a generic way to handle backends.
-	if (!backend.empty() && backend.compare("FS"))
-	    continue;
-
-	// Filesystem document. The url has to be like file://
-	if (idoc.url.find(cstr_fileu) != 0) {
-	    LOGERR(("idx::docsToPaths: FS backend and non fs url: [%s]\n",
-		    idoc.url.c_str()));
-	    continue;
-	}
-	paths.push_back(idoc.url.substr(7, string::npos));
-    }
-    return true;
-}
-
 // Update index for specific documents. The docs come from an index
 // query, so the udi, backend etc. fields are filled.
 bool ConfIndexer::updateDocs(std::vector<Rcl::Doc> &docs, IxFlag flag)
@@ -247,8 +235,8 @@ bool ConfIndexer::purgeFiles(std::list<string> &files, int flag)
     myfiles.sort();
 
     if (!m_db.open(Rcl::Db::DbUpd)) {
-	LOGERR(("ConfIndexer: purgeFiles error opening database %s\n", 
-                m_config->getDbDir().c_str()));
+	LOGERR("ConfIndexer: purgeFiles error opening database " <<
+               m_config->getDbDir() << "\n");
 	return false;
     }
     bool ret = false;
@@ -272,8 +260,8 @@ bool ConfIndexer::purgeFiles(std::list<string> &files, int flag)
 
     // The close would be done in our destructor, but we want status here
     if (!m_db.close()) {
-	LOGERR(("ConfIndexer::purgefiles: error closing database in %s\n", 
-		m_config->getDbDir().c_str()));
+	LOGERR("ConfIndexer::purgefiles: error closing database in " <<
+               m_config->getDbDir() << "\n");
 	return false;
     }
     return ret;
@@ -284,9 +272,11 @@ bool ConfIndexer::purgeFiles(std::list<string> &files, int flag)
 bool ConfIndexer::createStemmingDatabases()
 {
     string slangs;
+    bool ret = true;
     if (m_config->getConfParam("indexstemminglanguages", slangs)) {
         if (!m_db.open(Rcl::Db::DbUpd)) {
-            LOGERR(("ConfIndexer::createStemmingDb: could not open db\n"))
+            LOGERR("ConfIndexer::createStemmingDb: could not open db\n");
+            addIdxReason("stemming", "could not open db");
             return false;
         }
 	vector<string> langs;
@@ -300,10 +290,13 @@ bool ConfIndexer::createStemmingDatabases()
 	    if (find(langs.begin(), langs.end(), *it) == langs.end())
 		m_db.deleteStemDb(*it);
 	}
-	m_db.createStemDbs(langs);
+	ret = ret && m_db.createStemDbs(langs);
+        if (!ret) {
+            addIdxReason("stemming", "stem db creation failed");
+        }
     }
     m_db.close();
-    return true;
+    return ret;
 }
 
 bool ConfIndexer::createStemDb(const string &lang)
@@ -319,7 +312,7 @@ bool ConfIndexer::createStemDb(const string &lang)
 // module, either from a configuration variable or the NLS environment.
 bool ConfIndexer::createAspellDict()
 {
-    LOGDEB2(("ConfIndexer::createAspellDict()\n"));
+    LOGDEB2("ConfIndexer::createAspellDict()\n");
 #ifdef RCL_USE_ASPELL
     // For the benefit of the real-time indexer, we only initialize
     // noaspell from the configuration once. It can then be set to
@@ -334,22 +327,23 @@ bool ConfIndexer::createAspellDict()
 	return true;
 
     if (!m_db.open(Rcl::Db::DbRO)) {
-        LOGERR(("ConfIndexer::createAspellDict: could not open db\n"));
+        LOGERR("ConfIndexer::createAspellDict: could not open db\n");
 	return false;
     }
 
     Aspell aspell(m_config);
     string reason;
     if (!aspell.init(reason)) {
-	LOGERR(("ConfIndexer::createAspellDict: aspell init failed: %s\n", 
-		reason.c_str()));
+	LOGERR("ConfIndexer::createAspellDict: aspell init failed: " <<
+               reason << "\n");
 	noaspell = true;
 	return false;
     }
-    LOGDEB(("ConfIndexer::createAspellDict: creating dictionary\n"));
+    LOGDEB("ConfIndexer::createAspellDict: creating dictionary\n");
     if (!aspell.buildDict(m_db, reason)) {
-	LOGERR(("ConfIndexer::createAspellDict: aspell buildDict failed: %s\n", 
-		reason.c_str()));
+	LOGERR("ConfIndexer::createAspellDict: aspell buildDict failed: " <<
+               reason << "\n");
+        addIdxReason("aspell", reason);
 	noaspell = true;
 	return false;
     }
@@ -361,3 +355,4 @@ vector<string> ConfIndexer::getStemmerNames()
 {
     return Rcl::Db::getStemmerNames();
 }
+
