@@ -24,7 +24,7 @@
 #include "safesysstat.h"
 #include "safeunistd.h"
 
-#include "debuglog.h"
+#include "log.h"
 #include "rclmon.h"
 #include "rclinit.h"
 #include "fstreewalk.h"
@@ -76,15 +76,13 @@ public:
         FsTreeWalker& walker)
 	: m_config(conf), m_mon(mon), m_queue(queue), m_walker(walker)
     {}
-    virtual ~WalkCB() 
-    {}
+    virtual ~WalkCB() {}
 
     virtual FsTreeWalker::Status 
     processone(const string &fn, const struct stat *st, 
-               FsTreeWalker::CbFlag flg)
-    {
-	MONDEB(("rclMonRcvRun: processone %s m_mon %p m_mon->ok %d\n", 
-		 fn.c_str(), m_mon, m_mon?m_mon->ok():0));
+               FsTreeWalker::CbFlag flg) {
+	MONDEB("rclMonRcvRun: processone " << fn <<  " m_mon " << m_mon <<
+               " m_mon->ok " << (m_mon ? m_mon->ok() : false) << std::endl);
 
         if (flg == FsTreeWalker::FtwDirEnter || 
             flg == FsTreeWalker::FtwDirReturn) {
@@ -102,7 +100,7 @@ public:
 		    if (ev.m_etyp !=  RclMonEvent::RCLEVT_NONE)
 			m_queue->pushEvent(ev);
 		} else {
-		    MONDEB(("rclMonRcvRun: no event pending\n"));
+		    MONDEB("rclMonRcvRun: no event pending\n");
 		    break;
 		}
 	    }
@@ -143,41 +141,31 @@ private:
     FsTreeWalker&      m_walker;
 };
 
-/** Main thread routine: create watches, then forever wait for and queue events */
+// Main thread routine: create watches, then forever wait for and queue events
 void *rclMonRcvRun(void *q)
 {
     RclMonEventQueue *queue = (RclMonEventQueue *)q;
 
-    LOGDEB(("rclMonRcvRun: running\n"));
+    LOGDEB("rclMonRcvRun: running\n");
     recoll_threadinit();
     // Make a local copy of the configuration as it doesn't like
     // concurrent accesses. It's ok to copy it here as the other
     // thread will not work before we have sent events.
     RclConfig lconfig(*queue->getConfig());
 
-    string loglevel;
-    lconfig.getConfParam(string("daemloglevel"), loglevel);
-    if (loglevel.empty())
-	lconfig.getConfParam(string("loglevel"), loglevel);
-    if (!loglevel.empty()) {
-	int lev = atoi(loglevel.c_str());
-	DebugLog::getdbl()->setloglevel(lev);
-    }
-
     // Create the fam/whatever interface object
     RclMonitor *mon;
     if ((mon = makeMonitor()) == 0) {
-	LOGERR(("rclMonRcvRun: makeMonitor failed\n"));
+	LOGERR("rclMonRcvRun: makeMonitor failed\n");
 	queue->setTerminate();
 	return 0;
     }
 
-
     // Get top directories from config 
     vector<string> tdl = lconfig.getTopdirs();
     if (tdl.empty()) {
-	LOGERR(("rclMonRcvRun:: top directory list (topdirs param.) not"
-		"found in config or Directory list parse error"));
+	LOGERR("rclMonRcvRun:: top directory list (topdirs param.) not found "
+               "in configuration or topdirs list parse error");
 	queue->setTerminate();
 	return 0;
     }
@@ -186,7 +174,7 @@ void *rclMonRcvRun(void *q)
     FsTreeWalker walker;
     walker.setSkippedPaths(lconfig.getDaemSkippedPaths());
     WalkCB walkcb(&lconfig, mon, queue, walker);
-    for (vector<string>::iterator it = tdl.begin(); it != tdl.end(); it++) {
+    for (auto it = tdl.begin(); it != tdl.end(); it++) {
 	lconfig.setKeyDir(*it);
 	// Adjust the follow symlinks options
 	bool follow;
@@ -196,15 +184,29 @@ void *rclMonRcvRun(void *q)
 	} else {
 	    walker.setOpts(FsTreeWalker::FtwOptNone);
 	}
-	LOGDEB(("rclMonRcvRun: walking %s\n", it->c_str()));
-	if (walker.walk(*it, walkcb) != FsTreeWalker::FtwOk) {
-	    LOGERR(("rclMonRcvRun: tree walk failed\n"));
-	    goto terminate;
-	}
-	if (walker.getErrCnt() > 0) {
-	    LOGINFO(("rclMonRcvRun: fs walker errors: %s\n", 
-		     walker.getReason().c_str()));
-	}
+        // We have to special-case regular files which are part of the topdirs
+        // list because we the tree walker only adds watches for directories
+        struct stat st;
+        if (path_fileprops(*it, &st, follow) != 0) {
+            LOGERR("rclMonRcvRun: stat failed for "  << *it << "\n");
+            continue;
+        }
+        if (S_ISDIR(st.st_mode)) {
+            LOGDEB("rclMonRcvRun: walking "  << *it << "\n");
+            if (walker.walk(*it, walkcb) != FsTreeWalker::FtwOk) {
+                LOGERR("rclMonRcvRun: tree walk failed\n");
+                goto terminate;
+            }
+            if (walker.getErrCnt() > 0) {
+                LOGINFO("rclMonRcvRun: fs walker errors: " <<
+                        walker.getReason() << "\n");
+            }
+        } else {
+            if (!mon->addWatch(*it, false)) {
+                LOGERR("rclMonRcvRun: addWatch failed for " << *it <<
+                       " errno " << mon->saved_errno << std::endl);
+	    }
+        }
     }
 
     {
@@ -213,7 +215,7 @@ void *rclMonRcvRun(void *q)
 	if (doweb) {
 	    string webqueuedir = lconfig.getWebQueueDir();
 	    if (!mon->addWatch(webqueuedir, true)) {
-		LOGERR(("rclMonRcvRun: addwatch (webqueuedir) failed\n"));
+		LOGERR("rclMonRcvRun: addwatch (webqueuedir) failed\n");
 		if (mon->saved_errno != EACCES && mon->saved_errno != ENOENT)
 		    goto terminate;
 	    }
@@ -221,7 +223,8 @@ void *rclMonRcvRun(void *q)
     }
 
     // Forever wait for monitoring events and add them to queue:
-    MONDEB(("rclMonRcvRun: waiting for events. q->ok() %d\n", queue->ok()));
+    MONDEB("rclMonRcvRun: waiting for events. q->ok(): " << queue->ok() <<
+           std::endl);
     while (queue->ok() && mon->ok()) {
 	RclMonEvent ev;
 	// Note: I could find no way to get the select
@@ -249,16 +252,15 @@ void *rclMonRcvRun(void *q)
 		// it seems that fam/gamin is doing the job for us so
 		// that we are generating double events here (no big
 		// deal as prc will sort/merge).
-		LOGDEB(("rclMonRcvRun: walking new dir %s\n", 
-			ev.m_path.c_str()));
+		LOGDEB("rclMonRcvRun: walking new dir " << ev.m_path << "\n");
 		if (walker.walk(ev.m_path, walkcb) != FsTreeWalker::FtwOk) {
-		    LOGERR(("rclMonRcvRun: walking new dir %s: %s\n", 
-			    ev.m_path.c_str(), walker.getReason().c_str()));
+		    LOGERR("rclMonRcvRun: walking new dir " << ev.m_path <<
+                           " : "  << walker.getReason() << "\n");
 		    goto terminate;
 		}
 		if (walker.getErrCnt() > 0) {
-		    LOGINFO(("rclMonRcvRun: fs walker errors: %s\n", 
-			     walker.getReason().c_str()));
+		    LOGINFO("rclMonRcvRun: fs walker errors: " <<
+                            walker.getReason() << "\n");
 		}
 	    }
 
@@ -269,7 +271,7 @@ void *rclMonRcvRun(void *q)
 
 terminate:
     queue->setTerminate();
-    LOGINFO(("rclMonRcvRun: monrcv thread routine returning\n"));
+    LOGINFO("rclMonRcvRun: monrcv thread routine returning\n");
     return 0;
 }
 
@@ -278,7 +280,7 @@ terminate:
 bool eraseWatchSubTree(map<int, string>& idtopath, const string& top)
 {
     bool found = false;
-    MONDEB(("Clearing map for [%s]\n", top.c_str()));
+    MONDEB("Clearing map for [" << top << "]\n");
     map<int,string>::iterator it = idtopath.begin();
     while (it != idtopath.end()) {
 	if (it->second.find(top) == 0) {
@@ -353,7 +355,7 @@ RclFAM::RclFAM()
     : m_ok(false)
 {
     if (FAMOpen2(&m_conn, "Recoll")) {
-	LOGERR(("RclFAM::RclFAM: FAMOpen2 failed, errno %d\n", errno));
+	LOGERR("RclFAM::RclFAM: FAMOpen2 failed, errno " << errno << "\n");
 	return;
     }
     m_ok = true;
@@ -376,7 +378,7 @@ bool RclFAM::addWatch(const string& path, bool isdir)
 	return false;
     bool ret = false;
 
-    MONDEB(("RclFAM::addWatch: adding %s\n", path.c_str()));
+    MONDEB("RclFAM::addWatch: adding " << path << std::endl);
 
     // It happens that the following call block forever. 
     // We'd like to be able to at least terminate on a signal here, but
@@ -384,7 +386,7 @@ bool RclFAM::addWatch(const string& path, bool isdir)
     // to unblock signals. SIGALRM is not used by the main thread, so at least
     // ensure that we exit after gamin gets stuck.
     if (setjmp(jbuf)) {
-	LOGERR(("RclFAM::addWatch: timeout talking to FAM\n"));
+	LOGERR("RclFAM::addWatch: timeout talking to FAM\n");
 	return false;
     }
     signal(SIGALRM, onalrm);
@@ -392,12 +394,12 @@ bool RclFAM::addWatch(const string& path, bool isdir)
     FAMRequest req;
     if (isdir) {
 	if (FAMMonitorDirectory(&m_conn, path.c_str(), &req, 0) != 0) {
-	    LOGERR(("RclFAM::addWatch: FAMMonitorDirectory failed\n"));
+	    LOGERR("RclFAM::addWatch: FAMMonitorDirectory failed\n");
 	    goto out;
 	}
     } else {
 	if (FAMMonitorFile(&m_conn, path.c_str(), &req, 0) != 0) {
-	    LOGERR(("RclFAM::addWatch: FAMMonitorFile failed\n"));
+	    LOGERR("RclFAM::addWatch: FAMMonitorFile failed\n");
 	    goto out;
 	}
     }
@@ -415,14 +417,14 @@ bool RclFAM::getEvent(RclMonEvent& ev, int msecs)
 {
     if (!ok())
 	return false;
-    MONDEB(("RclFAM::getEvent:\n"));
+    MONDEB("RclFAM::getEvent:\n");
 
     fd_set readfds;
     int fam_fd = FAMCONNECTION_GETFD(&m_conn);
     FD_ZERO(&readfds);
     FD_SET(fam_fd, &readfds);
 
-    MONDEB(("RclFAM::getEvent: select. fam_fd is %d\n", fam_fd));
+    MONDEB("RclFAM::getEvent: select. fam_fd is " << fam_fd << std::endl);
     // Fam / gamin is sometimes a bit slow to send events. Always add
     // a little timeout, because if we fail to retrieve enough events,
     // we risk deadlocking in addwatch()
@@ -435,16 +437,16 @@ bool RclFAM::getEvent(RclMonEvent& ev, int msecs)
     }
     int ret;
     if ((ret=select(fam_fd+1, &readfds, 0, 0, msecs >= 0 ? &timeout : 0)) < 0) {
-	LOGERR(("RclFAM::getEvent: select failed, errno %d\n", errno));
+	LOGERR("RclFAM::getEvent: select failed, errno " << errno << "\n");
 	close();
 	return false;
     } else if (ret == 0) {
 	// timeout
-	MONDEB(("RclFAM::getEvent: select timeout\n"));
+	MONDEB("RclFAM::getEvent: select timeout\n");
 	return false;
     }
 
-    MONDEB(("RclFAM::getEvent: select returned %d\n", ret));
+    MONDEB("RclFAM::getEvent: select returned " << ret << std::endl);
 
     if (!FD_ISSET(fam_fd, &readfds))
 	return false;
@@ -455,18 +457,18 @@ bool RclFAM::getEvent(RclMonEvent& ev, int msecs)
     // around the issue, but we did not need this in the past and this
     // is most weird.
     if (FAMPending(&m_conn) <= 0) {
-	MONDEB(("RclFAM::getEvent: FAMPending says no events\n"));
+	MONDEB("RclFAM::getEvent: FAMPending says no events\n");
 	return false;
     }
 
-    MONDEB(("RclFAM::getEvent: call FAMNextEvent\n"));
+    MONDEB("RclFAM::getEvent: call FAMNextEvent\n");
     FAMEvent fe;
     if (FAMNextEvent(&m_conn, &fe) < 0) {
-	LOGERR(("RclFAM::getEvent: FAMNextEvent failed, errno %d\n", errno));
+	LOGERR("RclFAM::getEvent: FAMNextEvent: errno " << errno << "\n");
 	close();
 	return false;
     }
-    MONDEB(("RclFAM::getEvent: FAMNextEvent returned\n"));
+    MONDEB("RclFAM::getEvent: FAMNextEvent returned\n");
     
     map<int,string>::const_iterator it;
     if ((!path_isabsolute(fe.filename)) && 
@@ -476,8 +478,8 @@ bool RclFAM::getEvent(RclMonEvent& ev, int msecs)
 	ev.m_path = fe.filename;
     }
 
-    MONDEB(("RclFAM::getEvent: %-12s %s\n", 
-	    event_name(fe.code), ev.m_path.c_str()));
+    MONDEB("RclFAM::getEvent: " << event_name(fe.code) < " " <<
+           ev.m_path << std::endl);
 
     switch (fe.code) {
     case FAMCreated:
@@ -511,7 +513,7 @@ bool RclFAM::getEvent(RclMonEvent& ev, int msecs)
 	// Have to return something, this is different from an empty queue,
 	// esp if we are trying to empty it...
 	if (fe.code != FAMEndExist)
-	    LOGDEB(("RclFAM::getEvent: got other event %d!\n", fe.code));
+	    LOGDEB("RclFAM::getEvent: got other event " << fe.code << "!\n");
 	ev.m_etyp = RclMonEvent::RCLEVT_NONE;
 	break;
     }
@@ -532,7 +534,7 @@ public:
 	: m_ok(false), m_fd(-1), m_evp(0), m_ep(0)
     {
 	if ((m_fd = inotify_init()) < 0) {
-	    LOGERR(("RclIntf:: inotify_init failed, errno %d\n", errno));
+	    LOGERR("RclIntf:: inotify_init failed, errno " << errno << "\n");
 	    return;
 	}
 	m_ok = true;
@@ -598,7 +600,7 @@ bool RclIntf::addWatch(const string& path, bool)
 {
    if (!ok())
        return false;
-   MONDEB(("RclIntf::addWatch: adding %s\n", path.c_str()));
+   MONDEB("RclIntf::addWatch: adding " << path << std::endl);
     // CLOSE_WRITE is covered through MODIFY. CREATE is needed for mkdirs
     uint32_t mask = IN_MODIFY | IN_CREATE
         | IN_MOVED_FROM | IN_MOVED_TO | IN_DELETE
@@ -616,11 +618,11 @@ bool RclIntf::addWatch(const string& path, bool)
     int wd;
     if ((wd = inotify_add_watch(m_fd, path.c_str(), mask)) < 0) {
 	saved_errno = errno;
-        LOGERR(("RclIntf::addWatch: inotify_add_watch failed. errno %d\n",
-		   saved_errno));
+        LOGERR("RclIntf::addWatch: inotify_add_watch failed. errno " <<
+               saved_errno << "\n");
         if (errno == ENOSPC) {
-            LOGERR(("RclIntf::addWatch: ENOSPC error may mean that you need"
-                    "increase the inotify kernel constants. See inotify(7)\n"));
+            LOGERR("RclIntf::addWatch: ENOSPC error may mean that you should "
+                   "increase the inotify kernel constants. See inotify(7)\n");
         }
 	return false;
     }
@@ -635,7 +637,7 @@ bool RclIntf::getEvent(RclMonEvent& ev, int msecs)
     if (!ok())
 	return false;
     ev.m_etyp = RclMonEvent::RCLEVT_NONE;
-    MONDEB(("RclIntf::getEvent:\n"));
+    MONDEB("RclIntf::getEvent:\n");
 
     if (m_evp == 0) {
 	fd_set readfds;
@@ -647,24 +649,25 @@ bool RclIntf::getEvent(RclMonEvent& ev, int msecs)
 	    timeout.tv_usec = (msecs % 1000) * 1000;
 	}
 	int ret;
-	MONDEB(("RclIntf::getEvent: select\n"));
-	if ((ret=select(m_fd + 1, &readfds, 0, 0, msecs >= 0 ? &timeout : 0)) < 0) {
-	    LOGERR(("RclIntf::getEvent: select failed, errno %d\n", errno));
+	MONDEB("RclIntf::getEvent: select\n");
+	if ((ret = select(m_fd + 1, &readfds, 0, 0, msecs >= 0 ? &timeout : 0))
+            < 0) {
+	    LOGERR("RclIntf::getEvent: select failed, errno " << errno << "\n");
 	    close();
 	    return false;
 	} else if (ret == 0) {
-	    MONDEB(("RclIntf::getEvent: select timeout\n"));
+	    MONDEB("RclIntf::getEvent: select timeout\n");
 	    // timeout
 	    return false;
 	}
-	MONDEB(("RclIntf::getEvent: select returned\n"));
+	MONDEB("RclIntf::getEvent: select returned\n");
 
 	if (!FD_ISSET(m_fd, &readfds))
 	    return false;
 	int rret;
 	if ((rret=read(m_fd, m_evbuf, sizeof(m_evbuf))) <= 0) {
-	    LOGERR(("RclIntf::getEvent: read failed, %d->%d errno %d\n", 
-		    sizeof(m_evbuf), rret, errno));
+	    LOGERR("RclIntf::getEvent: read failed, "  << sizeof(m_evbuf) <<
+                   "->"  << rret << " errno "  << errno << "\n");
 	    close();
 	    return false;
 	}
@@ -681,7 +684,7 @@ bool RclIntf::getEvent(RclMonEvent& ev, int msecs)
     
     map<int,string>::const_iterator it;
     if ((it = m_idtopath.find(evp->wd)) == m_idtopath.end()) {
-	LOGERR(("RclIntf::getEvent: unknown wd %d\n", evp->wd));
+	LOGERR("RclIntf::getEvent: unknown wd " << evp->wd << "\n");
 	return true;
     }
     ev.m_path = it->second;
@@ -690,8 +693,8 @@ bool RclIntf::getEvent(RclMonEvent& ev, int msecs)
 	ev.m_path = path_cat(ev.m_path, evp->name);
     }
 
-    MONDEB(("RclIntf::getEvent: %-12s %s\n", 
-	    event_name(evp->mask), ev.m_path.c_str()));
+    MONDEB("RclIntf::getEvent: " << event_name(evp->mask) << " " <<
+           ev.m_path << std::endl);
 
     if ((evp->mask & IN_MOVED_FROM) && (evp->mask & IN_ISDIR)) {
 	// We get this when a directory is renamed. Erase the subtree
@@ -721,13 +724,13 @@ bool RclIntf::getEvent(RclMonEvent& ev, int msecs)
 	}
     } else if (evp->mask & (IN_IGNORED)) {
 	if (!m_idtopath.erase(evp->wd)) {
-	    LOGDEB0(("Got IGNORE event for unknown watch\n"));
+	    LOGDEB0("Got IGNORE event for unknown watch\n");
 	} else {
 	    eraseWatchSubTree(m_idtopath, ev.m_path);
 	}
     } else {
-	LOGDEB(("RclIntf::getEvent: unhandled event %s 0x%x %s\n", 
-		event_name(evp->mask), evp->mask, ev.m_path.c_str()));
+	LOGDEB("RclIntf::getEvent: unhandled event " << event_name(evp->mask) <<
+               " " << evp->mask << " " << ev.m_path << "\n");
 	return true;
     }
     return true;
@@ -748,8 +751,9 @@ static RclMonitor *makeMonitor()
     return new RclFAM;
 #endif
 #endif
-    LOGINFO(("RclMonitor: neither Inotify nor Fam was compiled as "
-             "file system change notification interface\n"));
+    LOGINFO("RclMonitor: neither Inotify nor Fam was compiled as file system "
+            "change notification interface\n");
     return 0;
 }
 #endif // RCL_MONITOR
+
