@@ -36,7 +36,7 @@
 
 using namespace std;
 
-#include "debuglog.h"
+#include "log.h"
 #include "rclinit.h"
 #include "indexer.h"
 #include "smallut.h"
@@ -61,27 +61,28 @@ using namespace std;
 // Command line options
 static int     op_flags;
 #define OPT_MOINS 0x1
-#define OPT_z     0x2 
-#define OPT_h     0x4 
-#define OPT_i     0x8
-#define OPT_s     0x10
-#define OPT_c     0x20
-#define OPT_S     0x40
-#define OPT_m     0x80
-#define OPT_D     0x100
-#define OPT_e     0x200
-#define OPT_w     0x400
-#define OPT_x     0x800
-#define OPT_l     0x1000
-#define OPT_b     0x2000
-#define OPT_f     0x4000
-#define OPT_C     0x8000
-#define OPT_Z     0x10000
-#define OPT_n     0x20000
-#define OPT_r     0x40000
-#define OPT_k     0x80000
-#define OPT_E     0x100000
-#define OPT_K     0x200000
+#define OPT_C    0x2     
+#define OPT_D    0x4     
+#define OPT_E    0x8     
+#define OPT_K    0x10    
+#define OPT_R    0x20    
+#define OPT_S    0x40    
+#define OPT_Z    0x80    
+#define OPT_b    0x100   
+#define OPT_c    0x200   
+#define OPT_e    0x400   
+#define OPT_f    0x800   
+#define OPT_h    0x1000  
+#define OPT_i    0x2000  
+#define OPT_k    0x4000  
+#define OPT_l    0x8000  
+#define OPT_m    0x10000 
+#define OPT_n    0x20000 
+#define OPT_r    0x40000 
+#define OPT_s    0x80000 
+#define OPT_w    0x100000
+#define OPT_x    0x200000
+#define OPT_z    0x400000
 ReExec *o_reexec;
 
 // Globals for atexit cleanup
@@ -149,7 +150,7 @@ class MyUpdater : public DbIxStatusUpdater {
 	// out and the indexing would go on, not good (ie: if the user
 	// logs in again, the new recollindex will fail).
 	if ((op_flags & OPT_m) && !(op_flags & OPT_x) && !x11IsAlive()) {
-	    LOGDEB(("X11 session went away during initial indexing pass\n"));
+	    LOGDEB("X11 session went away during initial indexing pass\n");
 	    stopindexing = true;
 	    return false;
 	}
@@ -167,7 +168,7 @@ static MyUpdater *updater;
 static void sigcleanup(int sig)
 {
     fprintf(stderr, "Got signal, registering stop request\n");
-    LOGDEB(("Got signal, registering stop request\n"));
+    LOGDEB("Got signal, registering stop request\n");
     CancelCheck::instance().setCancel();
     stopindexing = 1;
 }
@@ -302,7 +303,7 @@ static bool checktopdirs(RclConfig *config, vector<string>& nonexist)
     vector<string> tdl;
     if (!config->getConfParam("topdirs", &tdl)) {
         cerr << "No 'topdirs' parameter in configuration\n";
-        LOGERR(("recollindex:No 'topdirs' parameter in configuration\n"));;
+        LOGERR("recollindex:No 'topdirs' parameter in configuration\n");;
         return false;
     }
 
@@ -311,12 +312,10 @@ static bool checktopdirs(RclConfig *config, vector<string>& nonexist)
         if (!it->size() || !path_isabsolute(*it)) {
             if ((*it)[0] == '~') {
                 cerr << "Tilde expansion failed: " << *it << endl;
-                LOGERR(("recollindex: tilde expansion failed: %s\n",
-                        it->c_str()));
+                LOGERR("recollindex: tilde expansion failed: " << *it << "\n");
             } else {
                 cerr << "Not an absolute path: " << *it << endl;
-                LOGERR(("recollindex: not an absolute path: %s\n",
-                        it->c_str()));
+                LOGERR("recollindex: not an absolute path: " << *it << "\n");
             }
             return false;
         }
@@ -406,12 +405,41 @@ void lockorexit(Pidfile *pidfile)
     }
 }
 
+static ConfSimple reasons;
+static string reasonsfile;
+void addIdxReason(string who, string reason)
+{
+    reason = neutchars(reason, "\r\n");
+    if (!reasons.set(who, reason)) {
+        cerr << "addIdxReason: confsimple set failed\n";
+    }
+}
+static void flushIdxReasons()
+{
+    if (reasonsfile.empty())
+        return;
+    if (reasonsfile == "stdout") {
+        reasons.write(cout);
+    } else if (reasonsfile == "stderr") {
+        reasons.write(cerr);
+    } else {
+        ofstream out;
+        try {
+            out.open(reasonsfile, ofstream::out|ofstream::trunc);
+            reasons.write(out);
+        } catch (...) {
+            cerr << "Could not write reasons file " << reasonsfile << endl;
+            reasons.write(cerr);
+        }
+    }
+}
+
 int main(int argc, char **argv)
 {
     string a_config;
     int sleepsecs = 60;
     vector<string> selpatterns;
-
+    
     // The reexec struct is used by the daemon to shed memory after
     // the initial indexing pass and to restart when the configuration
     // changes
@@ -451,6 +479,8 @@ int main(int argc, char **argv)
 		selpatterns.push_back(*(++argv));
 		argc--; goto b1;
 	    case 'r': op_flags |= OPT_r; break;
+	    case 'R':	op_flags |= OPT_R; if (argc < 2)  Usage();
+                reasonsfile = *(++argv); argc--; goto b1;
 	    case 's': op_flags |= OPT_s; break;
 #ifdef RCL_USE_ASPELL
 	    case 'S': op_flags |= OPT_S; break;
@@ -483,11 +513,14 @@ int main(int argc, char **argv)
     if ((op_flags & OPT_E) && (op_flags & ~(OPT_E|OPT_c))) {
         Usage();
     }
+
     string reason;
     RclInitFlags flags = (op_flags & OPT_m) && !(op_flags&OPT_D) ? 
 	RCLINIT_DAEMON : RCLINIT_IDX;
     config = recollinit(flags, cleanup, sigcleanup, reason, &a_config);
     if (config == 0 || !config->ok()) {
+        addIdxReason("init", reason);
+        flushIdxReasons();
 	cerr << "Configuration problem: " << reason << endl;
 	exit(1);
     }
@@ -496,8 +529,11 @@ int main(int argc, char **argv)
 #endif
 
     vector<string> nonexist;
-    if (!checktopdirs(config, nonexist))
+    if (!checktopdirs(config, nonexist)) {
+        addIdxReason("init", "topdirs not set");
+        flushIdxReasons();
         exit(1);
+    }
 
     if (nonexist.size()) {
         ostream& out = (op_flags & OPT_E) ? cout : cerr;
@@ -517,18 +553,17 @@ int main(int argc, char **argv)
     string rundir;
     config->getConfParam("idxrundir", rundir);
     if (!rundir.compare("tmp")) {
-	LOGINFO(("recollindex: changing current directory to [%s]\n",
-		tmplocation().c_str()));
+	LOGINFO("recollindex: changing current directory to [" <<
+                tmplocation() << "]\n");
 	if (chdir(tmplocation().c_str()) < 0) {
-	    LOGERR(("chdir(%s) failed, errno %d\n", 
-		    tmplocation().c_str(), errno));
+	    LOGERR("chdir(" << tmplocation() << ") failed, errno " << errno <<
+                   "\n");
 	}
     } else if (!rundir.empty()) {
-	LOGINFO(("recollindex: changing current directory to [%s]\n",
-		 rundir.c_str()));
+	LOGINFO("recollindex: changing current directory to [" << rundir <<
+                "]\n");
 	if (chdir(rundir.c_str()) < 0) {
-	    LOGERR(("chdir(%s) failed, errno %d\n", 
-		    rundir.c_str(), errno));
+	    LOGERR("chdir(" << rundir << ") failed, errno " << errno << "\n");
 	}
     }
 
@@ -551,10 +586,10 @@ int main(int argc, char **argv)
 
     // Log something at LOGINFO to reset the trace file. Else at level
     // 3 it's not even truncated if all docs are up to date.
-    LOGINFO(("recollindex: starting up\n"));
+    LOGINFO("recollindex: starting up\n");
 #ifndef _WIN32
     if (setpriority(PRIO_PROCESS, 0, 20) != 0) {
-        LOGINFO(("recollindex: can't setpriority(), errno %d\n", errno));
+        LOGINFO("recollindex: can't setpriority(), errno " << errno << "\n");
     }
     // Try to ionice. This does not work on all platforms
     rclIxIonice(config);
@@ -565,8 +600,11 @@ int main(int argc, char **argv)
 	    Usage();
 	string top = *argv++; argc--;
 	bool status = recursive_index(config, top, selpatterns);
-        if (confindexer && !confindexer->getReason().empty())
+        if (confindexer && !confindexer->getReason().empty()) {
+            addIdxReason("indexer", confindexer->getReason());
             cerr << confindexer->getReason() << endl;
+        }
+        flushIdxReasons();
         exit(status ? 0 : 1);
     } else if (op_flags & (OPT_i|OPT_e)) {
 	lockorexit(&pidfile);
@@ -597,8 +635,11 @@ int main(int argc, char **argv)
         if (status && (op_flags & OPT_i)) {
 	    status = indexfiles(config, filenames);
         }
-        if (confindexer && !confindexer->getReason().empty())
+        if (confindexer && !confindexer->getReason().empty()) {
+            addIdxReason("indexer", confindexer->getReason());
             cerr << confindexer->getReason() << endl;
+        }
+        flushIdxReasons();
         exit(status ? 0 : 1);
     } else if (op_flags & OPT_l) {
 	if (argc != 0) 
@@ -626,12 +667,14 @@ int main(int argc, char **argv)
 	    Usage();
 	lockorexit(&pidfile);
 	if (!(op_flags&OPT_D)) {
-	    LOGDEB(("recollindex: daemonizing\n"));
+	    LOGDEB("recollindex: daemonizing\n");
 #ifndef _WIN32
 	    if (daemon(0,0) != 0) {
-	      fprintf(stderr, "daemon() failed, errno %d\n", errno);
-	      LOGERR(("daemon() failed, errno %d\n", errno));
-	      exit(1);
+                addIdxReason("monitor", "daemon() failed");
+                cerr << "daemon() failed, errno " << errno << endl;
+                LOGERR("daemon() failed, errno " << errno << "\n");
+                flushIdxReasons();
+                exit(1);
 	    }
 #endif
 	}
@@ -641,30 +684,31 @@ int main(int argc, char **argv)
         // Not too sure if I have to redo the nice thing after daemon(),
         // can't hurt anyway (easier than testing on all platforms...)
         if (setpriority(PRIO_PROCESS, 0, 20) != 0) {
-            LOGINFO(("recollindex: can't setpriority(), errno %d\n", errno));
+            LOGINFO("recollindex: can't setpriority(), errno " << errno<< "\n");
         }
 	// Try to ionice. This does not work on all platforms
 	rclIxIonice(config);
 #endif
 
 	if (sleepsecs > 0) {
-	    LOGDEB(("recollindex: sleeping %d\n", sleepsecs));
+	    LOGDEB("recollindex: sleeping " << sleepsecs << "\n");
 	    for (int i = 0; i < sleepsecs; i++) {
 	      sleep(1);
 	      // Check that x11 did not go away while we were sleeping.
 	      if (!(op_flags & OPT_x) && !x11IsAlive()) {
-		LOGDEB(("X11 session went away during initial sleep period\n"));
+		LOGDEB("X11 session went away during initial sleep period\n");
 		exit(0);
 	      }
 	    }
 	}
 	if (!(op_flags & OPT_n)) {
 	    makeIndexerOrExit(config, inPlaceReset);
-	    LOGDEB(("Recollindex: initial indexing pass before monitoring\n"));
+	    LOGDEB("Recollindex: initial indexing pass before monitoring\n");
 	    if (!confindexer->index(rezero, ConfIndexer::IxTAll, indexerFlags)
                 || stopindexing) {
-		LOGERR(("recollindex, initial indexing pass failed, "
-			"not going into monitor mode\n"));
+		LOGERR("recollindex, initial indexing pass failed, "
+                       "not going into monitor mode\n");
+                flushIdxReasons();
 		exit(1);
 	    } else {
                 // Record success of indexing pass with failed files retries.
@@ -675,7 +719,8 @@ int main(int argc, char **argv)
 	    deleteZ(confindexer);
 #ifndef _WIN32
 	    o_reexec->insertArgs(vector<string>(1, "-n"));
-	    LOGINFO(("recollindex: reexecuting with -n after initial full pass\n"));
+	    LOGINFO("recollindex: reexecuting with -n after initial full "
+                    "pass\n");
 	    // Note that -n will be inside the reexec when we come
 	    // back, but the monitor will explicitely strip it before
 	    // starting a config change exec to ensure that we do a
@@ -714,14 +759,17 @@ int main(int argc, char **argv)
         }
 	if (!status) 
 	    cerr << "Indexing failed" << endl;
-        if (!confindexer->getReason().empty())
+        if (!confindexer->getReason().empty()) {
+            addIdxReason("indexer", confindexer->getReason());
             cerr << confindexer->getReason() << endl;
-
+        }
         if (updater) {
 	    updater->status.phase = DbIxStatus::DBIXS_DONE;
 	    updater->status.fn.clear();
 	    updater->update();
 	}
+        flushIdxReasons();
 	return !status;
     }
 }
+
