@@ -21,7 +21,7 @@
 
 #include "rclconfig.h"
 #include "pxattr.h"
-#include "debuglog.h"
+#include "log.h"
 #include "cstr.h"
 #include "rcldoc.h"
 #include "execmd.h"
@@ -33,8 +33,7 @@ static void docfieldfrommeta(RclConfig* cfg, const string& name,
 			     const string &value, Rcl::Doc& doc)
 {
     string fieldname = cfg->fieldCanon(name);
-    LOGDEB0(("Internfile:: setting [%s] from cmd/xattr value [%s]\n",
-	     fieldname.c_str(), value.c_str()));
+    LOGDEB0("Internfile:: setting ["  << (fieldname) << "] from cmd/xattr value ["  << (value) << "]\n" );
     if (fieldname == cstr_dj_keymd) {
 	doc.dmtime = value;
     } else {
@@ -45,17 +44,15 @@ static void docfieldfrommeta(RclConfig* cfg, const string& name,
 void reapXAttrs(const RclConfig* cfg, const string& path, 
 		map<string, string>& xfields)
 {
-    LOGDEB2(("reapXAttrs: [%s]\n", path.c_str()));
+    LOGDEB2("reapXAttrs: ["  << (path) << "]\n" );
 #ifndef _WIN32
     // Retrieve xattrs names from files and mapping table from config
     vector<string> xnames;
     if (!pxattr::list(path, &xnames)) {
         if (errno == ENOTSUP) {
-            LOGDEB(("FileInterner::reapXattrs: pxattr::list: errno %d\n",
-                    errno));
+            LOGDEB("FileInterner::reapXattrs: pxattr::list: errno "  << (errno) << "\n" );
         } else {
-            LOGERR(("FileInterner::reapXattrs: pxattr::list: errno %d\n",
-                    errno));
+            LOGERR("FileInterner::reapXattrs: pxattr::list: errno "  << (errno) << "\n" );
         }
 	return;
     }
@@ -77,13 +74,12 @@ void reapXAttrs(const RclConfig* cfg, const string& path,
 	}
 	string value;
 	if (!pxattr::get(path, *it, &value, pxattr::PXATTR_NOFOLLOW)) {
-	    LOGERR(("FileInterner::reapXattrs: pxattr::get failed"
-		    "for %s, errno %d\n", (*it).c_str(), errno));
+	    LOGERR("FileInterner::reapXattrs: pxattr::get failedfor "  << ((*it)) << ", errno "  << (errno) << "\n" );
 	    continue;
 	}
 	// Encode should we ?
 	xfields[key] = value;
-	LOGDEB2(("reapXAttrs: [%s] -> [%s]\n", key.c_str(), value.c_str()));
+	LOGDEB2("reapXAttrs: ["  << (key) << "] -> ["  << (value) << "]\n" );
     }
 #endif
 }
@@ -103,7 +99,7 @@ void reapMetaCmds(RclConfig* cfg, const string& path,
     const vector<MDReaper>& reapers = cfg->getMDReapers();
     if (reapers.empty())
 	return;
-    map<char,string> smap = create_map<char, string>('f', path);
+    map<char,string> smap = {{'f', path}};
     for (vector<MDReaper>::const_iterator rp = reapers.begin();
 	 rp != reapers.end(); rp++) {
 	vector<string> cmd;
@@ -150,3 +146,4 @@ void docFieldsFromMetaCmds(RclConfig *cfg, const map<string, string>& cfields,
 	}
     }
 }
+
