@@ -23,11 +23,12 @@
 #include <string>
 #include <vector>
 #include <list>
+#include <mutex>
 using namespace std;
 
 #include "cstr.h"
 #include "mimehandler.h"
-#include "debuglog.h"
+#include "log.h"
 #include "rclconfig.h"
 #include "smallut.h"
 #include "md5ut.h"
@@ -40,7 +41,6 @@ using namespace std;
 #include "mh_symlink.h"
 #include "mh_unknown.h"
 #include "mh_null.h"
-#include "ptmutex.h"
 
 // Performance help: we use a pool of already known and created
 // handlers. There can be several instances for a given mime type
@@ -50,18 +50,18 @@ static multimap<string, RecollFilter*>  o_handlers;
 static list<multimap<string, RecollFilter*>::iterator> o_hlru;
 typedef list<multimap<string, RecollFilter*>::iterator>::iterator hlruit_tp;
 
-static PTMutexInit o_handlers_mutex;
+static std::mutex o_handlers_mutex;
 
 static const unsigned int max_handlers_cache_size = 100;
 
 /* Look for mime handler in pool */
 static RecollFilter *getMimeHandlerFromCache(const string& key)
 {
-    PTMutexLocker locker(o_handlers_mutex);
+    std::unique_lock<std::mutex> locker(o_handlers_mutex);
     string xdigest;
     MD5HexPrint(key, xdigest);
-    LOGDEB(("getMimeHandlerFromCache: %s cache size %u\n", 
-	    xdigest.c_str(), o_handlers.size()));
+    LOGDEB("getMimeHandlerFromCache: " << xdigest << " cache size " <<
+           o_handlers.size() << "\n");
 
     multimap<string, RecollFilter *>::iterator it = o_handlers.find(key);
     if (it != o_handlers.end()) {
@@ -70,14 +70,14 @@ static RecollFilter *getMimeHandlerFromCache(const string& key)
 	if (it1 != o_hlru.end()) {
 	    o_hlru.erase(it1);
 	} else {
-	    LOGERR(("getMimeHandlerFromCache: lru position not found\n"));
+	    LOGERR("getMimeHandlerFromCache: lru position not found\n");
 	}
 	o_handlers.erase(it);
-	LOGDEB(("getMimeHandlerFromCache: %s found size %u\n", 
-		xdigest.c_str(), o_handlers.size()));
+	LOGDEB("getMimeHandlerFromCache: " << xdigest << " found size " <<
+               o_handlers.size() << "\n");
 	return h;
     }
-    LOGDEB(("getMimeHandlerFromCache: %s not found\n", xdigest.c_str()));
+    LOGDEB("getMimeHandlerFromCache: " << xdigest << " not found\n");
     return 0;
 }
 
@@ -87,15 +87,16 @@ void returnMimeHandler(RecollFilter *handler)
     typedef multimap<string, RecollFilter*>::value_type value_type;
 
     if (handler == 0) {
-	LOGERR(("returnMimeHandler: bad parameter\n"));
+	LOGERR("returnMimeHandler: bad parameter\n");
 	return;
     }
     handler->clear();
 
-    PTMutexLocker locker(o_handlers_mutex);
+    std::unique_lock<std::mutex> locker(o_handlers_mutex);
 
-    LOGDEB(("returnMimeHandler: returning filter for %s cache size %d\n", 
-	    handler->get_mime_type().c_str(), o_handlers.size()));
+    LOGDEB("returnMimeHandler: returning filter for " <<
+           handler->get_mime_type() << " cache size " << o_handlers.size() <<
+           "\n");
 
     // Limit pool size. The pool can grow quite big because there are
     // many filter types, each of which can be used in several copies
@@ -108,9 +109,9 @@ void returnMimeHandler(RecollFilter *handler)
 	if (once) {
 	    once = 0;
 	    for (it = o_handlers.begin(); it != o_handlers.end(); it++) {
-		LOGDEB1(("Cache full. key: %s\n", it->first.c_str()));
+		LOGDEB1("Cache full. key: " << it->first << "\n");
 	    }
-	    LOGDEB1(("Cache LRU size: %u\n", o_hlru.size()));
+	    LOGDEB1("Cache LRU size: " << o_hlru.size() << "\n");
 	}
 	if (o_hlru.size() > 0) {
 	    it = o_hlru.back();
@@ -125,9 +126,9 @@ void returnMimeHandler(RecollFilter *handler)
 
 void clearMimeHandlerCache()
 {
-    LOGDEB(("clearMimeHandlerCache()\n"));
+    LOGDEB("clearMimeHandlerCache()\n");
     multimap<string, RecollFilter *>::iterator it;
-    PTMutexLocker locker(o_handlers_mutex);
+    std::unique_lock<std::mutex> locker(o_handlers_mutex);
     for (it = o_handlers.begin(); it != o_handlers.end(); it++) {
 	delete it->second;
     }
@@ -139,31 +140,31 @@ void clearMimeHandlerCache()
 static RecollFilter *mhFactory(RclConfig *config, const string &mime,
 				bool nobuild, string& id)
 {
-    LOGDEB2(("mhFactory(%s)\n", mime.c_str()));
+    LOGDEB2("mhFactory(" << mime << ")\n");
     string lmime(mime);
     stringtolower(lmime);
     if (cstr_textplain == lmime) {
-	LOGDEB2(("mhFactory(%s): returning MimeHandlerText\n", mime.c_str()));
+	LOGDEB2("mhFactory(" << mime << "): returning MimeHandlerText\n");
 	MD5String("MimeHandlerText", id);
 	return nobuild ? 0 : new MimeHandlerText(config, id);
     } else if ("text/html" == lmime) {
-	LOGDEB2(("mhFactory(%s): returning MimeHandlerHtml\n", mime.c_str()));
+	LOGDEB2("mhFactory(" << mime << "): returning MimeHandlerHtml\n");
 	MD5String("MimeHandlerHtml", id);
 	return nobuild ? 0 : new MimeHandlerHtml(config, id);
     } else if ("text/x-mail" == lmime) {
-	LOGDEB2(("mhFactory(%s): returning MimeHandlerMbox\n", mime.c_str()));
+	LOGDEB2("mhFactory(" << mime << "): returning MimeHandlerMbox\n");
 	MD5String("MimeHandlerMbox", id);
 	return nobuild ? 0 : new MimeHandlerMbox(config, id);
     } else if ("message/rfc822" == lmime) {
-	LOGDEB2(("mhFactory(%s): returning MimeHandlerMail\n", mime.c_str()));
+	LOGDEB2("mhFactory(" << mime << "): returning MimeHandlerMail\n");
 	MD5String("MimeHandlerMail", id);
 	return nobuild ? 0 : new MimeHandlerMail(config, id);
     } else if ("inode/symlink" == lmime) {
-	LOGDEB2(("mhFactory(%s): ret MimeHandlerSymlink\n", mime.c_str()));
+	LOGDEB2("mhFactory(" << mime << "): ret MimeHandlerSymlink\n");
 	MD5String("MimeHandlerSymlink", id);
 	return nobuild ? 0 : new MimeHandlerSymlink(config, id);
     } else if ("application/x-zerosize" == lmime) {
-	LOGDEB(("mhFactory(%s): ret MimeHandlerNull\n", mime.c_str()));
+	LOGDEB("mhFactory(" << mime << "): ret MimeHandlerNull\n");
 	MD5String("MimeHandlerNull", id);
 	return nobuild ? 0 : new MimeHandlerNull(config, id);
     } else if (lmime.find("text/") == 0) {
@@ -172,15 +173,15 @@ static RecollFilter *mhFactory(RclConfig *config, const string &mime,
         // mimeconf, not at random. For programs, for example this
         // allows indexing and previewing as text/plain (no filter
         // exec) but still opening with a specific editor.
-	LOGDEB2(("mhFactory(%s): returning MimeHandlerText(x)\n",mime.c_str()));
+	LOGDEB2("mhFactory(" << mime << "): returning MimeHandlerText(x)\n");
 	MD5String("MimeHandlerText", id);
         return nobuild ? 0 : new MimeHandlerText(config, id); 
     } else {
 	// We should not get there. It means that "internal" was set
 	// as a handler in mimeconf for a mime type we actually can't
 	// handle.
-	LOGERR(("mhFactory: mime type [%s] set as internal but unknown\n", 
-		lmime.c_str()));
+	LOGERR("mhFactory: mime type [" << lmime <<
+               "] set as internal but unknown\n");
 	MD5String("MimeHandlerUnknown", id);
 	return nobuild ? 0 : new MimeHandlerUnknown(config, id);
     }
@@ -203,8 +204,8 @@ MimeHandlerExec *mhExecFactory(RclConfig *cfg, const string& mtype, string& hs,
     string cmdstr;
 
     if (!cfg->valueSplitAttributes(hs, cmdstr, attrs)) {
-	LOGERR(("mhExecFactory: bad config line for [%s]: [%s]\n", 
-		mtype.c_str(), hs.c_str()));
+	LOGERR("mhExecFactory: bad config line for [" <<
+               mtype << "]: [" << hs << "]\n");
         return 0;
     }
 
@@ -212,8 +213,8 @@ MimeHandlerExec *mhExecFactory(RclConfig *cfg, const string& mtype, string& hs,
     vector<string> cmdtoks;
     stringToStrings(cmdstr, cmdtoks);
     if (cmdtoks.empty()) {
-	LOGERR(("mhExecFactory: bad config line for [%s]: [%s]\n", 
-		mtype.c_str(), hs.c_str()));
+	LOGERR("mhExecFactory: bad config line for [" << mtype <<
+               "]: [" << hs << "]\n");
 	return 0;
     }
     MimeHandlerExec *h = multiple ? 
@@ -227,8 +228,8 @@ MimeHandlerExec *mhExecFactory(RclConfig *cfg, const string& mtype, string& hs,
     // the same change if we ever want to use the same cmdling as windows
     if (!stringlowercmp("python", *it) || !stringlowercmp("perl", *it)) {
         if (cmdtoks.size() < 2) {
-            LOGERR(("mhExecFactory: python/perl cmd: no script?. [%s]: [%s]\n", 
-                    mtype.c_str(), hs.c_str()));
+            LOGERR("mhExecFactory: python/perl cmd: no script?. [" <<
+                   mtype << "]: [" << hs << "]\n");
         }
         vector<string>::iterator it1(it);
         it1++;
@@ -251,9 +252,9 @@ MimeHandlerExec *mhExecFactory(RclConfig *cfg, const string& mtype, string& hs,
     for (it = h->params.begin(); it != h->params.end(); it++) {
 	scmd += string("[") + *it + "] ";
     }
-    LOGDEB(("mhExecFactory:mt [%s] cfgmt [%s] cfgcs [%s] cmd: [%s]\n",
-	    mtype.c_str(), h->cfgFilterOutputMtype.c_str(), h->cfgFilterOutputCharset.c_str(),
-	    scmd.c_str()));
+    LOGDEB("mhExecFactory:mt [" << mtype << "] cfgmt [" <<
+           h->cfgFilterOutputMtype << "] cfgcs [" <<
+           h->cfgFilterOutputCharset << "] cmd: [" << scmd << "]\n");
 #endif
 
     return h;
@@ -263,8 +264,8 @@ MimeHandlerExec *mhExecFactory(RclConfig *cfg, const string& mtype, string& hs,
 RecollFilter *getMimeHandler(const string &mtype, RclConfig *cfg, 
 			      bool filtertypes)
 {
-    LOGDEB(("getMimeHandler: mtype [%s] filtertypes %d\n", 
-	     mtype.c_str(), filtertypes));
+    LOGDEB("getMimeHandler: mtype [" << mtype << "] filtertypes " <<
+           filtertypes << "\n");
     RecollFilter *h = 0;
 
     // Get handler definition for mime type. We do this even if an
@@ -297,18 +298,12 @@ RecollFilter *getMimeHandler(const string &mtype, RclConfig *cfg,
 	    MD5String(hs, id);
 	}
 
-#if 0
-	{ // string xdigest; LOGDEB2(("getMimeHandler: [%s] hs [%s] id [%s]\n", 
-	  //mtype.c_str(), hs.c_str(), MD5HexPrint(id, xdigest).c_str()));
-	}
-#endif
-
         // Do we already have a handler object in the cache ?
 	h = getMimeHandlerFromCache(id);
 	if (h != 0)
 	    goto out;
 
-	LOGDEB2(("getMimeHandler: %s not in cache\n", mtype.c_str()));
+	LOGDEB2("getMimeHandler: " << mtype << " not in cache\n");
 
 	// Not in cache. 
 	if (internal) {
@@ -319,14 +314,14 @@ RecollFilter *getMimeHandler(const string &mtype, RclConfig *cfg,
 	    // partly redundant with the localfields/rclaptg, but
 	    // better and the latter will probably go away at some
 	    // point in the future.
-	    LOGDEB2(("handlertype internal, cmdstr [%s]\n", cmdstr.c_str()));
+	    LOGDEB2("handlertype internal, cmdstr [" << cmdstr << "]\n");
 	    h = mhFactory(cfg, cmdstr.empty() ? mtype : cmdstr, false, id);
 	    goto out;
 	} else if (!stringlowercmp("dll", handlertype)) {
 	} else {
             if (cmdstr.empty()) {
-		LOGERR(("getMimeHandler: bad line for %s: %s\n", 
-			mtype.c_str(), hs.c_str()));
+		LOGERR("getMimeHandler: bad line for " << mtype << ": " <<
+                       hs << "\n");
 		goto out;
 	    }
             if (!stringlowercmp("exec", handlertype)) {
@@ -336,8 +331,8 @@ RecollFilter *getMimeHandler(const string &mtype, RclConfig *cfg,
                 h = mhExecFactory(cfg, mtype, cmdstr, true, id);
 		goto out;
             } else {
-		LOGERR(("getMimeHandler: bad line for %s: %s\n", 
-			mtype.c_str(), hs.c_str()));
+		LOGERR("getMimeHandler: bad line for " << mtype << ": " <<
+                       hs << "\n");
 		goto out;
             }
 	}
@@ -380,3 +375,14 @@ bool canIntern(const std::string mtype, RclConfig *cfg)
 	return false;
     return true;
 }
+
+string RecollFilter::metadataAsString()
+{
+    string s;
+    for (const auto& ent : m_metaData) {
+        if (ent.first == "content")
+            continue;
+        s += ent.first + "->" + ent.second + "\n";
+    }
+    return s;
+}
