@@ -35,7 +35,7 @@ using std::list;
 #include "recoll.h"
 #include "confguiindex.h"
 #include "smallut.h"
-#include "debuglog.h"
+#include "log.h"
 #include "rcldb.h"
 #include "conflinkrcl.h"
 #include "execmd.h"
@@ -68,9 +68,9 @@ ConfIndexW::ConfIndexW(QWidget *parent, RclConfig *config)
 
 void ConfIndexW::acceptChanges()
 {
-    LOGDEB(("ConfIndexW::acceptChanges()\n"));
+    LOGDEB("ConfIndexW::acceptChanges()\n" );
     if (!m_conf) {
-	LOGERR(("ConfIndexW::acceptChanges: no config\n"));
+	LOGERR("ConfIndexW::acceptChanges: no config\n" );
 	return;
     }
     // Let the changes to disk
@@ -88,7 +88,7 @@ void ConfIndexW::acceptChanges()
 
 void ConfIndexW::rejectChanges()
 {
-    LOGDEB(("ConfIndexW::rejectChanges()\n"));
+    LOGDEB("ConfIndexW::rejectChanges()\n" );
     // Discard local changes.
     delete m_conf;
     m_conf = 0;
@@ -250,11 +250,12 @@ ConfTopPanelW::ConfTopPanelW(QWidget *parent, ConfNull *config)
 	ConfParamSLW(this, 
                      ConfLink(new ConfLinkRclRep(config, "skippedPaths")), 
                      tr("Skipped paths"),
-		     tr("These are names of directories which indexing "
-			"will not enter.<br> May contain wildcards. "
-			"Must match "
-			"the paths seen by the indexer (ie: if topdirs "
-			"includes '/home/me' and '/home' is actually a link "
+		     tr("These are pathnames of directories which indexing "
+			"will not enter.<br>"
+                        "Path elements may contain wildcards. "
+			"The entries must match the paths seen by the indexer "
+                        "(e.g.: if topdirs includes '/home/me' and '/home' is "
+                        "actually a link "
 			"to '/usr/home', a correct skippedPath entry "
 			"would be '/home/me/tmp*', not '/usr/home/me/tmp*')"));
     eskp->setFsEncoding(true);
@@ -305,11 +306,12 @@ ConfTopPanelW::ConfTopPanelW(QWidget *parent, ConfNull *config)
 
     w = new ConfParamIntW(this, 
                           ConfLink(new ConfLinkRclRep(config, "maxfsoccuppc")),
-                          tr("Max disk occupation (%)"),
-                          tr("This is the percentage of disk occupation where "
-                             "indexing will fail and stop (to avoid filling up "
-                             "your disk).<br>0 means no limit "
-                             "(this is the default)."), 0, 100);
+                          tr("Max disk occupation (%, 0 means no limit)"),
+                          tr("This is the percentage of disk usage "
+                             "- total disk usage, not index size - at which "
+                             "indexing will fail and stop.<br>"
+                             "The default value of 0 removes any limit."),
+                          0, 100);
     gl1->addWidget(w, gridrow++, 0);
 
     ConfParamBoolW* cpasp =
@@ -477,7 +479,7 @@ ConfSubPanelW::ConfSubPanelW(QWidget *parent, ConfNull *config,
     string cmd = "iconv";
     int status = ex.doexec(cmd, args, 0, &icout);
     if (status) {
-	LOGERR(("Can't get list of charsets from 'iconv -l'"));
+	LOGERR("Can't get list of charsets from 'iconv -l'" );
     }
     icout = neutchars(icout, ",");
     list<string> ccsets;
@@ -579,7 +581,7 @@ void ConfSubPanelW::reloadAll()
 
 void ConfSubPanelW::subDirChanged(QListWidgetItem *current, QListWidgetItem *)
 {
-    LOGDEB(("ConfSubPanelW::subDirChanged\n"));
+    LOGDEB("ConfSubPanelW::subDirChanged\n" );
 	
     if (current == 0 || current->text() == "") {
 	m_sk = "";
@@ -588,13 +590,13 @@ void ConfSubPanelW::subDirChanged(QListWidgetItem *current, QListWidgetItem *)
 	m_sk = (const char *) current->text().toUtf8();
 	m_groupbox->setTitle(current->text());
     }
-    LOGDEB(("ConfSubPanelW::subDirChanged: now [%s]\n", m_sk.c_str()));
+    LOGDEB("ConfSubPanelW::subDirChanged: now ["  << (m_sk) << "]\n" );
     reloadAll();
 }
 
 void ConfSubPanelW::subDirDeleted(QString sbd)
 {
-    LOGDEB(("ConfSubPanelW::subDirDeleted(%s)\n", (const char *)sbd.toUtf8()));
+    LOGDEB("ConfSubPanelW::subDirDeleted("  << ((const char *)sbd.toUtf8()) << ")\n" );
     if (sbd == "") {
 	// Can't do this, have to reinsert it
 	QTimer::singleShot(0, this, SLOT(restoreEmpty()));
@@ -606,8 +608,9 @@ void ConfSubPanelW::subDirDeleted(QString sbd)
 
 void ConfSubPanelW::restoreEmpty()
 {
-    LOGDEB(("ConfSubPanelW::restoreEmpty()\n"));
+    LOGDEB("ConfSubPanelW::restoreEmpty()\n" );
     m_subdirs->getListBox()->insertItem(0, "");
 }
 
 } // Namespace confgui
+
