@@ -36,13 +36,10 @@
 #include "recoll.h"
 #include "smallut.h"
 #include "rclinit.h"
-#include "debuglog.h"
+#include "log.h"
 #include "rclmain_w.h"
 #include "ssearch_w.h"
 #include "guiutils.h"
-#ifdef RCL_USE_ASPELL
-#include "rclaspell.h"
-#endif
 #include "smallut.h"
 #include "readfile.h"
 
@@ -50,14 +47,14 @@
 
 extern RclConfig *theconfig;
 
-PTMutexInit thetempfileslock;
+std::mutex thetempfileslock;
 static vector<TempFile>  o_tempfiles;
 /* Keep an array of temporary files for deletion at exit. It happens that we
    erase some of them before exiting (ie: when closing a preview tab), we don't 
    reuse the array holes for now */
 void rememberTempFile(TempFile temp)
 {
-    PTMutexLocker locker(thetempfileslock);
+    std::unique_lock<std::mutex> locker(thetempfileslock);
     o_tempfiles.push_back(temp);
 }    
 
@@ -65,7 +62,7 @@ void forgetTempFile(string &fn)
 {
     if (fn.empty())
 	return;
-    PTMutexLocker locker(thetempfileslock);
+    std::unique_lock<std::mutex> locker(thetempfileslock);
     for (vector<TempFile>::iterator it = o_tempfiles.begin();
 	 it != o_tempfiles.end(); it++) {
 	if ((*it) && !fn.compare((*it)->filename())) {
@@ -77,15 +74,12 @@ void forgetTempFile(string &fn)
 
 void deleteAllTempFiles()
 {
-    PTMutexLocker locker(thetempfileslock);
+    std::unique_lock<std::mutex> locker(thetempfileslock);
     o_tempfiles.clear();
 }
 
 Rcl::Db *rcldb;
 
-#ifdef RCL_USE_ASPELL
-Aspell *aspell;
-#endif
 
 int recollNeedsExit;
 RclMain *mainWindow;
@@ -98,7 +92,7 @@ void startManual(const string& helpindex)
 
 bool maybeOpenDb(string &reason, bool force, bool *maindberror)
 {
-    LOGDEB2(("maybeOpenDb: force %d\n", force));
+    LOGDEB2("maybeOpenDb: force "  << (force) << "\n" );
     if (!rcldb) {
 	reason = "Internal error: db not created";
 	return false;
@@ -109,7 +103,7 @@ bool maybeOpenDb(string &reason, bool force, bool *maindberror)
     rcldb->rmQueryDb("");
     for (list<string>::const_iterator it = prefs.activeExtraDbs.begin();
 	 it != prefs.activeExtraDbs.end(); it++) {
-	LOGDEB(("main: adding [%s]\n", it->c_str()));
+	LOGDEB("main: adding ["  << *it << "]\n" );
 	rcldb->addQueryDb(*it);
     }
     Rcl::Db::OpenError error;
@@ -136,8 +130,7 @@ bool getStemLangs(vector<string>& vlangs)
     string reason;
     if (maybeOpenDb(reason)) {
 	vlangs = rcldb->getStemLangs();
-	LOGDEB0(("getStemLangs: from index: %s\n", 
-		 stringsToString(vlangs).c_str()));
+	LOGDEB0("getStemLangs: from index: "  << (stringsToString(vlangs)) << "\n" );
 	return true;
     } else {
 	// Cant get the langs from the index. Maybe it just does not
@@ -153,23 +146,19 @@ bool getStemLangs(vector<string>& vlangs)
 
 static void recollCleanup()
 {
-    LOGDEB2(("recollCleanup: closing database\n"));
+    LOGDEB2("recollCleanup: closing database\n" );
     deleteZ(rcldb);
     deleteZ(theconfig);
 
     deleteAllTempFiles();
     
-#ifdef RCL_USE_ASPELL
-    deleteZ(aspell);
-#endif
-
-    LOGDEB2(("recollCleanup: done\n"));
+    LOGDEB2("recollCleanup: done\n" );
 }
 
 void applyStyleSheet(const QString& ssfname)
 {
     const char *cfname = (const char *)ssfname.toLocal8Bit();
-    LOGDEB0(("Applying style sheet: [%s]\n", cfname));
+    LOGDEB0("Applying style sheet: ["  << (cfname) << "]\n" );
     if (cfname && *cfname) {
 	string stylesheet;
 	file_to_string(cfname, stylesheet);
@@ -323,15 +312,6 @@ int main(int argc, char **argv)
 
     //    fprintf(stderr, "Translations installed\n");
 
-#ifdef RCL_USE_ASPELL
-    aspell = new Aspell(theconfig);
-    aspell->init(reason);
-    if (!aspell || !aspell->ok()) {
-	LOGDEB(("Aspell speller creation failed %s\n", reason.c_str()));
-	aspell = 0;
-    }
-#endif
-
     string historyfile = path_cat(theconfig->getConfDir(), "history");
     g_dynconf = new RclDynConf(historyfile);
     if (!g_dynconf || !g_dynconf->ok()) {
@@ -396,7 +376,7 @@ int main(int argc, char **argv)
 	mainWindow->
 	    sSearch->setSearchString(QString::fromLocal8Bit(question.c_str()));
     } else if (!urltoview.empty()) {
-	LOGDEB(("MAIN: got urltoview [%s]\n", urltoview.c_str()));
+	LOGDEB("MAIN: got urltoview ["  << (urltoview) << "]\n" );
 	mainWindow->setUrlToView(QString::fromLocal8Bit(urltoview.c_str()));
     }
     return app.exec();
@@ -404,7 +384,7 @@ int main(int argc, char **argv)
 
 QString myGetFileName(bool isdir, QString caption, bool filenosave)
 {
-    LOGDEB1(("myFileDialog: isdir %d\n", isdir));
+    LOGDEB1("myFileDialog: isdir "  << (isdir) << "\n" );
     QFileDialog dialog(0, caption);
 
     if (isdir) {
@@ -430,3 +410,4 @@ QString myGetFileName(bool isdir, QString caption, bool filenosave)
     }
     return QString();
 }
+
