@@ -45,7 +45,7 @@
 #include <QShortcut>
 #include <QTimer>
 
-#include "debuglog.h"
+#include "log.h"
 #include "pathut.h"
 #include "internfile.h"
 #include "recoll.h"
@@ -195,7 +195,7 @@ void Preview::emitShowPrev()
 
 void Preview::closeEvent(QCloseEvent *e)
 {
-    LOGDEB(("Preview::closeEvent. m_loading %d\n", m_loading));
+    LOGDEB("Preview::closeEvent. m_loading "  << (m_loading) << "\n" );
     if (m_loading) {
         CancelCheck::instance().setCancel();
         e->ignore();
@@ -226,11 +226,10 @@ bool Preview::eventFilter(QObject *target, QEvent *event)
 {
     if (event->type() != QEvent::KeyPress) {
 #if 0
-        LOGDEB(("Preview::eventFilter(): %s\n", eventTypeToStr(event->type())));
+        LOGDEB("Preview::eventFilter(): "  << (eventTypeToStr(event->type())) << "\n" );
         if (event->type() == QEvent::MouseButtonRelease) {
             QMouseEvent *mev = (QMouseEvent *)event;
-            LOGDEB(("Mouse: GlobalY %d y %d\n", mev->globalY(),
-                    mev->y()));
+            LOGDEB("Mouse: GlobalY "  << (mev->globalY()) << " y "  << (mev->y()) << "\n" );
         }
 #endif
         return false;
@@ -241,7 +240,7 @@ bool Preview::eventFilter(QObject *target, QEvent *event)
 
     if (m_dynSearchActive) {
         if (keyEvent->key() == Qt::Key_F3) {
-            LOGDEB2(("Preview::eventFilter: got F3\n"));
+            LOGDEB2("Preview::eventFilter: got F3\n" );
             doSearch(searchTextCMB->currentText(), true, 
                      (keyEvent->modifiers() & Qt::ShiftModifier) != 0);
             return true;
@@ -254,18 +253,18 @@ bool Preview::eventFilter(QObject *target, QEvent *event)
             if (keyEvent->key() == Qt::Key_Slash ||
                 (keyEvent->key() == Qt::Key_F &&
                  (keyEvent->modifiers() & Qt::ControlModifier))) {
-                LOGDEB2(("Preview::eventFilter: got / or C-F\n"));
+                LOGDEB2("Preview::eventFilter: got / or C-F\n" );
                 searchTextCMB->setFocus();
                 m_dynSearchActive = true;
                 return true;
             } else if (keyEvent->key() == Qt::Key_Space) {
-                LOGDEB2(("Preview::eventFilter: got Space\n"));
+                LOGDEB2("Preview::eventFilter: got Space\n" );
                 int value = edit->verticalScrollBar()->value();
                 value += edit->verticalScrollBar()->pageStep();
                 edit->verticalScrollBar()->setValue(value);
                 return true;
             } else if (keyEvent->key() == Qt::Key_Backspace) {
-                LOGDEB2(("Preview::eventFilter: got Backspace\n"));
+                LOGDEB2("Preview::eventFilter: got Backspace\n" );
                 int value = edit->verticalScrollBar()->value();
                 value -= edit->verticalScrollBar()->pageStep();
                 edit->verticalScrollBar()->setValue(value);
@@ -279,8 +278,7 @@ bool Preview::eventFilter(QObject *target, QEvent *event)
 
 void Preview::searchTextChanged(const QString & text)
 {
-    LOGDEB1(("Search line text changed. text: '%s'\n", 
-             (const char *)text.toUtf8()));
+    LOGDEB1("Search line text changed. text: '"  << ((const char *)text.toUtf8()) << "'\n" );
     m_searchTextFromIndex = -1;
     if (text.isEmpty()) {
         m_dynSearchActive = false;
@@ -294,13 +292,13 @@ void Preview::searchTextChanged(const QString & text)
 
 void Preview::searchTextFromIndex(int idx)
 {
-    LOGDEB1(("search line from index %d\n", idx));
+    LOGDEB1("search line from index "  << (idx) << "\n" );
     m_searchTextFromIndex = idx;
 }
 
 PreviewTextEdit *Preview::currentEditor()
 {
-    LOGDEB2(("Preview::currentEditor()\n"));
+    LOGDEB2("Preview::currentEditor()\n" );
     QWidget *tw = pvTab->currentWidget();
     PreviewTextEdit *edit = 0;
     if (tw) {
@@ -325,9 +323,7 @@ void Preview::emitSaveDocToFile()
 void Preview::doSearch(const QString &_text, bool next, bool reverse, 
                        bool wordOnly)
 {
-    LOGDEB(("Preview::doSearch: text [%s] idx %d next %d rev %d word %d\n", 
-            (const char *)_text.toUtf8(), m_searchTextFromIndex, int(next), 
-            int(reverse), int(wordOnly)));
+    LOGDEB("Preview::doSearch: text ["  << ((const char *)_text.toUtf8()) << "] idx "  << (m_searchTextFromIndex) << " next "  << (int(next)) << " rev "  << (int(reverse)) << " word "  << (int(wordOnly)) << "\n" );
     QString text = _text;
 
     bool matchCase = matchCheck->isChecked();
@@ -339,7 +335,7 @@ void Preview::doSearch(const QString &_text, bool next, bool reverse,
 
     if (text.isEmpty() || m_searchTextFromIndex != -1) {
         if (!edit->m_plaintorich->haveAnchors()) {
-            LOGDEB(("NO ANCHORS\n"));
+            LOGDEB("NO ANCHORS\n" );
             return;
         }
         // The combobox indices are equal to the search ugroup indices
@@ -350,7 +346,7 @@ void Preview::doSearch(const QString &_text, bool next, bool reverse,
             edit->m_plaintorich->nextAnchorNum(m_searchTextFromIndex);
         }
         QString aname = edit->m_plaintorich->curAnchorName();
-        LOGDEB(("Calling scrollToAnchor(%s)\n", (const char *)aname.toUtf8()));
+        LOGDEB("Calling scrollToAnchor("  << ((const char *)aname.toUtf8()) << ")\n" );
         edit->scrollToAnchor(aname);
         // Position the cursor approximately at the anchor (top of
         // viewport) so that searches start from here
@@ -370,7 +366,7 @@ void Preview::doSearch(const QString &_text, bool next, bool reverse,
         edit->setTextCursor(cursor);
     }
     Chrono chron;
-    LOGDEB(("Preview::doSearch: first find call\n"));
+    LOGDEB("Preview::doSearch: first find call\n" );
     QTextDocument::FindFlags flags = 0;
     if (reverse)
         flags |= QTextDocument::FindBackward;
@@ -379,21 +375,19 @@ void Preview::doSearch(const QString &_text, bool next, bool reverse,
     if (matchCase)
         flags |= QTextDocument::FindCaseSensitively;
     bool found = edit->find(text, flags);
-    LOGDEB(("Preview::doSearch: first find call return: found %d %.2f S\n", 
-            found, chron.secs()));
+    LOGDEB("Preview::doSearch: first find call return: found "  << (found) << " "  << (chron.secs()) << " S\n" );
     // If not found, try to wrap around. 
     if (!found) { 
-        LOGDEB(("Preview::doSearch: wrapping around\n"));
+        LOGDEB("Preview::doSearch: wrapping around\n" );
         if (reverse) {
             edit->moveCursor (QTextCursor::End);
         } else {
             edit->moveCursor (QTextCursor::Start);
         }
-        LOGDEB(("Preview::doSearch: 2nd find call\n"));
+        LOGDEB("Preview::doSearch: 2nd find call\n" );
         chron.restart();
         found = edit->find(text, flags);
-        LOGDEB(("Preview::doSearch: 2nd find call return found %d %.2f S\n",
-                found, chron.secs()));
+        LOGDEB("Preview::doSearch: 2nd find call return found "  << (found) << " "  << (chron.secs()) << " S\n" );
     }
 
     if (found) {
@@ -403,37 +397,37 @@ void Preview::doSearch(const QString &_text, bool next, bool reverse,
             QApplication::beep();
         m_canBeep = false;
     }
-    LOGDEB(("Preview::doSearch: return\n"));
+    LOGDEB("Preview::doSearch: return\n" );
 }
 
 void Preview::nextPressed()
 {
-    LOGDEB2(("Preview::nextPressed\n"));
+    LOGDEB2("Preview::nextPressed\n" );
     doSearch(searchTextCMB->currentText(), true, false);
 }
 
 void Preview::prevPressed()
 {
-    LOGDEB2(("Preview::prevPressed\n"));
+    LOGDEB2("Preview::prevPressed\n" );
     doSearch(searchTextCMB->currentText(), true, true);
 }
 
 // Called when user clicks on tab
 void Preview::currentChanged(int index)
 {
-    LOGDEB2(("PreviewTextEdit::currentChanged\n"));
+    LOGDEB2("PreviewTextEdit::currentChanged\n" );
     QWidget *tw = pvTab->widget(index);
     PreviewTextEdit *edit = 
         tw->findChild<PreviewTextEdit*>("pvEdit");
-    LOGDEB1(("Preview::currentChanged(). Editor: %p\n", edit));
+    LOGDEB1("Preview::currentChanged(). Editor: "  << (edit) << "\n" );
     
     if (edit == 0) {
-        LOGERR(("Editor child not found\n"));
+        LOGERR("Editor child not found\n" );
         return;
     }
     edit->setFocus();
     // Disconnect the print signal and reconnect it to the current editor
-    LOGDEB(("Disconnecting reconnecting print signal\n"));
+    LOGDEB("Disconnecting reconnecting print signal\n" );
     disconnect(this, SIGNAL(printCurrentPreviewRequest()), 0, 0);
     connect(this, SIGNAL(printCurrentPreviewRequest()), edit, SLOT(print()));
     edit->installEventFilter(this);
@@ -444,7 +438,7 @@ void Preview::currentChanged(int index)
 
 void Preview::closeCurrentTab()
 {
-    LOGDEB1(("Preview::closeCurrentTab: m_loading %d\n", m_loading));
+    LOGDEB1("Preview::closeCurrentTab: m_loading "  << (m_loading) << "\n" );
     if (m_loading) {
         CancelCheck::instance().setCancel();
         return;
@@ -461,7 +455,7 @@ void Preview::closeCurrentTab()
 
 PreviewTextEdit *Preview::addEditorTab()
 {
-    LOGDEB1(("PreviewTextEdit::addEditorTab()\n"));
+    LOGDEB1("PreviewTextEdit::addEditorTab()\n" );
     QWidget *anon = new QWidget((QWidget *)pvTab);
     QVBoxLayout *anonLayout = new QVBoxLayout(anon); 
     PreviewTextEdit *editor = new PreviewTextEdit(anon, "pvEdit", this);
@@ -475,7 +469,7 @@ PreviewTextEdit *Preview::addEditorTab()
 
 void Preview::setCurTabProps(const Rcl::Doc &doc, int docnum)
 {
-    LOGDEB1(("Preview::setCurTabProps\n"));
+    LOGDEB1("Preview::setCurTabProps\n" );
     QString title;
     string ctitle;
     if (doc.getmeta(Rcl::Doc::keytt, &ctitle) && !ctitle.empty()) {
@@ -497,7 +491,7 @@ void Preview::setCurTabProps(const Rcl::Doc &doc, int docnum)
         struct tm *tm = localtime(&mtime);
         strftime(datebuf, 99, "%Y-%m-%d %H:%M:%S", tm);
     }
-    LOGDEB(("Doc.url: [%s]\n", doc.url.c_str()));
+    LOGDEB("Doc.url: ["  << (doc.url) << "]\n" );
     string url;
     printableUrl(theconfig->getDefCharset(), doc.url, url);
     string tiptxt = url + string("\n");
@@ -517,10 +511,10 @@ void Preview::setCurTabProps(const Rcl::Doc &doc, int docnum)
 
 bool Preview::makeDocCurrent(const Rcl::Doc& doc, int docnum, bool sametab)
 {
-    LOGDEB(("Preview::makeDocCurrent: %s\n", doc.url.c_str()));
+    LOGDEB("Preview::makeDocCurrent: "  << (doc.url) << "\n" );
 
     if (m_loading) {
-        LOGERR(("Already loading\n"));
+        LOGERR("Already loading\n" );
         return false;
     }
 
@@ -609,7 +603,7 @@ public:
 
 bool Preview::loadDocInCurrentTab(const Rcl::Doc &idoc, int docnum)
 {
-    LOGDEB1(("Preview::loadDocInCurrentTab()\n"));
+    LOGDEB1("Preview::loadDocInCurrentTab()\n" );
 
     LoadGuard guard(&m_loading);
     CancelCheck::instance().setCancel(false);
@@ -647,10 +641,7 @@ bool Preview::loadDocInCurrentTab(const Rcl::Doc &idoc, int docnum)
             progress.show();
     }
 
-    LOGDEB(("loadDocInCurrentTab: after file load: cancel %d status %d"
-            " text length %d\n", 
-            CancelCheck::instance().cancelState(), lthr.status,
-            lthr.fdoc.text.length()));
+    LOGDEB("loadDocInCurrentTab: after file load: cancel "  << (CancelCheck::instance().cancelState()) << " status "  << (lthr.status) << " text length "  << (lthr.fdoc.text.length()) << "\n" );
 
     if (CancelCheck::instance().cancelState())
         return false;
@@ -719,10 +710,10 @@ bool Preview::loadDocInCurrentTab(const Rcl::Doc &idoc, int docnum)
         qApp->processEvents();
 
         if (inputishtml) {
-            LOGDEB1(("Preview: got html %s\n", lthr.fdoc.text.c_str()));
+            LOGDEB1("Preview: got html "  << (lthr.fdoc.text) << "\n" );
             editor->m_plaintorich->set_inputhtml(true);
         } else {
-            LOGDEB1(("Preview: got plain %s\n", lthr.fdoc.text.c_str()));
+            LOGDEB1("Preview: got plain "  << (lthr.fdoc.text) << "\n" );
             editor->m_plaintorich->set_inputhtml(false);
         }
 
@@ -753,8 +744,7 @@ bool Preview::loadDocInCurrentTab(const Rcl::Doc &idoc, int docnum)
             }
         }
     } else {
-        LOGDEB(("Preview: no hilighting, loading %d bytes\n",
-                int(lthr.fdoc.text.size())));
+        LOGDEB("Preview: no hilighting, loading "  << (int(lthr.fdoc.text.size())) << " bytes\n" );
         // No plaintorich() call.  In this case, either the text is
         // html and the html quoting is hopefully correct, or it's
         // plain-text and there is no need to escape special
@@ -804,7 +794,7 @@ bool Preview::loadDocInCurrentTab(const Rcl::Doc &idoc, int docnum)
 
         if (progress.wasCanceled()) {
             editor->append("<b>Cancelled !</b>");
-            LOGDEB(("loadDocInCurrentTab: cancelled in editor load\n"));
+            LOGDEB("loadDocInCurrentTab: cancelled in editor load\n" );
             break;
         }
     }
@@ -836,7 +826,7 @@ bool Preview::loadDocInCurrentTab(const Rcl::Doc &idoc, int docnum)
         if (fn.empty() || !idoc.ipath.empty()) {
             TempFile temp = lthr.tmpimg;
             if (temp) {
-                LOGDEB1(("Preview: load: got temp file from internfile\n"));
+                LOGDEB1("Preview: load: got temp file from internfile\n" );
             } else if (!FileInterner::idocToFile(temp, string(), 
                                                  theconfig, idoc)) {
                 temp.reset(); // just in case.
@@ -868,7 +858,7 @@ bool Preview::loadDocInCurrentTab(const Rcl::Doc &idoc, int docnum)
         // Position to the first query term
         if (editor->m_plaintorich->haveAnchors()) {
             QString aname = editor->m_plaintorich->curAnchorName();
-            LOGDEB2(("Call movetoanchor(%s)\n", (const char *)aname.toUtf8()));
+            LOGDEB2("Call movetoanchor("  << ((const char *)aname.toUtf8()) << ")\n" );
             editor->scrollToAnchor(aname);
             // Position the cursor approximately at the anchor (top of
             // viewport) so that searches start from here
@@ -886,7 +876,7 @@ bool Preview::loadDocInCurrentTab(const Rcl::Doc &idoc, int docnum)
 
     editor->setFocus();
     emit(previewExposed(this, m_searchId, docnum));
-    LOGDEB(("loadDocInCurrentTab: returning true\n"));
+    LOGDEB("loadDocInCurrentTab: returning true\n" );
     return true;
 }
 
@@ -905,7 +895,7 @@ PreviewTextEdit::PreviewTextEdit(QWidget* parent, const char* nm, Preview *pv)
 
 void PreviewTextEdit::createPopupMenu(const QPoint& pos)
 {
-    LOGDEB1(("PreviewTextEdit::createPopupMenu()\n"));
+    LOGDEB1("PreviewTextEdit::createPopupMenu()\n" );
     QMenu *popup = new QMenu(this);
     switch (m_curdsp) {
     case PTE_DSPTXT:
@@ -944,7 +934,7 @@ void PreviewTextEdit::createPopupMenu(const QPoint& pos)
 // Display main text
 void PreviewTextEdit::displayText()
 {
-    LOGDEB1(("PreviewTextEdit::displayText()\n"));
+    LOGDEB1("PreviewTextEdit::displayText()\n" );
     if (m_format == Qt::PlainText)
         setPlainText(m_richtxt);
     else
@@ -955,7 +945,7 @@ void PreviewTextEdit::displayText()
 // Display field values
 void PreviewTextEdit::displayFields()
 {
-    LOGDEB1(("PreviewTextEdit::displayFields()\n"));
+    LOGDEB1("PreviewTextEdit::displayFields()\n" );
 
     QString txt = "<html><head></head><body>\n";
     txt += "<b>" + QString::fromLocal8Bit(m_url.c_str());
@@ -977,7 +967,7 @@ void PreviewTextEdit::displayFields()
 
 void PreviewTextEdit::displayImage()
 {
-    LOGDEB1(("PreviewTextEdit::displayImage()\n"));
+    LOGDEB1("PreviewTextEdit::displayImage()\n" );
     if (m_image.isNull())
         displayText();
 
@@ -995,7 +985,7 @@ void PreviewTextEdit::displayImage()
 
 void PreviewTextEdit::mouseDoubleClickEvent(QMouseEvent *event)
 {
-    LOGDEB2(("PreviewTextEdit::mouseDoubleClickEvent\n"));
+    LOGDEB2("PreviewTextEdit::mouseDoubleClickEvent\n" );
     QTextEdit::mouseDoubleClickEvent(event);
     if (textCursor().hasSelection() && m_preview)
         m_preview->emitWordSelect(textCursor().selectedText());
@@ -1003,7 +993,7 @@ void PreviewTextEdit::mouseDoubleClickEvent(QMouseEvent *event)
 
 void PreviewTextEdit::print()
 {
-    LOGDEB(("PreviewTextEdit::print\n"));
+    LOGDEB("PreviewTextEdit::print\n" );
     if (!m_preview)
         return;
         
@@ -1016,3 +1006,4 @@ void PreviewTextEdit::print()
     QTextEdit::print(&printer);
 #endif
 }
+
