@@ -24,7 +24,7 @@
 
 #include "qxtconfirmationmessage.h"
 
-#include "debuglog.h"
+#include "log.h"
 #include "fileudi.h"
 #include "execmd.h"
 #include "transcode.h"
@@ -33,6 +33,7 @@
 #include "internfile.h"
 #include "rclmain_w.h"
 #include "rclzg.h"
+#include "pathut.h"
 
 using namespace std;
 
@@ -47,9 +48,7 @@ void RclMain::viewUrl()
 	return;
 
     QUrl qurl(m_urltoview);
-    LOGDEB(("RclMain::viewUrl: Path [%s] fragment [%s]\n", 
-	    (const char *)qurl.path().toLocal8Bit(),
-	    (const char *)qurl.fragment().toLocal8Bit()));
+    LOGDEB("RclMain::viewUrl: Path ["  << ((const char *)qurl.path().toLocal8Bit()) << "] fragment ["  << ((const char *)qurl.fragment().toLocal8Bit()) << "]\n" );
 
     /* In theory, the url might not be for a file managed by the fs
        indexer so that the make_udi() call here would be
@@ -68,9 +67,9 @@ void RclMain::viewUrl()
     // StartNativeViewer needs a db source to call getEnclosing() on.
     Rcl::Query *query = new Rcl::Query(rcldb);
     DocSequenceDb *src = 
-	new DocSequenceDb(STD_SHARED_PTR<Rcl::Query>(query), "", 
-			  STD_SHARED_PTR<Rcl::SearchData>(new Rcl::SearchData));
-    m_source = STD_SHARED_PTR<DocSequence>(src);
+	new DocSequenceDb(std::shared_ptr<Rcl::Query>(query), "", 
+			  std::shared_ptr<Rcl::SearchData>(new Rcl::SearchData));
+    m_source = std::shared_ptr<DocSequence>(src);
 
 
     // Start a native viewer if the mimetype has one defined, else a
@@ -124,7 +123,7 @@ static bool lookForHtmlBrowser(string &exefile)
 
 void RclMain::openWith(Rcl::Doc doc, string cmdspec)
 {
-    LOGDEB(("RclMain::openWith: %s\n", cmdspec.c_str()));
+    LOGDEB("RclMain::openWith: "  << (cmdspec) << "\n" );
 
     // Split the command line
     vector<string> lcmd;
@@ -147,6 +146,9 @@ void RclMain::openWith(Rcl::Doc doc, string cmdspec)
     // Try to keep the letters used more or less consistent with the reslist
     // paragraph format.
     map<string, string> subs;
+#ifdef _WIN32
+    path_backslashize(fn);
+#endif
     subs["F"] = fn;
     subs["f"] = fn;
     subs["U"] = url_encode(url);
@@ -159,11 +161,10 @@ void RclMain::startNativeViewer(Rcl::Doc doc, int pagenum, QString term)
 {
     string apptag;
     doc.getmeta(Rcl::Doc::keyapptg, &apptag);
-    LOGDEB(("RclMain::startNativeViewer: mtype [%s] apptag [%s] page %d "
-	    "term [%s] url [%s] ipath [%s]\n", 
-	    doc.mimetype.c_str(), apptag.c_str(), pagenum, 
-	    (const char *)(term.toUtf8()), doc.url.c_str(), doc.ipath.c_str()
-	       ));
+    LOGDEB("RclMain::startNativeViewer: mtype [" << doc.mimetype <<
+           "] apptag ["  << apptag << "] page "  << pagenum << " term ["  <<
+           qs2utf8s(term) << "] url ["  << doc.url << "] ipath [" <<
+           doc.ipath << "]\n");
 
     // Look for appropriate viewer
     string cmdplusattr = theconfig->getMimeViewerDef(doc.mimetype, apptag, 
@@ -180,9 +181,15 @@ void RclMain::startNativeViewer(Rcl::Doc doc, int pagenum, QString term)
     string cmd;
     theconfig->valueSplitAttributes(cmdplusattr, cmd, viewerattrs);
     bool ignoreipath = false;
+    int execwflags = 0;
     if (viewerattrs.get("ignoreipath", cmdplusattr))
         ignoreipath = stringToBool(cmdplusattr);
-
+    if (viewerattrs.get("maximize", cmdplusattr)) {
+        if (stringToBool(cmdplusattr)) {
+            execwflags |= ExecCmd::EXF_MAXIMIZED;
+        }
+    }
+    
     // Split the command line
     vector<string> lcmd;
     if (!stringToStrings(cmd, lcmd)) {
@@ -293,8 +300,7 @@ void RclMain::startNativeViewer(Rcl::Doc doc, int pagenum, QString term)
     bool enterHistory = false;
     bool istempfile = false;
     
-    LOGDEB(("RclMain::startNV: groksipath %d wantsf %d wantsparentf %d\n",
-            groksipath, wantsfile, wantsparentfile));
+    LOGDEB("RclMain::startNV: groksipath "  << (groksipath) << " wantsf "  << (wantsfile) << " wantsparentf "  << (wantsparentfile) << "\n" );
 
     // If the command wants a file but this is not a file url, or
     // there is an ipath that it won't understand, we need a temp file:
@@ -383,6 +389,9 @@ void RclMain::startNativeViewer(Rcl::Doc doc, int pagenum, QString term)
     // paragraph format.
     map<string, string> subs;
     subs["D"] = efftime;
+#ifdef _WIN32
+    path_backslashize(fn);
+#endif
     subs["f"] = fn;
     subs["F"] = fn;
     subs["i"] = FileInterner::getLastIpathElt(doc.ipath);
@@ -396,20 +405,20 @@ void RclMain::startNativeViewer(Rcl::Doc doc, int pagenum, QString term)
          it != doc.meta.end(); it++) {
         subs[it->first] = it->second;
     }
-    execViewer(subs, enterHistory, execpath, lcmd, cmd, doc);
+    execViewer(subs, enterHistory, execpath, lcmd, cmd, doc, execwflags);
 }
 
 void RclMain::execViewer(const map<string, string>& subs, bool enterHistory,
                          const string& execpath,
                          const vector<string>& _lcmd, const string& cmd,
-                         Rcl::Doc doc)
+                         Rcl::Doc doc, int flags)
 {
     string ncmd;
     vector<string> lcmd;
     for (vector<string>::const_iterator it = _lcmd.begin(); 
          it != _lcmd.end(); it++) {
         pcSubst(*it, ncmd, subs);
-        LOGDEB(("%s->%s\n", it->c_str(), ncmd.c_str()));
+        LOGDEB(""  << *it << "->"  << (ncmd) << "\n" );
         lcmd.push_back(ncmd);
     }
 
@@ -436,7 +445,7 @@ void RclMain::execViewer(const map<string, string>& subs, bool enterHistory,
     zg_send_event(ZGSEND_OPEN, doc);
 
     // We keep pushing back and never deleting. This can't be good...
-    ExecCmd *ecmd = new ExecCmd(ExecCmd::EXF_SHOWWINDOW);
+    ExecCmd *ecmd = new ExecCmd(ExecCmd::EXF_SHOWWINDOW | flags);
     m_viewers.push_back(ecmd);
     ecmd->startExec(execpath, lcmd, false, false);
 }
@@ -457,8 +466,7 @@ void RclMain::startManual(const string& index)
     webhelp = path_cat(webhelp, "index.html");
     bool has_wh = path_exists(webhelp);
     
-    LOGDEB(("RclMain::startManual: help index is %s\n", 
-	    index.empty()?"(null)":index.c_str()));
+    LOGDEB("RclMain::startManual: help index is "  << (index.empty()?"(null)":index) << "\n" );
     bool indexempty = index.empty();
 
 #ifdef _WIN32
@@ -481,3 +489,4 @@ void RclMain::startManual(const string& index)
     doc.mimetype = "text/html";
     startNativeViewer(doc);
 }
+
