@@ -35,7 +35,7 @@
 #include <QClipboard>
 #include <QKeyEvent>
 
-#include "debuglog.h"
+#include "log.h"
 #include "recoll.h"
 #include "spell_w.h"
 #include "guiutils.h"
@@ -47,10 +47,6 @@
 #include "execmd.h"
 #include "indexer.h"
 
-#ifdef RCL_USE_ASPELL
-#include "rclaspell.h"
-#endif
-
 using std::list;
 using std::multimap;
 using std::string;
@@ -64,14 +60,8 @@ void SpellW::init()
     m_c2t.push_back(TYPECMB_REG);
     expTypeCMB->addItem(tr("Stem expansion"));
     m_c2t.push_back(TYPECMB_STEM);
-#ifdef RCL_USE_ASPELL
-    bool noaspell = false;
-    theconfig->getConfParam("noaspell", &noaspell);
-    if (!noaspell) {
-	expTypeCMB->addItem(tr("Spelling/Phonetic"));
-	m_c2t.push_back(TYPECMB_ASPELL);
-    }
-#endif
+    expTypeCMB->addItem(tr("Spelling/Phonetic"));
+    m_c2t.push_back(TYPECMB_SPELL);
     expTypeCMB->addItem(tr("Show index statistics"));
     m_c2t.push_back(TYPECMB_STATS);
 
@@ -147,7 +137,7 @@ void SpellW::doExpand()
     string reason;
     if (!maybeOpenDb(reason)) {
 	QMessageBox::critical(0, "Recoll", QString(reason.c_str()));
-	LOGDEB(("SpellW::doExpand: db error: %s\n", reason.c_str()));
+	LOGDEB("SpellW::doExpand: db error: "  << (reason) << "\n" );
 	return;
     }
 
@@ -178,7 +168,7 @@ void SpellW::doExpand()
 	string l_stemlang = qs2utf8s(stemLangCMB->currentText());
 
 	if (!rcldb->termMatch(mt, l_stemlang, expr, res, maxexpand)) {
-	    LOGERR(("SpellW::doExpand:rcldb::termMatch failed\n"));
+	    LOGERR("SpellW::doExpand:rcldb::termMatch failed\n" );
 	    return;
 	}
         statsLBL->setText(tr("Index: %1 documents, average length %2 terms."
@@ -189,37 +179,19 @@ void SpellW::doExpand()
         
     break;
 
-#ifdef RCL_USE_ASPELL
-    case TYPECMB_ASPELL: 
+    case TYPECMB_SPELL: 
     {
-	LOGDEB(("SpellW::doExpand: aspelling\n"));
-	if (!aspell) {
-	    QMessageBox::warning(0, "Recoll",
-				 tr("Aspell init failed. "
-				    "Aspell not installed?"));
-	    LOGDEB(("SpellW::doExpand: aspell init error\n"));
-	    return;
+	LOGDEB("SpellW::doExpand: spelling [" << expr << "]\n" );
+	vector<string> suggs;
+	if (!rcldb->getSpellingSuggestions(expr, suggs)) {
+	    QMessageBox::warning(0, "Recoll", tr("Spell expansion error. "));
 	}
-	list<string> suggs;
-	if (!aspell->suggest(*rcldb, expr, suggs, reason)) {
-	    QMessageBox::warning(0, "Recoll",
-				 tr("Aspell expansion error. "));
-	    LOGERR(("SpellW::doExpand:suggest failed: %s\n", reason.c_str()));
-	}
-	for (list<string>::const_iterator it = suggs.begin(); 
-	     it != suggs.end(); it++) 
-	    res.entries.push_back(Rcl::TermMatchEntry(*it));
-#ifdef TESTING_XAPIAN_SPELL
-	string rclsugg = rcldb->getSpellingSuggestion(expr);
-	if (!rclsugg.empty()) {
-	    res.entries.push_back(Rcl::TermMatchEntry("Xapian spelling:"));
-	    res.entries.push_back(Rcl::TermMatchEntry(rclsugg));
-	}
-#endif // TESTING_XAPIAN_SPELL
+	for (const auto& it : suggs) {
+	    res.entries.push_back(Rcl::TermMatchEntry(it));
+        }
         statsLBL->setText(tr("%1 results").arg(res.entries.size()));
     }
     break;
-#endif // RCL_USE_ASPELL
 
     case TYPECMB_STATS: 
     {
@@ -229,7 +201,6 @@ void SpellW::doExpand()
     break;
     }
 
-
     if (res.entries.empty()) {
         resTW->setItem(0, 0, new QTableWidgetItem(tr("No expansion found")));
     } else {
@@ -253,7 +224,7 @@ void SpellW::doExpand()
 
 	for (vector<Rcl::TermMatchEntry>::iterator it = res.entries.begin(); 
 	     it != res.entries.end(); it++) {
-	    LOGDEB2(("SpellW::expand: %6d [%s]\n", it->wcf, it->term.c_str()));
+	    LOGDEB2("SpellW::expand: "  << (it->wcf) << " ["  << (it->term) << "]\n" );
 	    char num[30];
 	    if (it->wcf)
 		sprintf(num, "%d / %d",  it->docs, it->wcf);
@@ -275,7 +246,7 @@ void SpellW::showStats()
 
     Rcl::DbStats res;
     if (!rcldb->dbStats(res)) {
-	LOGERR(("SpellW::doExpand:rcldb::dbStats failed\n"));
+	LOGERR("SpellW::doExpand:rcldb::dbStats failed\n" );
 	return;
     }
 
@@ -362,10 +333,10 @@ void SpellW::showStats()
 	string reason;
 	string q = string("mime:") + *it;
 	Rcl::SearchData *sd = wasaStringToRcl(theconfig, "", q, reason);
-	STD_SHARED_PTR<Rcl::SearchData> rq(sd);
+	std::shared_ptr<Rcl::SearchData> rq(sd);
 	Rcl::Query query(rcldb);
 	if (!query.setQuery(rq)) {
-	    LOGERR(("Query setup failed: %s",query.getReason().c_str()));
+	    LOGERR("Query setup failed: "  << (query.getReason()) << "" );
 	    return;
 	}
 	int cnt = query.getResCnt();
@@ -521,3 +492,4 @@ bool SpellW::eventFilter(QObject *target, QEvent *event)
     }
     return false;
 }
+
