@@ -60,12 +60,12 @@
  * </SD>
  */ 
 
-#include MEMORY_INCLUDE
+#include <memory>
 #include "searchdata.h"
 
 // Parsing XML from advanced search history or saved advanced search to to
 // SearchData structure:
-STD_SHARED_PTR<Rcl::SearchData> xmlToSearchData(const string& xml);
+std::shared_ptr<Rcl::SearchData> xmlToSearchData(const string& xml);
 
 // Parsing XML from saved simple search to ssearch parameters
 struct SSearchDef {
