@@ -31,7 +31,7 @@
 #include "rclconfig.h"
 #include "pathut.h"
 #include "rclinit.h"
-#include "debuglog.h"
+#include "log.h"
 #include "wasatorcl.h"
 #include "internfile.h"
 #include "wipedir.h"
@@ -342,7 +342,7 @@ endopts:
 	return 1;
     }
 
-    STD_SHARED_PTR<Rcl::SearchData> rq(sd);
+    std::shared_ptr<Rcl::SearchData> rq(sd);
     Rcl::Query query(&rcldb);
     if (op_flags & OPT_S) {
 	query.setSortBy(sortfield, (op_flags & OPT_D) ? false : true);
@@ -427,3 +427,4 @@ endopts:
 
     return 0;
 }
+
