@@ -22,6 +22,7 @@
 #include <stdlib.h>
 #include <math.h>
 #include <time.h>
+#include <stdint.h>
 
 #include <sstream>
 #include <list>
@@ -31,12 +32,13 @@ using std::list;
 
 #include "cstr.h"
 #include "reslistpager.h"
-#include "debuglog.h"
+#include "log.h"
 #include "rclconfig.h"
 #include "smallut.h"
 #include "rclutil.h"
 #include "plaintorich.h"
 #include "mimehandler.h"
+#include "transcode.h"
 
 // Default highlighter. No need for locking, this is query-only.
 static const string cstr_hlfontcolor("<span style='color: blue;'>");
@@ -67,13 +69,12 @@ ResListPager::ResListPager(int pagesize)
 void ResListPager::resultPageNext()
 {
     if (!m_docSource) {
-	LOGDEB(("ResListPager::resultPageNext: null source\n"));
+	LOGDEB("ResListPager::resultPageNext: null source\n" );
 	return;
     }
 
     int resCnt = m_docSource->getResCnt();
-    LOGDEB(("ResListPager::resultPageNext: rescnt %d, winfirst %d\n", 
-	    resCnt, m_winfirst));
+    LOGDEB("ResListPager::resultPageNext: rescnt "  << (resCnt) << ", winfirst "  << (m_winfirst) << "\n" );
 
     if (m_winfirst < 0) {
 	m_winfirst = 0;
@@ -125,13 +126,12 @@ static string maybeEscapeHtml(const string& fld)
 void ResListPager::resultPageFor(int docnum)
 {
     if (!m_docSource) {
-	LOGDEB(("ResListPager::resultPageFor: null source\n"));
+	LOGDEB("ResListPager::resultPageFor: null source\n" );
 	return;
     }
 
     int resCnt = m_docSource->getResCnt();
-    LOGDEB(("ResListPager::resultPageFor(%d): rescnt %d, winfirst %d\n", 
-	    docnum, resCnt, m_winfirst));
+    LOGDEB("ResListPager::resultPageFor("  << (docnum) << "): rescnt "  << (resCnt) << ", winfirst "  << (m_winfirst) << "\n" );
     m_winfirst = (docnum / m_pagesize) * m_pagesize;
 
     // Get the next page of results.
@@ -193,22 +193,24 @@ void ResListPager::displayDoc(RclConfig *config, int i, Rcl::Doc& doc,
     int docnumforlinks = m_winfirst + 1 + i;
     sprintf(numbuf, "%d", docnumforlinks);
 
-    // Document date: either doc or file modification time
-    char datebuf[100];
-    datebuf[0] = 0;
+    // Document date: either doc or file modification times
+    string datebuf;
     if (!doc.dmtime.empty() || !doc.fmtime.empty()) {
+        char cdate[100];
+        cdate[0] = 0;
 	time_t mtime = doc.dmtime.empty() ?
 	    atoll(doc.fmtime.c_str()) : atoll(doc.dmtime.c_str());
 	struct tm *tm = localtime(&mtime);
-	strftime(datebuf, 99, dateFormat().c_str(), tm);
+	strftime(cdate, 99, dateFormat().c_str(), tm);
+        transcode(cdate, datebuf, RclConfig::getLocaleCharset(), "UTF-8");
     }
 
     // Size information. We print both doc and file if they differ a lot
-    off_t fsize = -1, dsize = -1;
+    int64_t fsize = -1, dsize = -1;
     if (!doc.dbytes.empty())
-	dsize = static_cast<off_t>(atoll(doc.dbytes.c_str()));
+	dsize = static_cast<int64_t>(atoll(doc.dbytes.c_str()));
     if (!doc.fbytes.empty())
-	fsize =  static_cast<off_t>(atoll(doc.fbytes.c_str()));
+	fsize =  static_cast<int64_t>(atoll(doc.fbytes.c_str()));
     string sizebuf;
     if (dsize > 0) {
 	sizebuf = displayableBytes(dsize);
@@ -324,7 +326,7 @@ void ResListPager::displayDoc(RclConfig *config, int i, Rcl::Doc& doc,
     // the table approach for 1.15 for now (in guiutils.cpp)
 //	chunk << "<br style='clear:both;height:0;line-height:0;'>" << endl;
 
-    LOGDEB2(("Chunk: [%s]\n", (const char *)chunk.rdbuf()->str().c_str()));
+    LOGDEB2("Chunk: ["  << ((const char *)chunk.rdbuf()->str()) << "]\n" );
     append(chunk.rdbuf()->str(), i, doc);
 }
 
@@ -340,13 +342,13 @@ bool ResListPager::getDoc(int num, Rcl::Doc& doc)
 
 void ResListPager::displayPage(RclConfig *config)
 {
-    LOGDEB(("ResListPager::displayPage\n"));
+    LOGDEB("ResListPager::displayPage\n" );
     if (!m_docSource) {
-	LOGDEB(("ResListPager::displayPage: null source\n"));
+	LOGDEB("ResListPager::displayPage: null source\n" );
 	return;
     }
     if (m_winfirst < 0 && !pageEmpty()) {
-	LOGDEB(("ResListPager::displayPage: sequence error: winfirst < 0\n"));
+	LOGDEB("ResListPager::displayPage: sequence error: winfirst < 0\n" );
 	return;
     }
 
@@ -526,3 +528,4 @@ const string &ResListPager::dateFormat()
     return cstr_format;
 }
 
+
