@@ -19,9 +19,10 @@
 
 #include "autoconfig.h"
 
+#include <stdint.h>
 #include <string>
 #include <vector>
-#include MEMORY_INCLUDE
+#include <memory>
 
 #include "cstr.h"
 #include "rcldoc.h"
@@ -53,6 +54,7 @@ using std::vector;
 // reasonable)
 
 class RclConfig;
+class Aspell;
 
 namespace Rcl {
 
@@ -198,27 +200,47 @@ class Db {
     vector<string> getStemLangs();
 
     /** Test word for spelling correction candidate: not too long, no 
-	special chars... */
-    static bool isSpellingCandidate(const string& term)
+     * special chars... 
+     * @param with_aspell test for use with aspell, else for xapian speller
+     */
+    static bool isSpellingCandidate(const string& term, bool with_aspell=true)
     {
 	if (term.empty() || term.length() > 50)
 	    return false;
 	if (has_prefix(term))
 	    return false;
 	Utf8Iter u8i(term);
-	if (TextSplit::isCJK(*u8i)) 
-	    return false;
+        if (with_aspell) {
+            // If spelling with aspell, neither katakana nor other cjk
+            // scripts are candidates
+            if (TextSplit::isCJK(*u8i) || TextSplit::isKATAKANA(*u8i))
+                return false;
+        } else {
+#ifdef TESTING_XAPIAN_SPELL
+            // The Xapian speller (purely proximity-based) can be used
+            // for Katakana (when split as words which is not always
+            // completely feasible because of separator-less
+            // compounds). Currently we don't try to use the Xapian
+            // speller with other scripts with which it would be usable
+            // in the absence of aspell (it would indeed be better
+            // than nothing with e.g. european languages). This would
+            // require a few more config variables, maybe one day.
+            if (!TextSplit::isKATAKANA(*u8i)) {
+                return false;
+            }
+#else
+            return false;
+#endif
+        }
 	if (term.find_first_of(" !\"#$%&()*+,-./0123456789:;<=>?@[\\]^_`{|}~") 
 	    != string::npos)
 	    return false;
 	return true;
     }
 
-
-#ifdef TESTING_XAPIAN_SPELL
     /** Return spelling suggestion */
-    string getSpellingSuggestion(const string& word);
-#endif
+    bool getSpellingSuggestions(const string& word,
+                                std::vector<std::string>& suggs);
 
     /* The next two, only for searchdata, should be somehow hidden */
     /* Return configured stop words */
@@ -489,6 +511,9 @@ private:
     // place for this.
     SynGroups m_syngroups;
 
+    // Aspell object if needed
+    Aspell *m_aspell = nullptr;
+    
     /***************
      * Parameters cached out of the configuration files. Logically const 
      * after init */
@@ -535,7 +560,7 @@ private:
 		      const string& field = cstr_null);
 
     // Flush when idxflushmb is reached
-    bool maybeflush(off_t moretext);
+    bool maybeflush(int64_t moretext);
     bool docExists(const string& uniterm);
 
     /* Copyconst and assignement private and forbidden */
