@@ -29,7 +29,7 @@
 #include <ostream>
 
 #include "rcldb.h"
-#include MEMORY_INCLUDE
+#include <memory>
 #include "smallut.h"
 #include "cstr.h"
 #include "hldata.h"
@@ -178,7 +178,7 @@ private:
     std::vector<std::string>            m_nfiletypes;
     // Autophrase if set. Can't be part of the normal chain because
     // it uses OP_AND_MAYBE
-    STD_SHARED_PTR<SearchDataClauseDist>   m_autophrase;
+    std::shared_ptr<SearchDataClauseDist>   m_autophrase;
 
     // Special stuff produced by input which looks like a clause but means
     // something else (date and size specs)
@@ -493,7 +493,7 @@ private:
 /** Subquery */
 class SearchDataClauseSub : public SearchDataClause {
 public:
-    SearchDataClauseSub(STD_SHARED_PTR<SearchData> sub) 
+    SearchDataClauseSub(std::shared_ptr<SearchData> sub) 
 	: SearchDataClause(SCLT_SUB), m_sub(sub) 
     {
     }
@@ -509,13 +509,13 @@ public:
     {
 	m_sub.get()->getTerms(hldata);
     }
-    virtual STD_SHARED_PTR<SearchData> getSub() {
+    virtual std::shared_ptr<SearchData> getSub() {
         return m_sub;
     }
     virtual void dump(ostream& o) const;
 
 protected:
-    STD_SHARED_PTR<SearchData> m_sub;
+    std::shared_ptr<SearchData> m_sub;
 };
 
 } // Namespace Rcl
