@@ -17,14 +17,14 @@
 
 // Wrapper classes for the socket interface
 
-
-#ifndef TEST_NETCON
 #ifdef BUILDING_RECOLL
 #include "autoconfig.h"
 #else
 #include "config.h"
 #endif
 
+#include "netcon.h"
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -46,24 +46,7 @@
 
 #include <map>
 
-
-#ifdef BUILDING_RECOLL
-#include "debuglog.h"
-
-#else
-
-#define LOGFATAL(X)
-#define LOGERR(X)
-#define LOGINFO(X)
-#define LOGDEB(X)
-#define LOGDEB0(X)
-#define LOGDEB1(X)
-#define LOGDEB2(X)
-#define LOGDEB3(X)
-#define LOGDEB4(X)
-#endif
-
-#include "netcon.h"
+#include "log.h"
 
 using namespace std;
 
@@ -84,15 +67,15 @@ using namespace std;
 static const int one = 1;
 static const int zero = 0;
 
-#define LOGSYSERR(who, call, spar)                  \
-    LOGERR(("%s: %s(%s) errno %d (%s)\n", who, call,            \
-        spar, errno, strerror(errno)))
+#define LOGSYSERR(who, call, spar)                                \
+    LOGERR(who << ": "  << call << "("  << spar << ") errno " <<  \
+           errno << " ("  << strerror(errno) << ")\n")
 
 #ifndef MIN
-#define MIN(a,b) (a<b?a:b)
+#define MIN(a,b) ((a)<(b)?(a):(b))
 #endif
 #ifndef MAX
-#define MAX(a,b) (a>b?a:b)
+#define MAX(a,b) ((a)>(b)?(a):(b))
 #endif
 #ifndef freeZ
 #define freeZ(X) if (X) {free(X);X=0;}
@@ -121,7 +104,7 @@ int Netcon::select1(int fd, int timeo, int write)
         ret = select(fd + 1, &rd, 0, 0, &tv);
     }
     if (!FD_ISSET(fd, &rd)) {
-        LOGDEB2(("Netcon::select1: fd %d timeout\n", fd));
+        LOGDEB2("Netcon::select1: fd "  << (fd) << " timeout\n" );
     }
     return ret;
 }
@@ -188,7 +171,7 @@ int SelectLoop::doLoop()
     for (;;) {
         if (m_selectloopDoReturn) {
             m_selectloopDoReturn = false;
-            LOGDEB(("Netcon::selectloop: returning on request\n"));
+            LOGDEB("Netcon::selectloop: returning on request\n" );
             return m_selectloopReturnValue;
         }
         int nfds;
@@ -203,7 +186,8 @@ int SelectLoop::doLoop()
                 it != m_polldata.end(); it++) {
             NetconP& pll = it->second;
             int fd  = it->first;
-            LOGDEB2(("Selectloop: fd %d flags 0x%x\n", fd, pll->m_wantedEvents));
+            LOGDEB2("Selectloop: fd " << fd << " flags 0x"  <<
+                    pll->m_wantedEvents << "\n");
             if (pll->m_wantedEvents & Netcon::NETCONPOLL_READ) {
                 FD_SET(fd, &rd);
                 nfds = MAX(nfds, fd + 1);
@@ -223,11 +207,11 @@ int SelectLoop::doLoop()
             // Just in case there would still be open fds in there
             // (with no r/w flags set). Should not be needed, but safer
             m_polldata.clear();
-            LOGDEB1(("Netcon::selectloop: no fds\n"));
+            LOGDEB1("Netcon::selectloop: no fds\n" );
             return 0;
         }
 
-        LOGDEB2(("Netcon::selectloop: selecting, nfds = %d\n", nfds));
+        LOGDEB2("Netcon::selectloop: selecting, nfds = " << nfds << "\n");
 
         // Compute the next timeout according to what might need to be
         // done apart from waiting for data
@@ -235,7 +219,7 @@ int SelectLoop::doLoop()
         periodictimeout(&tv);
         // Wait for something to happen
         int ret = select(nfds, &rd, &wd, 0, &tv);
-        LOGDEB2(("Netcon::selectloop: select returns %d\n", ret));
+        LOGDEB2("Netcon::selectloop: select returns "  << (ret) << "\n" );
         if (ret < 0) {
             LOGSYSERR("Netcon::selectloop", "select", "");
             return -1;
@@ -268,9 +252,7 @@ int SelectLoop::doLoop()
             int canread = FD_ISSET(fd, &rd);
             int canwrite = FD_ISSET(fd, &wd);
             bool none = !canread && !canwrite;
-            LOGDEB2(("Netcon::selectloop: fd %d %s %s %s\n", fd,
-                     none ? "blocked" : "can" , canread ? "read" : "",
-                     canwrite ? "write" : ""));
+            LOGDEB2("Netcon::selectloop: fd "  << (fd) << " "  << (none ? "blocked" : "can") << " "  << (canread ? "read" : "") << " "  << (canwrite ? "write" : "") << "\n" );
             if (none) {
                 continue;
             }
@@ -278,7 +260,7 @@ int SelectLoop::doLoop()
             map<int, NetconP>::iterator it = m_polldata.find(fd);
             if (it == m_polldata.end()) {
                 /// This should not happen actually
-                LOGDEB2(("Netcon::selectloop: fd %d not found\n", fd));
+                LOGDEB2("Netcon::selectloop: fd "  << (fd) << " not found\n" );
                 continue;
             }
 
@@ -292,14 +274,13 @@ int SelectLoop::doLoop()
                 pll->m_wantedEvents &= ~Netcon::NETCONPOLL_WRITE;
             }
             if (!(pll->m_wantedEvents & (Netcon::NETCONPOLL_WRITE | Netcon::NETCONPOLL_READ))) {
-                LOGDEB0(("Netcon::selectloop: fd %d has 0x%x mask, erasing\n",
-                         it->first, it->second->m_wantedEvents));
+                LOGDEB0("Netcon::selectloop: fd "  << (it->first) << " has 0x"  << (it->second->m_wantedEvents) << " mask, erasing\n" );
                 m_polldata.erase(it);
             }
         } // fd sweep
 
     } // forever loop
-    LOGERR(("SelectLoop::doLoop: got out of loop !\n"));
+    LOGERR("SelectLoop::doLoop: got out of loop !\n" );
     return -1;
 }
 
@@ -309,7 +290,7 @@ int SelectLoop::addselcon(NetconP con, int events)
     if (!con) {
         return -1;
     }
-    LOGDEB1(("Netcon::addselcon: fd %d\n", con->m_fd));
+    LOGDEB1("Netcon::addselcon: fd "  << (con->m_fd) << "\n" );
     con->set_nonblock(1);
     con->setselevents(events);
     m_polldata[con->m_fd] = con;
@@ -323,10 +304,10 @@ int SelectLoop::remselcon(NetconP con)
     if (!con) {
         return -1;
     }
-    LOGDEB1(("Netcon::remselcon: fd %d\n", con->m_fd));
+    LOGDEB1("Netcon::remselcon: fd "  << (con->m_fd) << "\n" );
     map<int, NetconP>::iterator it = m_polldata.find(con->m_fd);
     if (it == m_polldata.end()) {
-        LOGDEB1(("Netcon::remselcon: con not found for fd %d\n", con->m_fd));
+        LOGDEB1("Netcon::remselcon: con not found for fd "  << (con->m_fd) << "\n" );
         return -1;
     }
     con->setloop(0);
@@ -369,9 +350,9 @@ void Netcon::setpeer(const char *hostname)
 
 int Netcon::settcpnodelay(int on)
 {
-    LOGDEB2(("Netcon::settcpnodelay\n"));
+    LOGDEB2("Netcon::settcpnodelay\n" );
     if (m_fd < 0) {
-        LOGERR(("Netcon::settcpnodelay: connection not opened\n"));
+        LOGERR("Netcon::settcpnodelay: connection not opened\n" );
         return -1;
     }
     char *cp = on ? (char *)&one : (char *)&zero;
@@ -382,6 +363,7 @@ int Netcon::settcpnodelay(int on)
     return 0;
 }
 
+
 // Set/reset non-blocking flag on fd
 int Netcon::set_nonblock(int onoff)
 {
@@ -399,23 +381,46 @@ int Netcon::set_nonblock(int onoff)
 /////////////////////////////////////////////////////////////////////
 // Data socket (NetconData) methods
 
+NetconData::NetconData(bool cancellable)
+    : m_buf(0), m_bufbase(0), m_bufbytes(0), m_bufsize(0), m_wkfds{-1,-1}
+{
+    if (cancellable) {
+        if (pipe(m_wkfds) < 0) {
+            LOGSYSERR("NetconData::NetconData", "pipe", "");
+            m_wkfds[0] = m_wkfds[1] = -1;
+        }
+        LOGDEB2("NetconData:: m_wkfds[0] " << m_wkfds[0] << " m_wkfds[1] " <<
+               m_wkfds[1] << endl);
+        for (int i = 0; i < 2; i++) {
+            int flags = fcntl(m_wkfds[i], F_GETFL, 0);
+            fcntl(m_wkfds[i], F_SETFL, flags | O_NONBLOCK);
+        }
+    }
+}
+
 NetconData::~NetconData()
 {
     freeZ(m_buf);
     m_bufbase = 0;
     m_bufbytes = m_bufsize = 0;
+    for (int i = 0; i < 2; i++) {
+        if (m_wkfds[i] >= 0) {
+            close(m_wkfds[i]);
+        }
+    }
 }
 
 int NetconData::send(const char *buf, int cnt, int expedited)
 {
-    LOGDEB2(("NetconData::send: fd %d cnt %d expe %d\n", m_fd, cnt, expedited));
+    LOGDEB2("NetconData::send: fd " << m_fd << " cnt " << cnt <<
+            " expe " << expedited << "\n");
     int flag = 0;
     if (m_fd < 0) {
-        LOGERR(("NetconData::send: connection not opened\n"));
+        LOGERR("NetconData::send: connection not opened\n" );
         return -1;
     }
     if (expedited) {
-        LOGDEB2(("NetconData::send: expedited data, count %d bytes\n", cnt));
+        LOGDEB2("NetconData::send: expedited data, count " <<cnt << " bytes\n");
         flag = MSG_OOB;
     }
     int ret;
@@ -436,37 +441,25 @@ int NetconData::send(const char *buf, int cnt, int expedited)
     return ret;
 }
 
-// Test for data available
-int NetconData::readready()
+void NetconData::cancelReceive()
 {
-    LOGDEB2(("NetconData::readready\n"));
-    if (m_fd < 0) {
-        LOGERR(("NetconData::readready: connection not opened\n"));
-        return -1;
+    if (m_wkfds[1] >= 0) {
+        LOGDEB2("NetconData::cancelReceive: writing to " << m_wkfds[1] << endl);
+        ::write(m_wkfds[1], "!", 1);
     }
-    return select1(m_fd, 0);
-}
-
-// Test for writable
-int NetconData::writeready()
-{
-    LOGDEB2(("NetconData::writeready\n"));
-    if (m_fd < 0) {
-        LOGERR(("NetconData::writeready: connection not opened\n"));
-        return -1;
-    }
-    return select1(m_fd, 0, 1);
 }
 
 // Receive at most cnt bytes (maybe less)
 int NetconData::receive(char *buf, int cnt, int timeo)
 {
-    LOGDEB2(("NetconData::receive: cnt %d timeo %d m_buf 0x%x m_bufbytes %d\n",
-             cnt, timeo, m_buf, m_bufbytes));
+    LOGDEB2("NetconData::receive: cnt " << cnt << " timeo "  << timeo <<
+            " m_buf 0x" << m_buf << " m_bufbytes " << m_bufbytes << "\n");
+
     if (m_fd < 0) {
-        LOGERR(("NetconData::receive: connection not opened\n"));
+        LOGERR("NetconData::receive: connection not opened\n" );
         return -1;
     }
+
     int fromibuf = 0;
     // Get whatever might have been left in the buffer by a previous
     // getline, except if we're called to fill the buffer of course
@@ -476,31 +469,54 @@ int NetconData::receive(char *buf, int cnt, int timeo)
         m_bufbytes -= fromibuf;
         m_bufbase += fromibuf;
         cnt -= fromibuf;
-        LOGDEB2(("NetconData::receive: transferred %d from mbuf\n", fromibuf));
+        LOGDEB2("NetconData::receive: got " << fromibuf << " from mbuf\n");
         if (cnt <= 0) {
             return fromibuf;
         }
     }
+
     if (timeo > 0) {
-        int ret = select1(m_fd, timeo);
-        if (ret == 0) {
-            LOGDEB2(("NetconData::receive timed out\n"));
-            m_didtimo = 1;
-            return -1;
+        struct timeval tv;
+        tv.tv_sec = timeo;
+        tv.tv_usec =  0;
+        fd_set rd;
+        FD_ZERO(&rd);
+        FD_SET(m_fd, &rd);
+        bool cancellable = (m_wkfds[0] >= 0);
+        if (cancellable) {
+            LOGDEB2("NetconData::receive: cancel fd " << m_wkfds[0] << endl);
+            FD_SET(m_wkfds[0], &rd);
         }
+        int nfds = MAX(m_fd, m_wkfds[0]) + 1;
+
+        int ret = select(nfds, &rd, 0, 0, &tv);
+        LOGDEB2("NetconData::receive: select returned " << ret << endl);
+        
+        if (cancellable && FD_ISSET(m_wkfds[0], &rd)) {
+            char b[100];
+            read(m_wkfds[0], b, 100);
+            return Cancelled;
+        }
+
+        if (!FD_ISSET(m_fd, &rd)) {
+            m_didtimo = 1;
+            return TimeoutOrError;
+        }
+
         if (ret < 0) {
             LOGSYSERR("NetconData::receive", "select", "");
-            return -1;
+            m_didtimo = 0;
+            return TimeoutOrError;
         }
     }
+
     m_didtimo = 0;
     if ((cnt = read(m_fd, buf + fromibuf, cnt)) < 0) {
-        char fdcbuf[20];
-        sprintf(fdcbuf, "%d", m_fd);
-        LOGSYSERR("NetconData::receive", "read", fdcbuf);
+        LOGSYSERR("NetconData::receive", "read", m_fd);
         return -1;
     }
-    LOGDEB2(("NetconData::receive: normal return, cnt %d\n", cnt));
+    LOGDEB2("NetconData::receive: normal return, fromibuf " << fromibuf <<
+            " cnt "  << cnt << "\n");
     return fromibuf + cnt;
 }
 
@@ -508,13 +524,13 @@ int NetconData::receive(char *buf, int cnt, int timeo)
 int NetconData::doreceive(char *buf, int cnt, int timeo)
 {
     int got, cur;
-    LOGDEB2(("Netcon::doreceive: cnt %d, timeo %d\n", cnt, timeo));
+    LOGDEB2("Netcon::doreceive: cnt " << cnt << ", timeo " << timeo << "\n");
     cur = 0;
     while (cnt > cur) {
         got = receive(buf, cnt - cur, timeo);
-        LOGDEB2(("Netcon::doreceive: got %d\n", got));
+        LOGDEB2("Netcon::doreceive: got "  << (got) << "\n" );
         if (got < 0) {
-            return -1;
+            return got;
         }
         if (got == 0) {
             return cur;
@@ -536,7 +552,7 @@ int NetconData::doreceive(char *buf, int cnt, int timeo)
 static const int defbufsize = 200;
 int NetconData::getline(char *buf, int cnt, int timeo)
 {
-    LOGDEB2(("NetconData::getline: cnt %d, timeo %d\n", cnt, timeo));
+    LOGDEB2("NetconData::getline: cnt "  << (cnt) << ", timeo "  << (timeo) << "\n" );
     if (m_buf == 0) {
         if ((m_buf = (char *)malloc(defbufsize)) == 0) {
             LOGSYSERR("NetconData::getline: Out of mem", "malloc", "");
@@ -553,8 +569,7 @@ int NetconData::getline(char *buf, int cnt, int timeo)
         // pointers consistant in all end cases
         int maxtransf = MIN(m_bufbytes, cnt - 1);
         int nn = maxtransf;
-        LOGDEB2(("Before loop, bufbytes %d, maxtransf %d, nn: %d\n",
-                 m_bufbytes, maxtransf, nn));
+        LOGDEB2("Before loop, bufbytes "  << (m_bufbytes) << ", maxtransf "  << (maxtransf) << ", nn: "  << (nn) << "\n" );
         for (nn = maxtransf; nn > 0;) {
             // This is not pretty but we want nn to be decremented for
             // each byte copied (even newline), and not become -1 if
@@ -568,8 +583,7 @@ int NetconData::getline(char *buf, int cnt, int timeo)
         maxtransf -= nn; // Actual count transferred
         m_bufbytes -= maxtransf;
         cnt -= maxtransf;
-        LOGDEB2(("After transfer: actual transf %d cnt %d, m_bufbytes %d\n",
-                 maxtransf, cnt, m_bufbytes));
+        LOGDEB2("After transfer: actual transf "  << (maxtransf) << " cnt "  << (cnt) << ", m_bufbytes "  << (m_bufbytes) << "\n" );
 
         // Finished ?
         if (cnt <= 1 || (cp > buf && cp[-1] == '\n')) {
@@ -599,7 +613,7 @@ int NetconData::getline(char *buf, int cnt, int timeo)
 // and discard.
 int NetconData::cando(Netcon::Event reason)
 {
-    LOGDEB2(("NetconData::cando\n"));
+    LOGDEB2("NetconData::cando\n" );
     if (m_user) {
         return m_user->data(this, reason);
     }
@@ -627,7 +641,7 @@ int NetconData::cando(Netcon::Event reason)
 int NetconCli::openconn(const char *host, unsigned int port, int timeo)
 {
     int ret = -1;
-    LOGDEB2(("Netconcli::openconn: host %s, port %d\n", host, port));
+    LOGDEB2("Netconcli::openconn: host "  << (host) << ", port "  << (port) << "\n" );
 
     closeconn();
 
@@ -648,8 +662,7 @@ int NetconCli::openconn(const char *host, unsigned int port, int timeo)
         } else {
             struct hostent *hp;
             if ((hp = gethostbyname(host)) == 0) {
-                LOGERR(("NetconCli::openconn: gethostbyname(%s) failed\n",
-                        host));
+                LOGERR("NetconCli::openconn: gethostbyname("  << (host) << ") failed\n" );
                 return -1;
             }
             memcpy(&ip_addr.sin_addr, hp->h_addr, hp->h_length);
@@ -665,7 +678,7 @@ int NetconCli::openconn(const char *host, unsigned int port, int timeo)
         memset(&unix_addr, 0, sizeof(unix_addr));
         unix_addr.sun_family = AF_UNIX;
         if (strlen(host) > UNIX_PATH_MAX - 1) {
-            LOGERR(("NetconCli::openconn: name too long: %s\n", host));
+            LOGERR("NetconCli::openconn: name too long: "  << (host) << "\n" );
             return -1;
         }
         strcpy(unix_addr.sun_path, host);
@@ -700,13 +713,13 @@ connectok:
         set_nonblock(0);
     }
 
-    LOGDEB2(("NetconCli::connect: setting keepalive\n"));
+    LOGDEB2("NetconCli::connect: setting keepalive\n" );
     if (setsockopt(m_fd, SOL_SOCKET, SO_KEEPALIVE,
                    (char *)&one, sizeof(one)) < 0) {
         LOGSYSERR("NetconCli::connect", "setsockopt", "KEEPALIVE");
     }
     setpeer(host);
-    LOGDEB2(("NetconCli::openconn: connection opened ok\n"));
+    LOGDEB2("NetconCli::openconn: connection opened ok\n" );
     ret = 0;
 out:
     if (ret < 0) {
@@ -718,12 +731,12 @@ out:
 // Same as previous, but get the port number from services
 int NetconCli::openconn(const char *host, const char *serv, int timeo)
 {
-    LOGDEB2(("Netconcli::openconn: host %s, serv %s\n", host, serv));
+    LOGDEB2("Netconcli::openconn: host "  << (host) << ", serv "  << (serv) << "\n" );
 
     if (host[0]  != '/') {
         struct servent *sp;
         if ((sp = getservbyname(serv, "tcp")) == 0) {
-            LOGERR(("NetconCli::openconn: getservbyname failed for %s\n", serv));
+            LOGERR("NetconCli::openconn: getservbyname failed for "  << (serv) << "\n" );
             return -1;
         }
         // Callee expects the port number in host byte order
@@ -736,7 +749,7 @@ int NetconCli::openconn(const char *host, const char *serv, int timeo)
 
 int NetconCli::setconn(int fd)
 {
-    LOGDEB2(("Netconcli::setconn: fd %d\n", fd));
+    LOGDEB2("Netconcli::setconn: fd "  << (fd) << "\n" );
     closeconn();
 
     m_fd = fd;
@@ -776,10 +789,10 @@ int NetconServLis::openservice(const char *serv, int backlog)
     int port;
     struct servent  *servp;
     if (!serv) {
-        LOGERR(("NetconServLis::openservice: null serv??\n"));
+        LOGERR("NetconServLis::openservice: null serv??\n" );
         return -1;
     }
-    LOGDEB1(("NetconServLis::openservice: serv %s\n", serv));
+    LOGDEB1("NetconServLis::openservice: serv "  << (serv) << "\n" );
 #ifdef NETCON_ACCESSCONTROL
     if (initperms(serv) < 0) {
         return -1;
@@ -789,16 +802,14 @@ int NetconServLis::openservice(const char *serv, int backlog)
     m_serv = serv;
     if (serv[0] != '/') {
         if ((servp = getservbyname(serv, "tcp")) == 0) {
-            LOGERR(("NetconServLis::openservice: getservbyname failed for %s\n",
-                    serv));
+            LOGERR("NetconServLis::openservice: getservbyname failed for "  << (serv) << "\n" );
             return -1;
         }
         port = (int)ntohs((short)servp->s_port);
         return openservice(port, backlog);
     } else {
         if (strlen(serv) > UNIX_PATH_MAX - 1) {
-            LOGERR(("NetconServLis::openservice: too long for AF_UNIX: %s\n",
-                    serv));
+            LOGERR("NetconServLis::openservice: too long for AF_UNIX: "  << (serv) << "\n" );
             return -1;
         }
         int ret = -1;
@@ -820,7 +831,7 @@ int NetconServLis::openservice(const char *serv, int backlog)
             goto out;
         }
 
-        LOGDEB1(("NetconServLis::openservice: service opened ok\n"));
+        LOGDEB1("NetconServLis::openservice: service opened ok\n" );
         ret = 0;
 out:
         if (ret < 0 && m_fd >= 0) {
@@ -834,7 +845,7 @@ out:
 // Port is a natural host integer value
 int NetconServLis::openservice(int port, int backlog)
 {
-    LOGDEB1(("NetconServLis::openservice: port %d\n", port));
+    LOGDEB1("NetconServLis::openservice: port "  << (port) << "\n" );
 #ifdef NETCON_ACCESSCONTROL
     if (initperms(port) < 0) {
         return -1;
@@ -863,7 +874,7 @@ int NetconServLis::openservice(int port, int backlog)
         goto out;
     }
 
-    LOGDEB1(("NetconServLis::openservice: service opened ok\n"));
+    LOGDEB1("NetconServLis::openservice: service opened ok\n" );
     ret = 0;
 out:
     if (ret < 0 && m_fd >= 0) {
@@ -893,7 +904,7 @@ int NetconServLis::initperms(const char *serv)
     }
 
     if (serv == 0 || *serv == 0 || strlen(serv) > 80) {
-        LOGERR(("NetconServLis::initperms: bad service name %s\n", serv));
+        LOGERR("NetconServLis::initperms: bad service name "  << (serv) << "\n" );
         return -1;
     }
 
@@ -903,17 +914,17 @@ int NetconServLis::initperms(const char *serv)
         serv = "default";
         sprintf(keyname, "%s_okaddrs", serv);
         if (genparams->getparam(keyname, &okaddrs) < 0) {
-            LOGERR(("NetconServLis::initperms: no okaddrs found in config file\n"));
+            LOGERR("NetconServLis::initperms: no okaddrs found in config file\n" );
             return -1;
         }
     }
     sprintf(keyname, "%s_okmasks", serv);
     if (genparams->getparam(keyname, &okmasks)) {
-        LOGERR(("NetconServLis::initperms: okmasks not found\n"));
+        LOGERR("NetconServLis::initperms: okmasks not found\n" );
         return -1;
     }
     if (okaddrs.len == 0 || okmasks.len == 0) {
-        LOGERR(("NetconServLis::initperms: len 0 for okmasks or okaddrs\n"));
+        LOGERR("NetconServLis::initperms: len 0 for okmasks or okaddrs\n" );
         return -1;
     }
 
@@ -935,12 +946,12 @@ int  NetconServLis::cando(Netcon::Event reason)
 NetconServCon *
 NetconServLis::accept(int timeo)
 {
-    LOGDEB(("NetconServLis::accept\n"));
+    LOGDEB("NetconServLis::accept\n" );
 
     if (timeo > 0) {
         int ret = select1(m_fd, timeo);
         if (ret == 0) {
-            LOGDEB2(("NetconServLis::accept timed out\n"));
+            LOGDEB2("NetconServLis::accept timed out\n" );
             m_didtimo = 1;
             return 0;
         }
@@ -976,7 +987,7 @@ NetconServLis::accept(int timeo)
 
     con = new NetconServCon(newfd);
     if (con == 0) {
-        LOGERR(("NetconServLis::accept: new NetconServCon failed\n"));
+        LOGERR("NetconServLis::accept: new NetconServCon failed\n" );
         goto out;
     }
 
@@ -985,8 +996,7 @@ NetconServLis::accept(int timeo)
         struct hostent *hp;
         if ((hp = gethostbyaddr((char *) & (who.sin_addr),
                                 sizeof(struct in_addr), AF_INET)) == 0) {
-            LOGERR(("NetconServLis::accept: gethostbyaddr failed for addr 0x%lx\n",
-                    who.sin_addr.s_addr));
+            LOGERR("NetconServLis::accept: gethostbyaddr failed for addr 0x"  << (who.sin_addr.s_addr) << "\n" );
             con->setpeer(inet_ntoa(who.sin_addr));
         } else {
             con->setpeer(hp->h_name);
@@ -995,12 +1005,12 @@ NetconServLis::accept(int timeo)
         con->setpeer(m_serv.c_str());
     }
 
-    LOGDEB2(("NetconServLis::accept: setting keepalive\n"));
+    LOGDEB2("NetconServLis::accept: setting keepalive\n" );
     if (setsockopt(newfd, SOL_SOCKET, SO_KEEPALIVE,
                    (char *)&one, sizeof(one)) < 0) {
         LOGSYSERR("NetconServLis::accept", "setsockopt", "KEEPALIVE");
     }
-    LOGDEB2(("NetconServLis::accept: got connect from %s\n", con->getpeer()));
+    LOGDEB2("NetconServLis::accept: got connect from "  << (con->getpeer()) << "\n" );
 
 out:
     if (con == 0 && newfd >= 0) {
@@ -1022,12 +1032,12 @@ NetconServLis::checkperms(void *cl, int)
     unsigned long ip_addr;
 
     if (addr->sa_family != AF_INET) {
-        LOGERR(("NetconServLis::checkperms: connection from non-INET addr !\n"));
+        LOGERR("NetconServLis::checkperms: connection from non-INET addr !\n" );
         return -1;
     }
 
     ip_addr = ntohl(((struct sockaddr_in *)addr)->sin_addr.s_addr);
-    LOGDEB2(("checkperms: ip_addr: 0x%x\n", ip_addr));
+    LOGDEB2("checkperms: ip_addr: 0x"  << (ip_addr) << "\n" );
     for (int i = 0; i < okaddrs.len; i++) {
         unsigned int mask;
         if (i < okmasks.len) {
@@ -1035,328 +1045,12 @@ NetconServLis::checkperms(void *cl, int)
         } else {
             mask = okmasks.intarray[okmasks.len - 1];
         }
-        LOGDEB2(("checkperms: trying okaddr 0x%x, mask 0x%x\n",
-                 okaddrs.intarray[i], mask));
+        LOGDEB2("checkperms: trying okaddr 0x"  << (okaddrs.intarray[i]) << ", mask 0x"  << (mask) << "\n" );
         if ((ip_addr & mask) == (okaddrs.intarray[i] & mask)) {
             return (0);
         }
     }
-    LOGERR(("NetconServLis::checkperm: connection from bad address 0x%x\n",
-            ip_addr));
+    LOGERR("NetconServLis::checkperm: connection from bad address 0x"  << (ip_addr) << "\n" );
     return -1;
 }
 #endif /* NETCON_ACCESSCONTROL */
-
-
-#else /* !TEST_NETCON */
-/////////////////////////////////////////////////////////////////////////
-////////// TEST DRIVER
-////////////////////////////////////////////////////////////////////////
-
-#include <stdio.h>
-#include <stdlib.h>
-#include <unistd.h>
-#include <signal.h>
-#include <string.h>
-
-#include "debuglog.h"
-#include "netcon.h"
-
-using namespace std;
-
-static char *thisprog;
-static char usage[] =
-    "-c <host> <service>: Connects to trnetcon server, exchange message, then\n"
-    "  sleeps 10 S, except if option -n is given (sleep forever)\n"
-    "\n"
-    "-s <service>: open service <service>\n"
-    ;
-static void
-Usage()
-{
-    fprintf(stderr, "Usage : %s:\n %s", thisprog, usage);
-    exit(1);
-}
-
-static int     op_flags;
-#define OPT_MOINS 0x1
-#define OPT_s     0x2 /* Server */
-#define OPT_c     0x4 /* Client */
-#define OPT_n     0x8  /* Client sleeps forever */
-
-extern int trycli(char *host, char *serv);
-extern int tryserv(char *serv);
-
-int nloop = 10;
-
-int main(int argc, char **argv)
-{
-    char *host, *serv;
-
-    thisprog = argv[0];
-    argc--;
-    argv++;
-
-    while (argc > 0 && **argv == '-') {
-        (*argv)++;
-        if (!(**argv))
-            /* Cas du "adb - core" */
-        {
-            Usage();
-        }
-        while (**argv)
-            switch (*(*argv)++) {
-            case 's':
-                op_flags |= OPT_s;
-                break;
-            case 'c':
-                op_flags |= OPT_c;
-                break;
-            case 'n':
-                op_flags |= OPT_n;
-                break;
-            default:
-                Usage();
-                break;
-            }
-        argc--;
-        argv++;
-    }
-    DebugLog::setfilename("stderr");
-    DebugLog::getdbl()->setloglevel(DEBDEB2);
-
-    if (op_flags & OPT_c) {
-        if (argc != 2) {
-            Usage();
-        }
-        host = *argv++;
-        argc--;
-        serv = *argv++;
-        argc--;
-        exit(trycli(host, serv));
-    } else if (op_flags & OPT_s) {
-        if (argc != 1) {
-            Usage();
-        }
-        serv = *argv++;
-        argc--;
-        exit(tryserv(serv));
-    } else {
-        Usage();
-    }
-}
-
-
-static char buf[1024];
-static int buflen = 1023;
-static char fromcli[200];
-
-class CliNetconWorker : public NetconWorker {
-public:
-    CliNetconWorker()  : m_count(0) {}
-    int data(NetconData *con, Netcon::Event reason) {
-        LOGDEB(("clientdata\n"));
-        if (reason & Netcon::NETCONPOLL_WRITE) {
-            sprintf(fromcli, "Bonjour Bonjour client %d, count %d",
-                    getpid(), m_count);
-            con->setselevents(Netcon::NETCONPOLL_READ);
-            if (con->send(fromcli, strlen(fromcli) + 1) < 0) {
-                fprintf(stderr, "send failed\n");
-                return -1;
-            }
-            m_count++;
-        }
-
-        if (reason & Netcon::NETCONPOLL_READ) {
-            con->setselevents(Netcon::NETCONPOLL_WRITE);
-            int n;
-            if ((n = con->receive(buf, buflen)) < 0) {
-                fprintf(stderr, "receive failed\n");
-                return -1;
-            }
-            if (n == 0) {
-                // EOF, close connection
-                return -1;
-            }
-            buf[n] = 0;
-            fprintf(stderr, "%d received \"%s\"\n", getpid(), buf);
-            if (op_flags & OPT_n) {
-                pause();
-            } else {
-                sleep(1);
-            }
-        }
-        if (m_count >= 10) {
-            fprintf(stderr, "Did 10, enough\n");
-            if (con->getloop()) {
-                con->getloop()->loopReturn(0);
-            }
-        }
-        return 0;
-    }
-private:
-    int m_count;
-};
-
-int trycli(char *host, char *serv)
-{
-    sprintf(fromcli, "Bonjour Bonjour je suis le client %d", getpid());
-
-    NetconCli *clicon = new NetconCli();
-    NetconP con(clicon);
-    if (!con) {
-        fprintf(stderr, "new NetconCli failed\n");
-        return 1;
-    }
-    int port = atoi(serv);
-    int ret = port > 0 ?
-              clicon->openconn(host, port) : clicon->openconn(host, serv);
-    if (ret < 0) {
-        fprintf(stderr, "openconn(%s, %s) failed\n", host, serv);
-        return 1;
-    }
-    fprintf(stderr, "openconn(%s, %s) ok\n", host, serv);
-#ifdef NOSELLOOP
-    for (int i = 0; i < nloop; i++) {
-        if (con->send(fromcli, strlen(fromcli) + 1) < 0) {
-            fprintf(stderr, "%d: Send failed\n", getpid());
-            return 1;
-        }
-        if (con->receive(buf, buflen) < 0) {
-            perror("receive:");
-            fprintf(stderr, "%d: Receive failed\n", getpid());
-            return 1;
-        }
-        fprintf(stderr, "%d Received \"%s\"\n", getpid(), buf);
-        if (op_flags & OPT_n) {
-            pause();
-        } else {
-            sleep(1);
-        }
-    }
-#else
-    STD_SHARED_PTR<NetconWorker> worker =
-        STD_SHARED_PTR<NetconWorker>(new CliNetconWorker());
-    clicon->setcallback(worker);
-    SelectLoop myloop;
-    myloop.addselcon(con, Netcon::NETCONPOLL_WRITE);
-    fprintf(stderr, "client ready\n");
-    ret = myloop.doLoop();
-    if (ret < 0) {
-        fprintf(stderr, "selectloop failed\n");
-        exit(1);
-    }
-    fprintf(stderr, "selectloop returned %d\n", ret);
-#endif
-    return 0;
-}
-
-//////////////////////////////////////////////////////////////////
-// Server-side sample code
-class ServNetconWorker : public NetconWorker {
-public:
-    ServNetconWorker() : m_count(0) {}
-    int data(NetconData *con, Netcon::Event reason) {
-        LOGDEB(("serverdata\n"));
-        if (reason & Netcon::NETCONPOLL_WRITE) {
-            con->setselevents(Netcon::NETCONPOLL_READ);
-            char fromserv[200];
-            sprintf(fromserv,
-                    "Du serveur: mon fd pour ce client est  %d, mon compte %d",
-                    con->getfd(), ++m_count);
-            if (con->send(fromserv, strlen(fromserv) + 1) < 0) {
-                fprintf(stderr, "send failed\n");
-                return -1;
-            }
-        }
-        if (reason & Netcon::NETCONPOLL_READ) {
-#define LL 200
-            char buf[LL + 1];
-            int n;
-            if ((n = con->receive(buf, LL)) < 0) {
-                fprintf(stderr, "receive failed\n");
-                return -1;
-            }
-            if (n == 0) {
-                return -1;
-            }
-            buf[n] = 0;
-            fprintf(stderr, "%d received \"%s\"\n", getpid(), buf);
-            con->setselevents(Netcon::NETCONPOLL_READ | Netcon::NETCONPOLL_WRITE);
-        }
-        return 0;
-    }
-private:
-    int m_count;
-};
-
-class MyNetconServLis : public NetconServLis {
-public:
-    MyNetconServLis(SelectLoop& loop)
-        : NetconServLis(), m_loop(loop) {
-    }
-protected:
-    int cando(Netcon::Event reason) {
-        NetconServCon *con = accept();
-        if (con == 0) {
-            return -1;
-        }
-        STD_SHARED_PTR<NetconWorker> worker =
-            STD_SHARED_PTR<NetconWorker>(new ServNetconWorker());
-        con->setcallback(worker);
-        m_loop.addselcon(NetconP(con), NETCONPOLL_READ);
-        return 1;
-    }
-    SelectLoop& m_loop;
-};
-
-NetconP lis;
-
-void
-onexit(int sig)
-{
-    fprintf(stderr, "Onexit: ");
-    if (sig == SIGQUIT) {
-        kill(getpid(), SIGKILL);
-    }
-    fprintf(stderr, "Exiting\n");
-    exit(0);
-}
-
-int tryserv(char *serv)
-{
-    signal(SIGCHLD, SIG_IGN);
-    SelectLoop myloop;
-    MyNetconServLis *servlis = new MyNetconServLis(myloop);
-    lis = NetconP(servlis);
-    if (!lis) {
-        fprintf(stderr, "new NetconServLis failed\n");
-        return 1;
-    }
-
-    // Prepare for cleanup
-    struct sigaction sa;
-    sa.sa_flags = 0;
-    sa.sa_handler = onexit;
-    sigemptyset(&sa.sa_mask);
-    sigaction(SIGINT, &sa, 0);
-    sigaction(SIGQUIT, &sa, 0);
-    sigaction(SIGTERM, &sa, 0);
-
-    int port = atoi(serv);
-    int ret = port > 0 ?
-              servlis->openservice(port) : servlis->openservice(serv);
-    if (ret < 0) {
-        fprintf(stderr, "openservice(%s) failed\n", serv);
-        return 1;
-    }
-    myloop.addselcon(lis, Netcon::NETCONPOLL_READ);
-    fprintf(stderr, "openservice(%s) Ok\n", serv);
-    if (myloop.doLoop() < 0) {
-        fprintf(stderr, "selectloop failed\n");
-        exit(1);
-    }
-    return 0;
-}
-
-#endif /* TEST_NETCON */
