@@ -69,6 +69,14 @@ void path_slashize(string& s)
         }
     }
 }
+void path_backslashize(string& s)
+{
+    for (string::size_type i = 0; i < s.size(); i++) {
+        if (s[i] == '/') {
+            s[i] = '\\';
+        }
+    }
+}
 static bool path_strlookslikedrive(const string& s)
 {
     return s.size() == 2 && isalpha(s[0]) && s[1] == ':';
@@ -436,6 +444,14 @@ string path_canon(const string& is, const string* cwd)
     } else {
         ret = "/";
     }
+
+#ifdef _WIN32
+    // Raw drive needs a final /
+    if (path_strlookslikedrive(ret)) {
+        path_catslash(ret);
+    }
+#endif
+
     return ret;
 }
 
@@ -860,6 +876,22 @@ using namespace std;
 
 #include "pathut.h"
 
+void path_to_thumb(const string& _input)
+{
+    string input(_input);
+    // Make absolute path if needed
+    if (input[0] != '/') {
+        input = path_absolute(input);
+    }
+
+    input = string("file://") + path_canon(input);
+
+    string path;
+    //path = url_encode(input, 7);
+    thumbPathForUrl(input, 7, path);
+    cout << path << endl;
+}
+
 const char *tstvec[] = {"", "/", "/dir", "/dir/", "/dir1/dir2",
                         "/dir1/dir2",
                         "./dir", "./dir1/", "dir", "../dir", "/dir/toto.c",
@@ -958,6 +990,29 @@ int main(int argc, const char **argv)
     pidfile.remove();
 #endif
 
+#if 0
+    if (argc > 1) {
+        cerr <<  "Usage: thumbpath <filepath>" << endl;
+        exit(1);
+    }
+    string input;
+    if (argc == 1) {
+        input = *argv++;
+        if (input.empty())  {
+            cerr << "Usage: thumbpath <filepath>" << endl;
+            exit(1);
+        }
+        path_to_thumb(input);
+    } else {
+        while (getline(cin, input)) {
+            path_to_thumb(input);
+        }
+    }
+
+
+    exit(0);
+#endif
+
 #if 0
     if (argc != 1) {
         cerr << "Usage: trpathut <filename>" << endl;
