@@ -1,27 +1,20 @@
-/* Copyright (C) 2004-2016 J.F.Dockes
- *   This program is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; either version 2 of the License, or
- *   (at your option) any later version.
+/* Copyright (C) 2006-2016 J.F.Dockes
  *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details.
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
  *
- *   You should have received a copy of the GNU General Public License
- *   along with this program; if not, write to the
- *   Free Software Foundation, Inc.,
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ *   02110-1301 USA
  */
-
-#ifndef TEST_SMALLUT
-#ifdef BUILDING_RECOLL
-#include "autoconfig.h"
-#else
-#include "config.h"
-#endif
-
 #include <stdio.h>
 #include <stdlib.h>
 #include <time.h>
@@ -31,11 +24,21 @@
 #include <string.h>
 #include <math.h>
 
+// Older compilers don't support stdc++ regex, but Windows does not
+// have the Linux one. Have a simple class to solve the simple cases.
+#if defined(_WIN32)
+#define USE_STD_REGEX
+#include <regex>
+#else
+#define USE_LINUX_REGEX
+#include <regex.h>
+#endif
+
 #include <string>
 #include <iostream>
 #include <list>
-#include UNORDERED_MAP_INCLUDE
-#include UNORDERED_SET_INCLUDE
+#include <unordered_map>
+#include <unordered_set>
 
 #include "smallut.h"
 
@@ -87,6 +90,23 @@ string stringtolower(const string& i)
     stringtolower(o);
     return o;
 }
+
+void stringtoupper(string& io)
+{
+    string::iterator it = io.begin();
+    string::iterator ite = io.end();
+    while (it != ite) {
+        *it = ::toupper(*it);
+        it++;
+    }
+}
+string stringtoupper(const string& i)
+{
+    string o = i;
+    stringtoupper(o);
+    return o;
+}
+
 extern int stringisuffcmp(const string& s1, const string& s2)
 {
     string::const_reverse_iterator r1 = s1.rbegin(), re1 = s1.rend(),
@@ -165,6 +185,14 @@ int stringuppercmp(const string& s1, const string& s2)
     }
 }
 
+bool beginswith(const std::string& big, const std::string& small)
+{
+    if (big.compare(0, small.size(), small)) {
+        return false;
+    }
+    return true;
+}
+
 // Compare charset names, removing the more common spelling variations
 bool samecharset(const string& cs1, const string& cs2)
 {
@@ -298,8 +326,8 @@ template bool stringToStrings<vector<string> >(const string&,
         vector<string>&, const string&);
 template bool stringToStrings<set<string> >(const string&,
         set<string>&, const string&);
-template bool stringToStrings<STD_UNORDERED_SET<string> >
-(const string&, STD_UNORDERED_SET<string>&, const string&);
+template bool stringToStrings<std::unordered_set<string> >
+(const string&, std::unordered_set<string>&, const string&);
 
 template <class T> void stringsToString(const T& tokens, string& s)
 {
@@ -332,6 +360,7 @@ template <class T> void stringsToString(const T& tokens, string& s)
 template void stringsToString<list<string> >(const list<string>&, string&);
 template void stringsToString<vector<string> >(const vector<string>&, string&);
 template void stringsToString<set<string> >(const set<string>&, string&);
+template void stringsToString<unordered_set<string> >(const unordered_set<string>&, string&);
 template <class T> string stringsToString(const T& tokens)
 {
     string out;
@@ -341,6 +370,7 @@ template <class T> string stringsToString(const T& tokens)
 template string stringsToString<list<string> >(const list<string>&);
 template string stringsToString<vector<string> >(const vector<string>&);
 template string stringsToString<set<string> >(const set<string>&);
+template string stringsToString<unordered_set<string> >(const unordered_set<string>&);
 
 template <class T> void stringsToCSV(const T& tokens, string& s,
                                      char sep)
@@ -498,16 +528,13 @@ string escapeHtml(const string& in)
 {
     string out;
     for (string::size_type pos = 0; pos < in.length(); pos++) {
-        switch (in.at(pos)) {
-        case '<':
-            out += "&lt;";
-            break;
-        case '&':
-            out += "&amp;";
-            break;
-        default:
-            out += in.at(pos);
-        }
+	switch(in.at(pos)) {
+	case '<': out += "&lt;"; break;
+	case '>': out += "&gt;"; break;
+	case '&': out += "&amp;"; break;
+	case '"': out += "&quot;"; break;
+	default: out += in.at(pos); break;
+	}
     }
     return out;
 }
@@ -541,6 +568,34 @@ string escapeShell(const string& in)
     return out;
 }
 
+// Escape value to be suitable as C++ source double-quoted string (for
+// generating a c++ program
+string makeCString(const string& in)
+{
+    string out;
+    out += "\"";
+    for (string::size_type pos = 0; pos < in.length(); pos++) {
+        switch (in.at(pos)) {
+        case '"':
+            out += "\\\"";
+            break;
+        case '\n':
+            out += "\\n";
+            break;
+        case '\r':
+            out += "\\r";
+            break;
+        case '\\':
+            out += "\\\\";
+            break;
+        default:
+            out += in.at(pos);
+        }
+    }
+    out += "\"";
+    return out;
+}
+
 
 // Substitute printf-like percent cmds inside a string
 bool pcSubst(const string& in, string& out, const map<char, string>& subs)
@@ -615,7 +670,7 @@ bool pcSubst(const string& in, string& out, const map<string, string>& subs)
     }
     return true;
 }
-inline static int ulltorbuf(unsigned long long val, char *rbuf)
+inline static int ulltorbuf(uint64_t val, char *rbuf)
 {
     int idx;
     for (idx = 0; val; idx++) {
@@ -635,7 +690,7 @@ inline static void ullcopyreverse(const char *rbuf, string& buf, int idx)
     }
 }
 
-void ulltodecstr(unsigned long long val, string& buf)
+void ulltodecstr(uint64_t val, string& buf)
 {
     buf.clear();
     if (val == 0) {
@@ -650,7 +705,7 @@ void ulltodecstr(unsigned long long val, string& buf)
     return;
 }
 
-void lltodecstr(long long val, string& buf)
+void lltodecstr(int64_t val, string& buf)
 {
     buf.clear();
     if (val == 0) {
@@ -675,14 +730,14 @@ void lltodecstr(long long val, string& buf)
     return;
 }
 
-string lltodecstr(long long val)
+string lltodecstr(int64_t val)
 {
     string buf;
     lltodecstr(val, buf);
     return buf;
 }
 
-string ulltodecstr(unsigned long long val)
+string ulltodecstr(uint64_t val)
 {
     string buf;
     ulltodecstr(val, buf);
@@ -690,7 +745,7 @@ string ulltodecstr(unsigned long long val)
 }
 
 // Convert byte count into unit (KB/MB...) appropriate for display
-string displayableBytes(off_t size)
+string displayableBytes(int64_t size)
 {
     const char *unit;
 
@@ -708,7 +763,7 @@ string displayableBytes(off_t size)
         unit = " GB ";
         roundable = double(size) / 1E9;
     }
-    size = off_t(round(roundable));
+    size = int64_t(round(roundable));
     return lltodecstr(size).append(unit);
 }
 
@@ -1107,6 +1162,7 @@ void catstrerror(string *reason, const char *what, int _errno)
     errbuf[0] = 0;
     // We don't use ret, it's there to silence a cc warning
     char *ret = (char *)strerror_r(_errno, errbuf, ERRBUFSZ);
+    (void)ret;
     reason->append(errbuf);
 #endif
 }
@@ -1141,14 +1197,14 @@ static const string cstr_cp1252("CP1252");
 
 string langtocode(const string& lang)
 {
-    static STD_UNORDERED_MAP<string, string> lang_to_code;
+    static std::unordered_map<string, string> lang_to_code;
     if (lang_to_code.empty()) {
         for (unsigned int i = 0;
                 i < sizeof(vlang_to_code) / sizeof(char *); i += 2) {
             lang_to_code[vlang_to_code[i]] = vlang_to_code[i + 1];
         }
     }
-    STD_UNORDERED_MAP<string, string>::const_iterator it =
+    std::unordered_map<string, string>::const_iterator it =
         lang_to_code.find(lang);
 
     // Use cp1252 by default...
@@ -1175,6 +1231,160 @@ string localelang()
     return locale.substr(0, under);
 }
 
+#ifdef USE_STD_REGEX
+
+class SimpleRegexp::Internal {
+public:
+    Internal(const string& exp, int flags, int nm)
+        : expr(exp,
+               basic_regex<char>::flag_type(regex_constants::extended |
+                   ((flags&SRE_ICASE) ? regex_constants::icase : 0) |
+                   ((flags&SRE_NOSUB) ? regex_constants::nosubs : 0)
+                   )), ok(true), nmatch(nm) {
+    }
+    std::regex expr;
+    std::smatch res;
+    bool ok;
+    int nmatch;
+};
+
+bool SimpleRegexp::simpleMatch(const string& val) const
+{
+    if (!ok())
+        return false;
+    return regex_match(val, m->res, m->expr);
+}
+
+string SimpleRegexp::getMatch(const string& val, int i) const
+{
+    return m->res.str(i);
+}
+
+#else // -> !WIN32
+
+class SimpleRegexp::Internal {
+public:
+    Internal(const string& exp, int flags, int nm) : nmatch(nm) {
+        if (regcomp(&expr, exp.c_str(), REG_EXTENDED |
+                    ((flags&SRE_ICASE) ? REG_ICASE : 0) |
+                    ((flags&SRE_NOSUB) ? REG_NOSUB : 0)) == 0) {
+            ok = true;
+        } else {
+            ok = false;
+        }
+        matches.reserve(nmatch+1);
+    }
+    ~Internal() {
+        regfree(&expr);
+    }
+    bool ok;
+    regex_t expr;
+    int nmatch;
+    vector<regmatch_t> matches;
+};
+
+bool SimpleRegexp::simpleMatch(const string& val) const
+{
+    if (!ok())
+        return false;
+    if (regexec(&m->expr, val.c_str(), m->nmatch+1, &m->matches[0], 0) == 0) {
+        return true;
+    } else {
+        return false;
+    }
+}
+
+string SimpleRegexp::getMatch(const string& val, int i) const
+{
+    if (i > m->nmatch) {
+        return string();
+    }
+    return val.substr(m->matches[i].rm_so,
+                      m->matches[i].rm_eo - m->matches[i].rm_so);
+}
+
+#endif // win/notwinf
+
+SimpleRegexp::SimpleRegexp(const string& exp, int flags, int nmatch)
+    : m(new Internal(exp, flags, nmatch))
+{
+}
+
+SimpleRegexp::~SimpleRegexp()
+{
+    delete m;
+}
+
+bool SimpleRegexp::ok() const
+{
+    return m->ok;
+}
+
+bool SimpleRegexp::operator() (const string& val) const
+{
+    return simpleMatch(val);
+}
+
+string flagsToString(const vector<CharFlags>& flags, unsigned int val)
+{
+    const char *s;
+    string out;
+    for (auto& flag : flags) {
+        if ((val & flag.value) == flag.value) {
+            s = flag.yesname;
+        } else {
+            s = flag.noname;
+        }
+        if (s && *s) {
+            /* We have something to write */
+            if (out.length()) {
+                // If not first, add '|' separator
+                out.append("|");
+            }
+            out.append(s);
+        }
+    }
+    return out;
+}
+
+string valToString(const vector<CharFlags>& flags, unsigned int val)
+{
+    string out;
+    for (auto& flag : flags) {
+        if (flag.value == val) {
+            out = flag.yesname;
+            return out;
+        }
+    }
+    {
+        char mybuf[100];
+        sprintf(mybuf, "Unknown Value 0x%x", val);
+        out = mybuf;
+    }
+    return out;
+}
+
+unsigned int stringToFlags(const vector<CharFlags>& flags,
+                           const string& input, const char *sep)
+{
+    unsigned int out = 0;
+
+    vector<string> toks;
+    stringToTokens(input, toks, sep);
+    for (auto& tok: toks) {
+        trimstring(tok);
+        for (auto& flag : flags) {
+            if (!tok.compare(flag.yesname)) {
+                /* Note: we don't break: the same name could conceivably
+                   set several flags. */
+                out |= flag.value;
+            }
+        }
+    }
+    return out;
+}
+
+
 // Initialization for static stuff to be called from main thread before going
 // multiple
 void smallut_init_mt()
@@ -1182,226 +1392,3 @@ void smallut_init_mt()
     // Init langtocode() static table
     langtocode("");
 }
-
-#else // TEST_SMALLUT
-
-#include <string>
-using namespace std;
-#include <iostream>
-
-#include "smallut.h"
-
-struct spair {
-    const char *s1;
-    const char *s2;
-};
-struct spair pairs[] = {
-    {"", ""},
-    {"", "a"},
-    {"a", ""},
-    {"a", "a"},
-    {"A", "a"},
-    {"a", "A"},
-    {"A", "A"},
-    {"12", "12"},
-    {"a", "ab"},
-    {"ab", "a"},
-    {"A", "Ab"},
-    {"a", "Ab"},
-};
-int npairs = sizeof(pairs) / sizeof(struct spair);
-struct spair suffpairs[] = {
-    {"", ""},
-    {"", "a"},
-    {"a", ""},
-    {"a", "a"},
-    {"toto.txt", ".txt"},
-    {"TXT", "toto.txt"},
-    {"toto.txt", ".txt1"},
-    {"toto.txt1", ".txt"},
-};
-int nsuffpairs = sizeof(suffpairs) / sizeof(struct spair);
-
-
-// Periods test strings
-const char* periods[] = {
-    "2001",    // Year 2001
-    "2001/",  // 2001 or later
-    "2001/P3Y", // 2001 -> 2004 or 2005, ambiguous
-    "2001-01-01/P3Y", // 01-2001 -> 01 2004
-    "2001-03-03/2001-05-01", // Explicit one
-    "P3M/", // 3 months ago to now
-    "P1Y1M/2001-03-01", // 2000-02-01/2001-03-01
-    "/2001", // From the epoch to the end of 2001
-};
-const int nperiods = sizeof(periods) / sizeof(char*);
-
-const char *thisprog;
-static void cerrdip(const string& s, DateInterval *dip)
-{
-    cerr << s << dip->y1 << "-" << dip->m1 << "-" << dip->d1 << "/"
-         << dip->y2 << "-" << dip->m2 << "-" << dip->d2
-         << endl;
-}
-
-int main(int argc, char **argv)
-{
-    thisprog = *argv++;
-    argc--;
-
-#if 1
-    if (argc <= 0) {
-        cerr << "Usage: smallut <stringtosplit>" << endl;
-        exit(1);
-    }
-    string s = *argv++;
-    argc--;
-    vector<string> vs;
-    stringToTokens(s, vs, "/");
-    for (vector<string>::const_iterator it = vs.begin(); it != vs.end(); it++) {
-        cerr << "[" << *it << "] ";
-    }
-    cerr << endl;
-    exit(0);
-#elif 0
-    if (argc <= 0) {
-        cerr << "Usage: smallut <stringtosplit>" << endl;
-        exit(1);
-    }
-    string s = *argv++;
-    argc--;
-    vector<string> vs;
-    if (!stringToStrings(s, vs, ":-()")) {
-        cerr << "Bad entry" << endl;
-        exit(1);
-    }
-    for (vector<string>::const_iterator it = vs.begin(); it != vs.end(); it++) {
-        cerr << "[" << *it << "] ";
-    }
-    cerr << endl;
-    exit(0);
-#elif 0
-    if (argc <= 0) {
-        cerr << "Usage: smallut <dateinterval>" << endl;
-        exit(1);
-    }
-    string s = *argv++;
-    argc--;
-    DateInterval di;
-    if (!parsedateinterval(s, &di)) {
-        cerr << "Parse failed" << endl;
-        exit(1);
-    }
-    cerrdip("", &di);
-    exit(0);
-#elif 0
-    DateInterval di;
-    for (int i = 0; i < nperiods; i++) {
-        if (!parsedateinterval(periods[i], &di)) {
-            cerr << "Parsing failed for [" << periods[i] << "]" << endl;
-        } else {
-            cerrdip(string(periods[i]).append(" : "), &di);
-        }
-    }
-    exit(0);
-#elif 0
-    for (int i = 0; i < npairs; i++) {
-        {
-            int c = stringicmp(pairs[i].s1, pairs[i].s2);
-            printf("'%s' %s '%s' ", pairs[i].s1,
-                   c == 0 ? "==" : c < 0 ? "<" : ">", pairs[i].s2);
-        }
-        {
-            int cl = stringlowercmp(pairs[i].s1, pairs[i].s2);
-            printf("L '%s' %s '%s' ", pairs[i].s1,
-                   cl == 0 ? "==" : cl < 0 ? "<" : ">", pairs[i].s2);
-        }
-        {
-            int cu = stringuppercmp(pairs[i].s1, pairs[i].s2);
-            printf("U '%s' %s '%s' ", pairs[i].s1,
-                   cu == 0 ? "==" : cu < 0 ? "<" : ">", pairs[i].s2);
-        }
-        printf("\n");
-    }
-#elif 0
-    for (int i = 0; i < nsuffpairs; i++) {
-        int c = stringisuffcmp(suffpairs[i].s1, suffpairs[i].s2);
-        printf("[%s] %s [%s] \n", suffpairs[i].s1,
-               c == 0 ? "matches" : c < 0 ? "<" : ">", suffpairs[i].s2);
-    }
-#elif 0
-    std::string testit("\303\251l\303\251gant");
-    for (int sz = 10; sz >= 0; sz--) {
-        utf8truncate(testit, sz);
-        cout << testit << endl;
-    }
-#elif 0
-    std::string testit("ligne\ndeuxieme ligne\r3eme ligne\r\n");
-    cout << "[" << neutchars(testit, "\r\n") << "]" << endl;
-    string i, o;
-    cout << "neutchars(null) is [" << neutchars(i, "\r\n") << "]" << endl;
-#elif 0
-    map<string, string> substs;
-    substs["a"] = "A_SUBST";
-    substs["title"] = "TITLE_SUBST";
-    string in = "a: %a title: %(title) pcpc: %% %";
-    string out;
-    pcSubst(in, out, substs);
-    cout << in << " => " << out << endl;
-
-    in = "unfinished: %(unfinished";
-    pcSubst(in, out, substs);
-    cout << in << " => " << out << endl;
-    in = "unfinished: %(";
-    pcSubst(in, out, substs);
-    cout << in << " => " << out << endl;
-    in = "empty: %()";
-    pcSubst(in, out, substs);
-    cout << in << " => " << out << endl;
-    substs.clear();
-    in = "a: %a title: %(title) pcpc: %% %";
-    pcSubst(in, out, substs);
-    cout << "After map clear: " << in << " => " << out << endl;
-#elif 0
-    list<string> tokens;
-    tokens.push_back("");
-    tokens.push_back("a,b");
-    tokens.push_back("simple value");
-    tokens.push_back("with \"quotes\"");
-    string out;
-    stringsToCSV(tokens, out);
-    cout << "CSV line: [" << out << "]" << endl;
-#elif 0
-    string sshort("ABC");
-    string slong("ABCD");
-    string sshortsmaller("ABB");
-
-    vector<pair<string, string> > cmps;
-    cmps.push_back(pair<string, string>(sshort, sshort));
-    cmps.push_back(pair<string, string>(sshort, slong));
-    cmps.push_back(pair<string, string>(slong, sshort));
-    cmps.push_back(pair<string, string>(sshortsmaller, sshort));
-    cmps.push_back(pair<string, string>(sshort, sshortsmaller));
-
-    for (vector<pair<string, string> >::const_iterator it = cmps.begin();
-            it != cmps.end(); it++) {
-        cout << it->first << " " << it->second << " " <<
-             stringicmp(it->first, it->second) << endl;
-    }
-    cout << endl;
-    for (vector<pair<string, string> >::const_iterator it = cmps.begin();
-            it != cmps.end(); it++) {
-        cout << it->first << " " << it->second << " " <<
-             stringlowercmp(stringtolower(it->first), it->second) << endl;
-    }
-    cout << endl;
-    for (vector<pair<string, string> >::const_iterator it = cmps.begin();
-            it != cmps.end(); it++) {
-        cout << it->first << " " << it->second << " " <<
-             stringuppercmp(it->first, it->second) << endl;
-    }
-
-#endif
-}
-
-#endif
