@@ -1,23 +1,25 @@
-/* Copyright (C) 2004-2016 J.F.Dockes
- *   This program is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; either version 2 of the License, or
- *   (at your option) any later version.
+/* Copyright (C) 2006-2016 J.F.Dockes
  *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details.
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
  *
- *   You should have received a copy of the GNU General Public License
- *   along with this program; if not, write to the
- *   Free Software Foundation, Inc.,
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ *   02110-1301 USA
  */
 #ifndef _SMALLUT_H_INCLUDED_
 #define _SMALLUT_H_INCLUDED_
 
 #include <sys/types.h>
+#include <stdint.h>
 
 #include <string>
 #include <vector>
@@ -63,6 +65,9 @@ extern int stringuppercmp(const std::string& alreadyupper,
 
 extern void stringtolower(std::string& io);
 extern std::string stringtolower(const std::string& io);
+extern void stringtoupper(std::string& io);
+extern std::string stringtoupper(const std::string& io);
+extern bool beginswith(const std::string& big, const std::string& small);
 
 // Is one string the end part of the other ?
 extern int stringisuffcmp(const std::string& s1, const std::string& s2);
@@ -141,6 +146,9 @@ extern void trimstring(std::string& s, const char *ws = " \t");
 /** Escape things like < or & by turning them into entities */
 extern std::string escapeHtml(const std::string& in);
 
+/** Double-quote and escape to produce C source code string (prog generation) */
+extern std::string makeCString(const std::string& in);
+
 /** Replace some chars with spaces (ie: newline chars). */
 extern std::string neutchars(const std::string& str, const std::string& chars);
 extern void neutchars(const std::string& str, std::string& out,
@@ -155,13 +163,13 @@ extern std::string escapeShell(const std::string& str);
 extern std::string truncate_to_word(const std::string& input,
                                     std::string::size_type maxlen);
 
-void ulltodecstr(unsigned long long val, std::string& buf);
-void lltodecstr(long long val, std::string& buf);
-std::string lltodecstr(long long val);
-std::string ulltodecstr(unsigned long long val);
+void ulltodecstr(uint64_t val, std::string& buf);
+void lltodecstr(int64_t val, std::string& buf);
+std::string lltodecstr(int64_t val);
+std::string ulltodecstr(uint64_t val);
 
 /** Convert byte count into unit (KB/MB...) appropriate for display */
-std::string displayableBytes(off_t size);
+std::string displayableBytes(int64_t size);
 
 /** Break big string into lines */
 std::string breakIntoLines(const std::string& in, unsigned int ll = 100,
@@ -189,45 +197,53 @@ inline void leftzeropad(std::string& s, unsigned len)
     }
 }
 
-// Code for static initialization of an stl map. Somewhat like Boost.assign.
-// Ref: http://stackoverflow.com/questions/138600/initializing-a-static-stdmapint-int-in-c
-// Example use: map<int, int> m = create_map<int, int> (1,2) (3,4) (5,6) (7,8);
-
-template <typename T, typename U>
-class create_map {
-private:
-    std::map<T, U> m_map;
+// A class to solve platorm/compiler issues for simple regex
+// matches. Uses the appropriate native lib under the hood.
+// This always uses extended regexp syntax.
+class SimpleRegexp {
 public:
-    create_map(const T& key, const U& val) {
-        m_map[key] = val;
-    }
-
-    create_map<T, U>& operator()(const T& key, const U& val) {
-        m_map[key] = val;
-        return *this;
-    }
-
-    operator std::map<T, U>() {
-        return m_map;
-    }
-};
-template <typename T>
-class create_vector {
+    enum Flags {SRE_NONE = 0, SRE_ICASE = 1, SRE_NOSUB = 2};
+    /// @param nmatch must be >= the number of parenthesed subexp in exp
+    SimpleRegexp(const std::string& exp, int flags, int nmatch = 0);
+    ~SimpleRegexp();
+    /// Match input against exp, return true if matches
+    bool simpleMatch(const std::string& val) const;
+    /// After simpleMatch success, get nth submatch, 0 is the whole
+    /// match, 1 first parentheses, etc.
+    std::string getMatch(const std::string& val, int matchidx) const;
+    /// Calls simpleMatch()
+    bool operator() (const std::string& val) const;
+    /// Check after construction
+    bool ok() const;
+    
+    class Internal;
 private:
-    std::vector<T> m_vector;
-public:
-    create_vector(const T& val) {
-        m_vector.push_back(val);
-    }
-
-    create_vector<T>& operator()(const T& val) {
-        m_vector.push_back(val);
-        return *this;
-    }
-
-    operator std::vector<T>() {
-        return m_vector;
-    }
+    Internal *m;
 };
 
+/// Utilities for printing names for defined values (Ex: O_RDONLY->"O_RDONLY")
+
+/// Entries for the descriptive table
+struct CharFlags {
+    unsigned int value; // Flag or value
+    const char *yesname;// String to print if flag set or equal
+    const char *noname; // String to print if flag not set (unused for values)
+};
+
+/// Helper macro for the common case where we want to print the
+/// flag/value defined name
+#define CHARFLAGENTRY(NM) {NM, #NM}
+
+/// Translate a bitfield into string description
+extern std::string flagsToString(const std::vector<CharFlags>&,
+                                 unsigned int flags);
+
+/// Translate a value into a name
+extern std::string valToString(const std::vector<CharFlags>&, unsigned int val);
+
+/// Reverse operation: translate string into bitfield
+extern unsigned int
+stringToFlags(const std::vector<CharFlags>&, const std::string& input,
+              const char *sep = "|");
+
 #endif /* _SMALLUT_H_INCLUDED_ */
